local lang = {
  ["abort"] = "Přerušit",
  ["actions"] = "Akce",
  ["activities"] = "Aktivity",
  ["activity"] = "Aktivita",
  ["advanced"] = "Pokročilé",
  ["aggregation"] = "Agregace",
  ["alias"] = "Alias",
  ["all"] = "Vše",
  ["allowed"] = "Povoleno",
  ["any"] = "Jakýkoliv",
  ["app_name"] = "Název Aplikace",
  ["application"] = "Aplikace",
  ["applications"] = "Aplikace",
  ["apply"] = "Použít",
  ["arp"] = "ARP",
  ["arp_top_talkers"] = "ARP Matrix Talkers",
  ["as"] = "AS",
  ["as_number"] = "AS number",
  ["asn"] = "ASN",
  ["available"] = "Dostupný",
  ["backup"] = "Záloha",
  ["begin"] = "Začít",
  ["breakdown"] = "Breakdown",
  ["bridge"] = "Most",
  ["broadcast_domain"] = "Broadcast Domain",
  ["broadcast_traffic"] = "Broadcast Traffic",
  ["bytes"] = "Bytů",
  ["cancel"] = "Zrušit",
  ["categories"] = "Kategorie",
  ["category"] = "Kategorie",
  ["change_number_of_rows"] = "Změň počet řádků na stránku",
  ["chart"] = "Chart",
  ["client"] = "Klient",
  ["clone"] = "Klonovat",
  ["close"] = "Zavřít",
  ["countries"] = "Země / Státy",
  ["date_from"] = "Začít Od Datum/Čas:",
  ["date_to"] = "Skončit Od Datum/Čas:",
  ["day"] = "Den",
  ["define"] = "Definuj",
  ["delete"] = "Smaž",
  ["destination"] = "Cíl",
  ["device_protocols_description"] = "Na této stránce je možné nakonfigurovat seznam přijatelných aplikací podle typu a směru zařízení (zařízení jako klient nebo server s ohledem na aplikaci). Povolením výstrah zařízení aplikace na konfigurační stránce výstrah v části Předvolby se výstrahy generují, když je detekována anomální aplikace.",
  ["devices"] = "Zařízení",
  ["difference"] = "Rozdíl",
  ["disabled"] = "Vypnutý",
  ["discarded"] = "Smazaný",
  ["dns"] = "DNS",
  ["domain"] = "Doména",
  ["download"] = "Stáhnout",
  ["download_x"] = "%{what} stáhnout",
  ["downloaders"] = "Download Volume",
  ["drilldown"] = "Drilldown",
  ["duplexstatus"] = "Duplex Status",
  ["duration"] = "Doba trvání",
  ["egress"] = "Odchozí",
  ["empty"] = "Prázdný",
  ["end"] = "Konec",
  ["enterpriseOnly"] = "Tato funkce je k dispozici pouze v edici ntopng Enterprise",
  ["error"] = "Chyba",
  ["error_no_search_results"] = "Nebyly nalezeny žádné výsledky. Upravte prosím kritéria vyhledávání.",
  ["error_not_granted"] = "Žádosti nebylo vyhověno",
  ["error_rrd_cannot_complete_dump"] = "Nelze dokončit výpis místních časů hostitelů. Disk je pomalý nebo příliš mnoho místních hostitelů?",
  ["error_rrd_low_resolution"] = "Žádáte o načtení dat s nižším rozlišením, než jaké je k dispozici na RRD, což povede k neplatným datům. <br> Pokud stále chcete data s takovou podrobností, vylaďte prosím <a href=\"%{prefs}\">Časový rozvrh aplikací / sítí</a> preference",
  ["errors"] = "Chyby",
  ["expired_csrf"] = "Požadovanou akci nelze provést, protože platnost stránky vypršela. Proveďte akci znovu.",
  ["fingerprint_note"] = "Název aplikace je nastaven, pouze pokud je ntopng nakonfigurován pro příjem zdroje eBPF prostřednictvím ZMQ",
  ["flow"] = "Tok",
  ["flow_search_criteria"] = "Kritéria vyhledávání toku",
  ["flow_search_from_aggregated"] = "(Agregován)",
  ["flow_search_results"] = "Výsledky hledání toku",
  ["flows"] = "Toky",
  ["forbidden"] = "Zakázáno",
  ["free"] = "Volný",
  ["from"] = "z",
  ["gateway"] = "Brány",
  ["hassh_fingerprint"] = "HASSH Fingerprint",
  ["host"] = "Host %{host}",
  ["host_address"] = "Host Address",
  ["hosts"] = "Hosts",
  ["hour"] = "Hodina",
  ["http"] = "HTTP",
  ["icmp"] = "ICMP",
  ["iface_download"] = "%{iface} download",
  ["iface_upload"] = "%{iface} upload",
  ["incomingflows"] = "Aktivní příchozí toky",
  ["info"] = "Info",
  ["ingress"] = "Vstup",
  ["interface"] = "Rozhraní",
  ["interface_ifname"] = "Rozhraní %{ifname}",
  ["interfaces"] = "Rozhraní",
  ["ip_address"] = "IP Adresa",
  ["ipv4"] = "IPv4",
  ["ipv6"] = "IPv6",
  ["ja3_fingerprint"] = "JA3 Fingerprint",
  ["key"] = "Klíč",
  ["language"] = "Jazyk",
  ["layer_2"] = "Mac Addresses",
  ["legenda"] = "Legenda",
  ["local_traffic"] = "Lokální Provoz",
  ["mac_address"] = "Mac Address",
  ["max_rate"] = "Max Rate",
  ["memory"] = "Paměť",
  ["model"] = "Model",
  ["month"] = "Měsíc",
  ["mtu"] = "MTU",
  ["name"] = "Název",
  ["netmask"] = "Netmask",
  ["networks"] = "Sítě",
  ["next"] = "Další",
  ["no"] = "Ne",
  ["noTraffic"] = "Pro zadaný výběr data a času nebyl hlášen žádný provoz",
  ["no_data_available"] = "Nejsou k dispozici žádná data",
  ["no_ports"] = "Žádné Porty",
  ["no_results_found"] = "Nebyly nalezeny žádné výsledky",
  ["no_talkers_for_the_host"] = "Pro aktuálního hostitele nejsou žádní talkers",
  ["note_flow_search_allowed_networks"] = "Aktuální uživatel smí procházet pouze následující sítě: %{nets}.",
  ["note_flow_search_allowed_networks_applications"] = "Hostitelé, kteří nepatří k žádné z povolených sítí, budou před aplikačními talkers skryti.",
  ["note_flow_search_allowed_networks_counter"] = "Čítače ve výsledcích hledání toku jsou totální, ale budou zobrazeny pouze toky s klientem a serverem v povolených sítích.",
  ["note_flow_search_allowed_networks_ipv6"] = "Neprázdné povolené sítě IPv6 způsobí zobrazení všech toků IPv6.",
  ["note_flow_search_allowed_networks_talkers"] = "Hostitelé, kteří nepatří k žádné z povolených sítí, budou skryti před Top Talkers.",
  ["notes"] = "POZNÁMKY:",
  ["num_different_ports"] = "%{num} ports. None doing %{threshold}%%+ of the traffic.",
  ["num_uses"] = "Počet Užití",
  ["operating_systems"] = "Operační Systémy",
  ["os"] = "OS",
  ["other"] = "Ostatní",
  ["outgoingflows"] = "Aktivní Odchozí Toky",
  ["overview"] = "Přehled",
  ["packets"] = "Pakety",
  ["peers"] = "peers",
  ["percentage"] = "Procenta",
  ["pkts"] = "Pkts",
  ["port"] = "Port",
  ["ports"] = "Porty",
  ["previous"] = "Předchozí",
  ["protocol"] = "Protokol",
  ["protocol_categories"] = "Kategorie Protokolu",
  ["protocols"] = "Protokoly",
  ["purged_error_message"] = "Je velmi pravděpodobné, že platnost vypršela a %{product} ji vymazal z paměti. Nastavení časového limitu vyprázdnění můžete nastavit z <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preference</a>.",
  ["quotas"] = "Kvóty",
  ["reason"] = "Důvod",
  ["received"] = "Přijato",
  ["refresh"] = "Obnovit",
  ["remote_hosts"] = "Vzdálení Hosté",
  ["remote_networks"] = "Vzdálené Sítě",
  ["remove"] = "Odstranit",
  ["reset"] = "Reset",
  ["restore"] = "Obnovit",
  ["retry"] = "Znova",
  ["running"] = "Běžící",
  ["save"] = "Ulož",
  ["save_configuration"] = "Ulož Konfiguraci",
  ["save_settings"] = "Ulož Nastavení",
  ["score"] = "Skóre",
  ["search_host"] = "Vyhledávání",
  ["seen_since"] = "Viděn od",
  ["sent"] = "Posláno",
  ["server"] = "Server",
  ["showing_x_to_y_rows"] = "Ukazuji %{x} do %{y} z %{tot} řádků",
  ["similarity"] = "Podobnost",
  ["speed"] = "Rychlost",
  ["ssh"] = "SSH",
  ["start"] = "Start",
  ["status"] = "Status",
  ["stop"] = "Stop",
  ["summary"] = "Souhrn",
  ["system"] = "System",
  ["system_status"] = "Stav systému",
  ["talkers"] = "Talkers",
  ["tcp_flags"] = "TCP Flags",
  ["tcp_stats"] = "TCP Statistics",
  ["telemetry"] = "Telemetrie",
  ["throughput"] = "Propustnost",
  ["time"] = "Čas",
  ["timeframe"] = "Časové okno",
  ["tls"] = "TLS",
  ["tls_certificate"] = "TLS Certifikát",
  ["today"] = "Dnes",
  ["total"] = "Celkem",
  ["total_incoming_misbehaving_flows"] = "Celkový počet chybných toků jako Server",
  ["total_incoming_unreachable_flows"] = "Celkový počet nedosažitelných toků jako Server",
  ["total_outgoing_misbehaving_flows"] = "Celkem chybné toky jako klient",
  ["total_outgoing_unreachable_flows"] = "Total Port Unreachable Flows As Client",
  ["traffic"] = "Provoz",
  ["traffic_policy"] = "Politika Provozu",
  ["undo"] = "Zpět",
  ["unknowers"] = "Unknown Traffic Volume",
  ["unknown"] = "Neznámý",
  ["unlimited"] = "&infin;",
  ["uploaders"] = "Upload Volume",
  ["version"] = "Vaše verze je %{vers}.",
  ["via"] = "Skrz",
  ["vlan"] = "VLAN",
  ["volume"] = "Volume",
  ["volume_size"] = "Volume Size",
  ["warning"] = "Varování",
  ["week"] = "Týden",
  ["welcome"] = "Vítejte",
  ["welcome_to"] = "Vítejte do %{product}",
  ["yes"] = "Ano",
  ["about"] = {
    ["about_ntopng"] = "O ntopng",
    ["about_x"] = "O %{product}",
    ["built_on"] = "Postaveno na",
    ["callback_directories"] = "Adresáře uživatelských skriptů",
    ["copyright"] = "Copyright",
    ["cpu_load"] = "CPU load",
    ["data_directory"] = "Data",
    ["datadir_warning"] = "Oznámení o migraci datového adresáře",
    ["defs_directories"] = "Definice adresářů",
    ["dhcp_range_missing_warning"] = "<a href='%{url}'>%{name}</a> preference je neúčinná. Prosím nakonfigurujte <a href='%{dhcp_url}'>Rozsah DHCP</a> vhodně.",
    ["directories"] = "Adresáře",
    ["flow_checks_directory"] = "Tok",
    ["host_checks_directory"] = "Host",
    ["host_identifier_warning"] = "Toto rozhraní monitoruje hostitele DHCP. Zvažte prosím změnu <a href='%{url}'>%{name}</a> preference \"Mac adresy\".",
    ["influxdb_migration_msg"] = "Máte spoustu místních hostitelů. Prosím zvažte <a href='%{url}'>přesun z RRD do InfluxDB</a> pro ukládání časových řad pro zlepšení výkonu.",
    ["interface_callbacks_directory"] = "Rozhraní",
    ["last_log"] = "Poslední záznam trace",
    ["licence"] = "Licence",
    ["licence_expires_in"] = "Licence vyprší za %{time}",
    ["licence_generation"] = "Kliknutím na výše uvedenou adresu URL vygenerujete licenci pro profesionální verzi nebo <br>zakupte licenci na<a href=\"%{purchase_url}\">e-shop</a>. Pokud jste nezisková, výzkumová či vzdělávací <br>instituce, prosím, přečtěte <a href=\"%{universities_url}\">toto</a>.",
    ["maintenance"] = "Údržba: Do doby %{_until} [%{days_left} zbývající dny]",
    ["maintenance_expired"] = "%{product} údržba vypršela",
    ["maxmind"] = "Tento produkt obsahuje data GeoDB vytvořená <a class='ntopng-external-link' href=\"%{maxmind_url}\">MaxMind <i class=\"fas fa-external-link-alt\"></i></a> / <a class='ntopng-external-link' href='https://db-ip.com'>DB-IP <i class=\"fas fa-external-link-alt\"></i></a>.",
    ["network_callbacks_directory"] = "Síť",
    ["ntop_blog"] = "ntop Blog",
    ["platform"] = "Platforma",
    ["ram_memory"] = "RAM",
    ["readme_and_manual"] = "Uživatelská příručka",
    ["report_issue"] = "Nahlásit Problém",
    ["runtime_status"] = "Runtime Status",
    ["save_licence"] = "Uložit licenci",
    ["scripts_directory"] = "Skripty",
    ["specify_licence"] = "Zde zadejte svou licenci ntopng",
    ["startup_line"] = "Startup Line",
    ["system"] = "Systém",
    ["system_id"] = "ID systému",
    ["telegram"] = "Pomoc A Novinky",
    ["telemetry_data_opt_out_msg"] = "Přispějte do projektu zasláním šifrovaného, <a href=\"%{tel_url}\">anonymních telemetrických dat</a> do <a href=\"%{ntop_org}\">ntop.org</a>: navštivte <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> předvolby</a> stránky a vyjádřete své preference.",
    ["upgrade_to_professional"] = "Upgradujte na profesionální verzi",
    ["uptime"] = "Uptime",
    ["version"] = "Verze",
    ["you_have_too_many_flows"] = "Máte příliš mnoho hostitelů / toků %{product} konfigurace a to povede k poklesu paketů a vysokému zatížení CPU. Prosím restartujte %{product} zvýšením -x a -X",
  },
  ["activities_page"] = {
    ["host_activity"] = "Hostitelská aktivita",
  },
  ["alert_messages"] = {
    ["host_alert_countries_contacts"] = "Příliš mnoho zemí kontaktováno% {entity} [% {value} & gt; % {threshold} zemí]",
    ["a_new_device_has_connected"] = "Nové zařízení <a href=\"%{url}\">%{device}</a> se připojilo do sítě.",
    ["anomalous_tcp_flags"] = "%{entity} has %{sent_or_rcvd} too many TCP RST flags vs SYN [Ratio: %{ratio}%%]",
    ["broadcast_domain_too_large"] = "Provoz ARP z <a href=\"%{src_mac_url}\">%{src_mac}</a>/<a href=\"%{spa_url}\">%{spa}</a> do <a href=\"%{dst_mac_url}\">%{dst_mac}</a>/<a href=\"%{tpa_url}\">%{tpa}</a> detekováno. Je nepravděpodobné, že by mezi těmito IPs viděl přenos ARP, protože patrně patří do různých vysílacích domén. Zkontrolujte konfigurace hostitelů a sítí.",
    ["device_has_connected"] = "Zařízení <a href=\"%{url}\">%{device}</a> se připojilo do sítě.",
    ["device_has_disconnected"] = "Zařízení <a href=\"%{url}\">%{device}</a> se odpojilo ze sítě.",
    ["flow_flood_attacker"] = "%{entity} is a flow flooder [%{value} &gt; %{threshold} flows sent]",
    ["flow_flood_victim"] = "%{entity} is under flow flood attack [%{value} &gt; %{threshold} flows received]",
    ["host_entity"] = "host %{entity_value}",
    ["host_pool_has_connected"] = "Hostitelský fond <a href=\"%{url}\">%{pool}</a> se připojil do sítě",
    ["host_pool_has_disconnected"] = "Hostitelský fond <a href=\"%{url}\">%{pool}</a> se odpojil od sítě.",
    ["host_remote_to_remote"] = "Vzdálený host <a href=\"%{url}\">%{ip}</a> %{mac} kontaktoval vzdáleného hosta. Vzdálené dálkové toky dostupné z  <a href=\"%{flow_alerts_url}\">stránky s upozorněním na toky</a>.",
    ["influxdb_dropped_points"] = "Points dropped. Nelze je odeslat do \"%{influxdb}\".",
    ["influxdb_partial_write"] = "To lze opravit nastavením \"max-values-per-tag = 0\" v konfiguraci serveru InfluxDB.",
    ["influxdb_write_error"] = "Při odesílání dat časových adres do došlo k chybě \"%{influxdb}\": %{err}",
    ["interface_entity"] = "rozhraní %{entity_value}",
    ["ip_outside_dhcp_range_router_ip"] = "[Router: <a href=\"%{router_url}\">%{router_ip}</a>]",
    ["ip_outsite_dhcp_range"] = "Zařízení <a href=\"%{client_url}\">%{client_mac}</a> v <a href=\"%{client_ip_url}\">%{client_ip}</a> ,které je mimo <a href=\"%{dhcp_url}\">nakonfigurovaného rozsahu DHCP</a>. [Sender: <a href=\"%{sender_url}\">%{sender_mac}</a>]",
    ["mac_ip_association_change"] = "IP %{ip} změněno přidružení z <a href=\"%{old_mac_url}\">%{old_mac}</a> do <a href=\"%{new_mac_url}\">%{new_mac}</a>",
    ["misbehaving_flows_ratio"] = "%{entity} má %{sent_or_rcvd} příliš mnoho chybných toků vs celkové toky [Poměr: %{ratio}%%]",
    ["network_entity"] = "Síť %{entity_value}",
    ["nfq_flushed"] = "Rozhraní <a href=\"%{url}\">%{name}</a> fronty paketů propláchnuta. Fronta %{pct}%% plná s %{tot} pakety a %{dropped} drops.",
    ["ntopng_anomalous_termination"] = "Zahájeno po anomálním ukončení (<a href=\"%{url}\">hlášení o chybě</a>)",
    ["ntopng_start"] = "Začal",
    ["ntopng_stop"] = "Přestal",
    ["open_files_limit_too_small"] = "Ntopng zjistil, že maximální počet souborů, které MySQL může otevřít, je potenciálně příliš malý. To může mít za následek ztrátu dat toku v důsledku chyb, například [Nedostatek zdrojů při otevírání souboru './ntopng/flowsv6#P#p22.MYD' (Errcode: 24 - Too many open files)][23]. Nezapomeňte zvýšit hodnotu open_files_limit nebo, pokud chcete toto varování ignorovat, deaktivujte kontrolu z předvoleb.",
    ["ping_host_unreachable"] = "Host %{ip_label} %{numeric_ip} je nedosažitelný.",
    ["ping_rtt_too_slow"] = "RTT příliš vysoko pro hostitele %{ip_label} %{numeric_ip}. Měřené RTT%{rtt_value} ms, maximální očekávané RTT%{maximum_rtt} ms.",
    ["potentially_dangerous_protocol_description"] = "Tento tok může být pro síť škodlivý, protože se používá zastaralý nebo zranitelný protokol.",
    ["proto_bytes_quotas"] = "%{proto} bajty",
    ["proto_time_quotas"] = "%{proto} čas",
    ["slow_periodic_activity"] = "Periodická činnost \"%{script}\" trvala příliš mnoho na dokončení [%{duration} &gt; %{max_duration}]",
    ["subject_quota_exceeded"] = "Hostitelský fond <a href=\"%{url}\">%{pool}</a> překročena %{subject} kvóta[%{value} &gt; %{quota}]",
    ["syn_flood_attacker"] = "%{entity} is a SYN flooder [%{value} &gt; %{threshold} SYN sent]",
    ["syn_flood_victim"] = "%{entity} is under SYN flood attack [%{value} &gt; %{threshold} SYN received]",
    ["syn_scan_attacker"] = "%{entity} is a SYN Scan attacker [%{value} &gt; %{threshold} SYN sent]",
    ["syn_scan_victim"] = "%{entity} is under SYN Scan [%{value} &gt; %{threshold} SYN received]",
    ["test_failed"] = "Test selhal",
    ["threshold_crossed"] = "%{granularity} <b>%{metric}</b> crossed by %{entity} [%{value} %{op} %{threshold}]",
    ["too_many_drops"] = "%{iface}má příliš mnoho vynechaných paketů [&gt %{max_drops}%%]",
    ["too_many_flows"] = "%{iface} má příliš mnoho toků. Prosím rozšířte %{option} možnost příkazového řádku",
    ["too_many_hosts"] = "%{iface} má příliš mnoho hostitelů. Prosím rozšířte %{option} možnost příkazového řádku",
    ["x_alerts"] = "%{num} upozornění",
  },
  ["alerts_dashboard"] = {
    ["host_alert_countries_contacts"] = "Země Upozornění na kontakty",
    ["active_flows_anomaly"] = "Anomálie aktivních toků.",
    ["alert_counts"] = "Počítá",
    ["alert_duration"] = "Doba trvání",
    ["alert_severity"] = "Vážnost",
    ["alert_type"] = "Typ",
    ["alerts_dashboard"] = "Informační panel upozornění",
    ["all_hosts"] = "Všichni hostitelé",
    ["anomalous_tcp_flags"] = "Anomalous TCP Flags",
    ["blacklisted_flow"] = "Tok na černé listině",
    ["blocked_flow"] = "Blokovaný Tok",
    ["broadcast_domain_too_large"] = "Vysílací doména",
    ["connection_issues"] = "Problémy S Připojením",
    ["custom_period"] = "Vlastní období",
    ["device_connection"] = "Připojení zařízení",
    ["device_disconnection"] = "Odpojení zařízení",
    ["dns_anomaly"] = "DNS Anomaly",
    ["engaged_for_longest"] = "Past Alerts Engaged for Longest",
    ["error"] = "Chyba",
    ["experimental_checks"] = "Experimentální",
    ["experimental_checks_description"] = "Povolit experimentální kontroly výstrah:  TCP flags, poměr anomálních toků",
    ["external_alert"] = "Externí upozornění",
    ["five_mins"] = "Trvá 5 minut",
    ["flow_alert_origins"] = "Původy výstrah toku",
    ["flow_alert_targets"] = "Cíle upozornění toku",
    ["flow_misbehaviour"] = "Špatné chování Toku",
    ["flows_flood"] = "Flows Flood",
    ["ghost_network_detected"] = "Byla Detekována Ghost Network",
    ["ghost_network_detected_description"] = "Subnet %{network} nepatří do <a href='%{url}'>%{entity} sítě </a>.",
    ["host_pool_connection"] = "Hostitelský fond Připojen",
    ["host_pool_disconnection"] = "Hostitelský fond Odpojení",
    ["icmp_anomaly"] = "ICMP Anomaly",
    ["inactivity"] = "Nečinnost",
    ["influxdb_dropped_points"] = "InfluxDB Dropped Points",
    ["influxdb_export_failure"] = "InfluxDB Export selhal",
    ["info"] = "Info",
    ["involving_msg"] = "Zapojení výstrah toku",
    ["last_day"] = "Poslední Den",
    ["last_hour"] = "Poslední Hodina",
    ["last_minute"] = "Poslední Minuta",
    ["list_download_failed"] = "Stažení seznamu se nezdařilo",
    ["local_only"] = "Jen lokální hostitelé",
    ["local_origin_remote_target"] = "Místní původ - vzdálený cíl",
    ["login_failed"] = "Přihlášení Se Nezdařilo",
    ["mac_ip_association_change"] = "IP/MAC Změna",
    ["malicious_signature_detected"] = "Možný škodlivý Signature",
    ["many_replies"] = "%{count} %{what} odpovědi",
    ["many_requests"] = "%{count} %{what} požadavky",
    ["misbehaving_flows_ratio"] = "Příliš mnoho špatnéhých toků",
    ["misconfigured_app"] = "Nesprávně nakonfigurovaná aplikace",
    ["misconfigured_dhcp_range"] = "Chybně nakonfigurovaný rozsah DHCP",
    ["new_device"] = "Nové Zařízení",
    ["nfq_flushed"] = "Fronta paketů propláchnuta",
    ["no_alert"] = "Žádné Upozornění",
    ["no_alerts"] = "Žádné Upozornění",
    ["none"] = "Žádný",
    ["not_engaged"] = "Není zapojen",
    ["one_day"] = "Poslední Den",
    ["one_hour"] = "Poslední Hodina",
    ["one_min"] = "Poslední Minuta",
    ["one_reply"] = "%{count} %{what} odpověď",
    ["one_request"] = "%{count} %{what} požadavek",
    ["ping_issues"] = "Ping",
    ["potentially_dangerous_protocol"] = "Potenciálně nebezpečný protokol",
    ["process"] = "Proces",
    ["quota_exceeded"] = "Kvóta překročena",
    ["remote_only"] = "Pouze vzdálení hostitelé",
    ["remote_origin_local_target"] = "Vzdálený původ - místní cíl",
    ["remote_to_remote"] = "Remote to Remote",
    ["search_criteria"] = "Nastavení řídicího panelu",
    ["slow_periodic_activity"] = "Pomalá periodická aktivita",
    ["snmp_device_is_unresponsive"] = "SNMP zařízení a href=\"%{url}\">%{device}</a> neodpovídá",
    ["snmp_port_changed_duplex_status"] = "Rozhrání <a href=\"%{port_url}\">%{port}</a> na SNMP zařízení <a href=\"%{url}\">%{device}</a> změnilo svůj duplexní stav na %{new_op}",
    ["snmp_port_changed_operational_status"] = "Rozhrání <a href=\"%{port_url}\">%{port}</a> na SNMP zařízení <a href=\"%{url}\">%{device}</a> změnilo svůj stav na %{new_op}",
    ["snmp_port_duplexstatus_change"] = "Změna stavu duplexu rozhraní",
    ["snmp_port_errors"] = "Chyby rozhraní",
    ["snmp_port_errors_increased"] = "Počítadla  smazaných / chyb zvýšené na rozhraní <a href=\"%{port_url}\">%{port}</a> na zařízení SNMP <a href=\"%{url}\">%{device}</a>",
    ["snmp_port_load_threshold_exceeded"] = "na zařízení SNMP",
    ["snmp_port_load_threshold_exceeded_message"] = "%{direction} zatížení je %{port_load}%% na rozhraní <a href=\"%{port_url}\">%{port}</a> na zařízení SNMP <a href=\"%{url}\">%{device}</a>",
    ["snmp_port_status_change"] = "Změna stavu rozhraní",
    ["starting_on"] = "Začínající na",
    ["submit"] = "Aktualizujte řídicí panel",
    ["suspicious_activity"] = "Podezřelá Aktivita",
    ["suspicious_device_protocol"] = "Podezřelý Protokol Zařízení",
    ["tcp_syn_flood"] = "TCP SYN Flood",
    ["tcp_syn_scan"] = "TCP SYN Scan",
    ["threashold_cross"] = "Threshold Cross",
    ["too_low_replies_received"] = "%{entity} odeslal %{requests} ale přijal %{replies} [%{granularity} poměr: %{ratio}%%]",
    ["too_low_replies_sent"] = "%{entity} přijal %{requests} ale odeslal %{replies} [%{granularity} poměr: %{ratio}%%]",
    ["too_many_drops"] = "Packet Drops",
    ["total_alerts"] = "Celkem upozornění",
    ["trailing_msg"] = "Time Window",
    ["unresponsive_device"] = "Zařízení neodpovídá",
    ["user_activity"] = "Uživatelská aktivita",
    ["warning"] = "Varování",
    ["web_mining"] = "Web Mining",
  },
  ["alerts_thresholds_config"] = {
    ["countries_contacts_title"] = "Země Upozornění na kontakty",
    ["countries_contacts_description"] = "Spustit výstrahu, když počet různých kontaktovaných zemí překročí prahovou hodnotu",
    ["active_local_hosts"] = "Upozornění místních hostitelů",
    ["active_local_hosts_threshold_descr"] = "Spustí upozornění, když počet aktivních místních hostitelů překročí prahovou hodnotu",
    ["activity_time"] = "Výstraha času aktivity",
    ["alert_active_description"] = "Spustí výstrahu, když delta času aktivity překročí prahovou hodnotu",
    ["alert_bytes_description"] = "Spustí výstrahu, když delta vrstvy 2 bajtů (odeslaná + přijatá) překročí prahovou hodnotu",
    ["alert_bytes_title"] = "Provozní upozornění",
    ["alert_dns_description"] = "Spustí výstrahu, když delta 2 bajtů (odeslaná + přijatá) pro přenos DNS překročí prahovou hodnotu",
    ["alert_flows_description"] = "Spustí výstrahu, když delta toky (jako klient + jako server) překročí prahovou hodnotu",
    ["alert_flows_title"] = "Opozornění toků",
    ["alert_idle_description"] = "Spustí výstrahu, když doba nečinnosti (doba od posledního viděného paketu) překročí prahovou hodnotu",
    ["alert_network_egress_description"] = "Spustí výstrahu, když delta odchozích bajtů překročí prahovou hodnotu",
    ["alert_network_ingress_description"] = "Spustí výstrahu, když delta vstupních bajtů překročí prahovou hodnotu",
    ["alert_network_inner_description"] = "Spustí výstrahu, když delta vnitřních bajtů překročí prahovou hodnotu",
    ["alert_p2p_description"] = "Spustí výstrahu, když delta vrstvy 2 bajtů (odeslaná + přijatá) pro přenos P2P překročí prahovou hodnotu",
    ["alert_packets_description"] = "Spustí výstrahu, když delta paketů (odeslaná + přijatá) překročí prahovou hodnotu",
    ["alert_packets_title"] = "Upozornění na pakety",
    ["alert_throughput_description"] = "Spustí výstrahu, když průměrná propustnost (odeslaná + přijatá) překročí prahovou hodnotu",
    ["common_thresholds_local_sources"] = "%{source} Obvyklá Konfigurace",
    ["daily"] = "Denně",
    ["dns_traffic"] = "DNS Traffic Alert",
    ["egress_traffic"] = "odchozí provozní upozornění",
    ["every_5_minutes"] = "Každých 5 minut",
    ["every_minute"] = "Každou Minutu",
    ["hourly"] = "Hodinově",
    ["idle_time"] = "Upozornění na nečinnost",
    ["ingress_traffic"] = "Vstupní provozní upozornění",
    ["inner_traffic"] = "vnitřní provozní upozornění",
    ["note_add_custom_scripts"] = "%{product} hledá v nich vlastní skripty <a href=\"%{url}\"> <i class=\"fas fa-folder\"></i> adresáře</a>.",
    ["note_checks_on_active_hosts"] = "Kontroly se provádějí pouze u aktivních hostitelů.",
    ["note_consecutive_checks"] = "Následné kontroly nejsou nutně prováděny v po sobě jdoucích obdobích. Pokud je například hostitel nečinný, jeho prahové hodnoty nebudou kontrolovány, dokud nebude znovu aktivní.",
    ["note_control_threshold_checks_periods"] = "Zpětná volání uvedená na těchto kartách jsou prováděna pravidelně.",
    ["note_create_custom_scripts"] = "Dokumentace k vytvoření vlastních skriptů pro provádění zpětných volání je k dispozici zde <a class='ntopng-external-link' href=\"%{url}\">link <i class=\"fas fa-external-link-alt\"></i></a>.",
    ["note_thresholds_expressed_as_delta"] = "Některá zpětná volání počítají deltu. Delta je rozdíl stejného množství mezi dvěma po sobě jdoucími executions.",
    ["notes"] = "POZNÁMKY",
    ["p2p_traffic"] = "P2P Traffic Alert",
    ["threshold_type"] = "Zpětné volání",
    ["thresholds_single_source"] = "%{source} %{alt_name} konfigurace",
    ["throughput"] = "Výstraha průchodnosti",
  },
  ["arp_page"] = {
    ["arp_type"] = "ARP Type",
  },
  ["as_details"] = {
    ["as"] = "Autonomous System",
    ["as_parameter_missing_message"] = "Chybí parametr autonomního systému (interní chyba?)",
    ["as_timeseries_enable_message"] = "AS Timeseries lze povolit z <A HREF=\"%{url}\">%{icon_flask} Preference</A>. K zobrazení prvních datových bodů je třeba jen pár minut.",
    ["no_available_data_for_as"] = "Nejsou k dispozici žádná data pro AS %{asn}.",
  },
  ["as_stats"] = {
    ["autonomous_systems"] = "Autonomní systémy",
  },
  ["categories_page"] = {
    ["search_application"] = "Vyhledávací aplikace",
    ["target"] = "Cíl",
  },
  ["category_lists"] = {
    ["category_lists"] = "Seznamy kategorií",
    ["connection_time_out"] = "Časový limit připojení serveru vypršel po %{duration} sekundách",
    ["disable_some_list"] = "Chcete-li to vyřešit, zakažte některé seznamy.",
    ["edit_list"] = "Upravit seznam kategorií",
    ["enabled"] = "Povoleno",
    ["error_occurred"] = "Při stahování seznamu došlo k chybě '%{name}': %{err}",
    ["http_code"] = "[HTTP Code: %{err_code}]",
    ["last_update"] = "Poslední aktualizace",
    ["list_will_be_updated"] = "Seznam '%{name}'bude aktualizován do 30 sekund.",
    ["loading_stats"] = "Poslední načtení(na %{when}): načten %{num_hosts} domény, %{num_ips} IP adresy, %{num_ja3} JA3 signatures v %{duration} .",
    ["ready_for_update"] = "Připraveno na aktualizaci",
    ["server_returned_error"] = "Server vrátil chybu",
    ["too_many_hosts_loaded"] = "Bylo dosaženo limit  (%{limit} názvů domén)",
    ["too_many_ips_loaded"] = "Bylo dosaženo limitu (%{limit} IP adres )",
    ["too_many_ja3_loaded"] = "Bylo dosaženo limitu (%{limit} Signatures JA3)",
    ["update_frequency"] = "Frekvence aktualizace",
    ["update_now"] = "Aktualizovat teď",
  },
  ["conf_backup"] = {
    ["conf_backup"] = "Konfigurace zálohy",
    ["conf_restore"] = "Obnovte konfiguraci",
  },
  ["contacts_page"] = {
    ["client_address"] = "Adresa klienta",
    ["client_contacts_initiator"] = "Kontakty klienta (Iniciátor)",
    ["contacts"] = "Kontakty",
    ["no_client_contacts_so_far"] = "Dosud žádné klientské kontakty",
    ["no_contacts_message"] = "Pro tohoto hostitele nejsou dostupné žádné kontakty",
    ["no_server_contacts_so_far"] = "Zatím žádné kontakty na serveru.",
    ["server_address"] = "Adresa serveru",
    ["server_contacts_receiver"] = "Kontakty serveru (Přijímač)",
  },
  ["containers_stats"] = {
    ["all_containers"] = "All Containers",
    ["all_pods"] = "All Pods",
    ["avg_rtt"] = "Avg RTT",
    ["avg_rtt_as_client"] = "Avg RTT Jako Klient",
    ["avg_rtt_as_server"] = "Avg RTT Jako Server",
    ["avg_rtt_variance"] = "Avg RTT Odchylka",
    ["avg_rtt_variance_as_client"] = "Avg RTT Varianta jako klient",
    ["avg_rtt_variance_as_server"] = "Avg RTT Varianta jako server",
    ["client_container"] = "Client Container",
    ["client_pod"] = "Client Pod",
    ["client_rtt"] = "Client RTT",
    ["container"] = "Container",
    ["containers"] = "Containers",
    ["containers_list"] = "Containers Seznam",
    ["containers_of_pod"] = "Containers of Pod '%{pod}'",
    ["pod"] = "Pod",
    ["pods"] = "Pods",
    ["pods_list"] = "Pods Seznam",
    ["server_container"] = "Server Container",
    ["server_pod"] = "Server Pod",
    ["server_rtt"] = "Server RTT",
  },
  ["country_details"] = {
    ["country"] = "Stát / Země",
    ["country_parameter_missing_message"] = "Chybí parametr země (interní chyba?)",
    ["no_available_stats_for_country"] = "Žádné dostupné statistiky pro zemi %{country}",
  },
  ["custom_categories"] = {
    ["add"] = "Add",
    ["add_application"] = "Přidat aplikaci",
    ["add_custom_app"] = "Přidat vlastní aplikaci",
    ["add_to_categories"] = "Přidat pravidlo hostitele",
    ["application_exists"] = "Aplikace \"%{app}\" již existuje!",
    ["application_name"] = "Název Aplikace",
    ["application_not_exists"] = "Aplikace \"%{app}\" neexistuje!",
    ["apps_and_categories"] = "Aplikace a kategorie",
    ["custom_host_category"] = "Vlastní pravidlo hostitele",
    ["custom_hosts"] = "Vlastní pravidla",
    ["delete_note"] = "Vlastní aplikace budou po restartu odstraněny, pokud je zadána prázdná sada pravidel.",
    ["domain_names_substrings"] = "Názvy domén jsou interpretovány jako podřetězce, které mají být přiřazeny.'<br>např. \"%{s1}\" bude odpovídat \"%{s2}\" a \"%{s3}\"",
    ["each_host_separate_line"] = "Každé pravidlo musí být umístěno na samostatném řádku",
    ["edit_custom_rules"] = "Upravit vlastní pravidla",
    ["edit_hosts"] = "Upravit Pravidla",
    ["example_port_range"] = "Příklady rozsahu portů: \"%{example1}\", \"%{example2}\"",
    ["host_domain_or_cidr"] = "Pravidla mohou být názvy domén nebo IPv4 addresses/CIDR síťové adresy",
    ["host_domain_or_port"] = "Pravidla mohou být názvy domén, adresy IPv4 nebo rozsahy portů TCP / UDP",
    ["invalid_rule"] = "Neplatné pravidlo bylo ignorováno: %{rule}",
    ["new_app_added"] = "Aplikace \"%{app}\" byla nakonfigurována. Prosím restartujte %{product} aby jste ji mohli začít používat.",
    ["option_needed"] = "Vlastní konfigurace aplikací je v současné době zakázána jako <i>%{option}</i> parametr chybí v konfiguraci. Překontrolujte <a href=\"%{url}\">dokumentaci</a> pro více detailů.",
    ["protos_reboot_necessary"] = "Pravidla aplikace byla napsána. Prosím restartujte %{product} aby jste je aplikovali.",
    ["protos_unexpected_error"] = "Neočekávaná chyba při aktualizaci pravidel aplikace. Další podrobnosti najdete v protokolu %{product}.",
    ["select_url_category"] = "Prosím vyberte, kam bude doména přidána:",
    ["similar_host_found"] = "Pravidlo podobné \"%{host}\" je již obsaženo v %{category} kategorii",
    ["the_following_is_a_list_of_hosts"] = "Následuje seznam vlastních pravidel pro %{category} kategorii",
    ["the_following_is_a_list_of_hosts_app"] = "Následuje seznam vlastních pravidel pro %{application} aplikaci",
    ["the_following_url_will_be_added"] = "Přidá se následující doména:",
  },
  ["dashboard"] = {
    ["actual_traffic"] = "Skutečný provoz",
    ["lastday_app_traffic"] = "Top provoz aplikace za poslední den",
    ["lastday_traffic"] = "Síťová rozhraní: Zobrazení za poslední den",
    ["realtime_app_traffic"] = "Top přenos aplikací v reálném čase",
    ["realtime_traffic"] = "Síťová rozhraní: Provoz v reálném čase",
    ["slow_dashboard_message"] = "Příliš velká latence v %{product} odezvě. Zvažte nastavení vyšší <a href='%{url}'>obnovovací frekvence statistik v reálném čase</a>.",
    ["top_local_talkers"] = "Top lokální Talkers",
    ["top_remote_destinations"] = "Top vzdálené cíle",
    ["traffic_dashboard"] = "Provozní řídicí panel",
  },
  ["db_explorer"] = {
    ["abort"] = "Přerušit",
    ["all"] = "Vše",
    ["app_between_talkers_pairs"] = "Aplikace mezi páry Talkers",
    ["app_flows_between"] = "%{app} aplikační toky mezi %{peer1} a %{peer2}",
    ["app_talkers"] = "%{app} talkers",
    ["app_talkers_with"] = "%{app} talkers s %{peer}",
    ["application_flows"] = "Aplikační toky",
    ["applications_between"] = "Aplikace mezi %{peer1} a %{peer2}",
    ["average_throughput"] = "Avg Thpt",
    ["client_server_breakdown"] = "Rozdělení provozu mezi klientem a serverem",
    ["client_server_host"] = "Host serveru / hostitele",
    ["dns_query"] = "DNS Query",
    ["download_flows"] = "Toky stahování",
    ["download_flows_limit"] = "Maximálně 1000 záznamů.",
    ["empty_query_response"] = "Prázdná odpověď na dotaz (database down or query killed/timed out?)",
    ["extract_pcap"] = "Rozbalit pcap",
    ["filter_bpf"] = "Filtrovat (BPF)",
    ["first_last_seen"] = "Prvně / Posledně Viděn",
    ["flow_peers"] = "Flow Peers",
    ["get_proto_talkers"] = "Získejte Talkers pomocí této aplikace",
    ["historical_data_explorer"] = "Prohlížeč historických dat",
    ["host_name"] = "Název hostitele",
    ["host_talkers"] = "%{host} talkers",
    ["hosts_talking_proto_with"] = "Hostitelé mluvící %{proto} s {host}",
    ["http_host"] = "HTTP Host",
    ["http_method"] = "HTTP Method",
    ["interface_name"] = "Název instance",
    ["last_hour_flows"] = "Toky viděné za poslední hodinu",
    ["ms_client"] = "%{client} ms (client)",
    ["ms_server"] = "%{server} ms (server)",
    ["network_latency_breakdown"] = "Rozdělení latence sítě",
    ["observation_period"] = "Období pozorování",
    ["ok_request_sent"] = "OK, žádost byla odeslána",
    ["packet_rate"] = "Průměrná rychlost paketu",
    ["pcap_requests_and_status"] = "Pcap Žádosti a statusy",
    ["pcaps"] = "Pcaps",
    ["protocol_flows_between"] = "%{proto} aplikační toky mezi %{peer1} a %{peer2}",
    ["protocol_id"] = "ID aplikace",
    ["query_in_progress"] = "Probíhá databázový dotaz, čeká se na obdržení výsledků ...",
    ["request_failed"] = "Požadavek selhal",
    ["response_code"] = "Kód odezvy",
    ["search_flows"] = "Vyhledat Toky",
    ["selected_saved"] = "Vyberte uložené",
    ["server_name"] = "Název serveru",
    ["summary"] = "Souhrn",
    ["talkers_with_this_host"] = "Talkers s tímto hostitelem",
    ["task_id"] = "Id úkolu",
    ["this_flow_has_been_reset"] = "Tento tok byl resetován a pravděpodobně došlo k výpadku serverové aplikace",
    ["this_flow_is_active"] = "Tento tok je aktivní",
    ["this_flow_is_completed"] = "Tento tok je dokončen a brzy vyprší",
    ["top_flows_ipv4"] = "Top IPv4 Flows [%{date_from} - %{date_to}]",
    ["top_flows_ipv6"] = "Top IPv6 Flows [%{date_from} - %{date_to}]",
    ["top_proto_ipv4_flows"] = "Top %{proto} IPv4 toky",
    ["top_proto_ipv6_flows"] = "Top %{proto} IPv6 toky",
    ["total_flows"] = "Celkový počet toků",
    ["total_packets"] = "Celkový počet paketů",
    ["total_traffic"] = "Celkový Počet bajtů",
    ["traffic_rate"] = "Průměrná míra provozu",
    ["traffic_received"] = "Bajty byly přijaty",
    ["traffic_sent"] = "Bajty byly odeslány",
    ["traffic_sent_to_cli"] = "Bajty odeslané klientům",
    ["traffic_sent_to_srv"] = "Bajty odeslané na servery",
    ["traffic_volume"] = "Traffic Volume",
    ["unable_to_find_flow"] = "Zadaný tok nelze najít",
    ["unsave"] = "Odstranit",
    ["vlan_id"] = "VLAN Id",
  },
  ["delete_data"] = {
    ["delete_active_interface_confirmation"] = "Opravdu chcete odstranit všechna trvalá data spojená s %{ifname}?<br><br><b><b></b>:</b> Mazání dat bude provedeno %{product} za restart. Restartujte %{product} aby bylo vymazání účinné.",
    ["delete_active_interface_data_failed"] = "Nelze smazat aktivní data rozhraní.",
    ["delete_active_interface_data_ok"] = "Data pro %{ifname} byly úspěšně označeny k odstranění. Restartujte %{product} aby bylo vymazání účinné.",
    ["delete_confirmation"] = "Opravdu chcete odstranit všechna trvalá data pro %{host}?",
    ["delete_failed"] = "Nelze odstranit data pro %{host}.",
    ["delete_inactive_interfaces_confirmation"] = "Následující rozhraní jsou neaktivní: %{interfaces_list}Opravdu chcete odstranit všechna jejich trvalá data?",
    ["delete_inactive_interfaces_data_failed"] = "Nelze smazat neaktivní data rozhraní.",
    ["delete_inactive_interfaces_data_ok"] = "Data pro neaktivní rozhraní byla úspěšně smazána.",
    ["delete_ok"] = "Data pro %{host} byly úspěšně smazány.",
    ["msg_err_invalid_host"] = "Formát zadaného hostitele není rozpoznán.",
    ["msg_err_no_fs_data"] = "Pro zadaného hostitele nebyly nalezeny žádné trvalé údaje.",
    ["msg_err_unable_to_delete_dir"] = "Nelze smazat datový adresář.",
    ["msg_err_unable_to_delete_ts_data"] = "Data časové řady nelze smazat.",
    ["msg_err_unknown"] = "Nastala neznámá chyba.",
    ["node_nindex_flows"] = "VAROVÁNÍ: nIndex je povolen pro výpis toků, informace o historických tokech nebudou smazány.",
    ["note_persistent_data"] = "Všechna trvalá data jsou vymazána. Data zahrnují čítače provozu, časové úseky, toky, upozornění a Redis caches",
  },
  ["details"] = {
    ["additional_mac_address"] = "Additional MAC Address",
    ["address_resolution_protocol"] = "Protokol pro rozlišení adres",
    ["ago"] = "před",
    ["alerts"] = "Upozornění",
    ["arp_replies"] = "ARP Replies",
    ["arp_requests"] = "ARP Requests",
    ["as_client"] = "Jako Klient",
    ["as_server"] = "Jako Server",
    ["device_port"] = "Port zařízení",
    ["device_type"] = "Typ Zařízené",
    ["first_last_seen"] = "Prvně / Posledně Viděn",
    ["first_observed_on"] = "Prvně pozorováno na",
    ["flow_snmp_localization"] = "Flow SNMP Localization",
    ["flows_dropped_by_bridge"] = "Toky blokovány z důvodu provozní politiky",
    ["flows_non_packet_iface"] = "Nedávno aktivní toky / Celkem / Celkem Anomální",
    ["flows_packet_iface"] = "Toky: Aktivní / Celkový / Low Goodput / Anomalus / Port Unreach",
    ["fragments"] = "Fragmenty",
    ["further_host_names_information"] = "Další názvy hostitele",
    ["goodput"] = "Goodput",
    ["host_pool"] = "Hostitelský fond",
    ["host_purged"] = "Tento host již není aktivní a měl by být vyčištěn z paměti",
    ["host_snmp_localization"] = "SNMP Localization",
    ["input_device_port"] = "Vstupní port zařízení",
    ["keep_alive"] = "KeepAlive",
    ["label_blacklisted_host"] = "Na černé listině",
    ["label_local_host"] = "Lokální",
    ["label_private_ip"] = "Soukromý",
    ["label_remote"] = "Vzdálený",
    ["label_system_ip"] = "IP Systému",
    ["lost"] = "Ztracen",
    ["misbehaving_flows_reasons"] = "Důvody neobvyklých toků",
    ["note"] = "POZNÁMKA",
    ["note_hosts_located_snmp_device"] = "Hostitelé se nacházejí v zařízeních SNMP pomocí <A HREF=%{url}>Bridge MIB</A>.",
    ["out_of_order"] = "Mimo provoz",
    ["output_device_port"] = "Výstupní port zařízení",
    ["peers"] = "Peers: Aktivní",
    ["rcvd"] = "Rcvd",
    ["retransmissions"] = "Retransmissions",
    ["router_access_point_mac_address"] = "(Směrovač / AccessPoint) MAC adresa",
    ["sent_vs_received_traffic_breakdown"] = "Odesláné vs Přijaté rozdělení provozu",
    ["show_hosts"] = "Zobrazit hostitelé",
    ["source"] = "Zdroj",
    ["source_id"] = "ID Zdroje",
    ["tcp_packets_sent_analysis"] = "Analýza odeslaných paketů TCP",
    ["total_traffic"] = "Celkový provoz",
    ["traffic_sent_received"] = "Provoz odeslán / přijat",
    ["vlan_id"] = "VLAN ID",
    ["whois_lookup"] = "Whois Lookup",
  },
  ["device_protocols"] = {
    ["alert"] = "Spustit upozornění",
    ["alerts_disabled_msg"] = "Konfigurované aplikace zařízení se používají pouze ke generování výstrah aplikací zařízení, když zařízení provozuje určité aplikace, které nemá používat. Nezapomeňte povolit tato upozornění z <A HREF=\"%{url}\"><i class=\"fas fa-flask\"></i> Preferencí</A>.",
    ["device_protocol_policy"] = "Politika aplikace zařízení",
    ["device_protocols"] = "Aplikace zařízení",
    ["devtype_as_proto_client"] = "%{devtype} jako <i>%{proto}</i> klient",
    ["devtype_as_proto_server"] = "%{devtype} jako <i>%{proto}</i> server",
    ["filter_device_protocols"] = "%{filter} Aplikace zařízení",
    ["ok"] = "Přijatelný",
  },
  ["device_types"] = {
    ["iot"] = "IoT",
    ["laptop"] = "Laptop",
    ["multimedia"] = "Multimédia",
    ["nas"] = "NAS",
    ["networking"] = "Router/Switch",
    ["phone"] = "Mobil",
    ["printer"] = "Tiskárna",
    ["tablet"] = "Tablet",
    ["tv"] = "TV",
    ["unknown"] = "Neznámý",
    ["video"] = "Video",
    ["wifi"] = "Bezdrátová Síť",
    ["workstation"] = "Počítač",
  },
  ["dhcp"] = {
    ["delete_range"] = "Odstranit rozsah DHCP",
    ["delete_range_confirm"] = "Opravdu chcete smazat nakonfigurovaný rozsah DHCP %{range} ?",
    ["dhcp_alert_note"] = "Upozornění bude generováno, pokud je IP adresa přiřazena mimo nakonfigurované rozsahy DHCP.",
    ["dhcp_configuration_note"] = "Na této stránce jsou uvedeny konfigurované rozsahy DHCP pro toto rozhraní. Ty by se měly shodovat se skutečnou používanou konfigurací serveru DHCP",
    ["invalid_ip_address"] = "Neplatná adresa IP",
    ["no_dhcp_ranges"] = "Nejsou nakonfigurovány žádné rozsahy DHCP.",
  },
  ["discover"] = {
    ["device"] = "Zařízení",
    ["discovered_devices"] = "Objevil %{manuf} %{sys} %{dev} zařízení",
    ["err_unable_to_arp_discovery"] = "Nelze spustit vyhledávání sítě ARPN",
    ["error_no_discovery_cached"] = "Zatím nebyla uložena žádná data zjišťování.",
    ["error_unable_to_decode_json"] = "Nelze dekódovat mezipaměť JSON discovery data.",
    ["ghost_icon_descr"] = "%{ghost_icon}ikona upozorňuje na Ghost Hosts (tj. nepatří do sítě IP adres rozhraní)",
    ["network_discovery"] = "Vyhledávání Sítě",
    ["network_discovery_datetime"] = "Poslední Vyhlédávání Sítě",
    ["network_discovery_not_enabled"] = "Probíhá vyhledávání sítě",
  },
  ["dns_page"] = {
    ["dns_breakdown"] = "DNS Breakdown",
    ["dns_query_sent_distribution"] = "DNS Query Sent Distribution",
    ["error_replies"] = "Odpovědi na chyby",
    ["note"] = "POZNÁMKA",
    ["note_dns_ratio"] = "V ideálním případě by poměr DNS mezi žádostí a odpovědí měl být 1 (jedna odpověď na žádost). Pokud jsou mnohem nižší, pak stojí za to prozkoumat problémy, protože to znamená, že počet obdržených odpovědí je mnohem nižší, než se očekávalo, a to může znamenat, že používáme neodpovídající DNS překládače nebo že jsou nesprávně nakonfigurováni (např. Byly přesunuty do další IP).",
    ["positive_replies"] = "Pozitivní odpovědi",
    ["queries"] = "Dotazy",
    ["ratio"] = "Poměr",
    ["rcvd"] = "Rcvd",
    ["replies"] = "Odpovědi",
    ["reply_breakdown"] = "Reply Breakdown",
    ["request_vs_reply"] = "Žádost vs Odpověď Pom",
  },
  ["entity_thresholds"] = {
    ["flow_attacker_description"] = "Spustit upozornění, když nový klient překročí prahovou hodnotu toků/s prahovou hodnotu",
    ["flow_attacker_title"] = "Flow Flood Attacker Alert",
    ["flow_victim_description"] = "Spustit upozornění, když nový server překročí prahovou hodnotu toků/s překročí",
    ["flow_victim_title"] = "Flow Flood Victim Alert",
    ["request_reply_ratio_description"] = "Spustit výstrahu, když počet odpovědí vs. požadavků (v různých aplikacích) překročí prahovou hodnotu",
    ["request_reply_ratio_title"] = "Poměr odpovědí / požadavků",
    ["syn_attacker_description"] = "Spustit výstrahu, když počet odeslaných SYN/s překročí prahovou hodnotu",
    ["syn_attacker_title"] = "SYN Flood Attacker Alert",
    ["syn_scan_attacker_description"] = "Spustit upozornění, když počet odeslaných SYN/min (bez odpovědi) překročí prahovou hodnotu",
    ["syn_scan_attacker_title"] = "SYN Scan Attacker Alert",
    ["syn_scan_victim_description"] = "Spustit upozornění, když počet přijatých SYN/min (bez odpovědi) překročí prahovou hodnotu",
    ["syn_scan_victim_title"] = "SYN Scan Victim Alert",
    ["syn_victim_description"] = "Spustit upozornění, když počet přijatých SYN / s překročí prahovou hodnotu",
    ["syn_victim_title"] = "SYN Flood Victim Alert",
  },
  ["event_exporters"] = {
    ["event_device_x"] = "Event Exporter %{device}",
    ["event_exporter_ip"] = "Event Exporter IP",
    ["event_exporters"] = "Event Exporters",
  },
  ["export_data"] = {
    ["export_json_data"] = "Export JSON Data",
    ["note_active_hosts"] = "Vrací se pouze aktivní hostitel=.",
    ["note_maximum_number"] = "Maximální počet hostitelů ke stažení je 32 768.",
  },
  ["external_stats"] = {
    ["capture_drops"] = "Dropped Packets",
    ["capture_packets"] = "Captured Packets",
    ["signatures_failed"] = "Signatures Failed",
    ["signatures_loaded"] = "Signatures Loaded",
    ["suricata_statistics"] = "Statistiky Suricata",
    ["title"] = "Externí statistika",
  },
  ["field_units"] = {
    ["bytes"] = "Bajty",
    ["flow_sec"] = "Toků/s",
    ["flows"] = "Toků",
    ["hosts"] = "hostitelé",
    ["mbits"] = "Mbps",
    ["packets"] = "pakety",
    ["percentage"] = "%%",
    ["seconds"] = "sekundy",
    ["syn_min"] = "SYNs/min",
    ["syn_sec"] = "SYNs/s",
  },
  ["flow_alerts_explorer"] = {
    ["by_target_port"] = "Podle cílového portu",
    ["flow_alert_origin"] = "Původ upozorněné",
    ["flow_alert_target"] = "Cíl upozornění",
    ["label"] = "Průzkumník upozornění toku",
    ["origins"] = "Původy",
    ["search"] = "Vyhledávání výstrahy toku",
    ["summary_cli2srv"] = "Celkový původ do cílového provozu",
    ["summary_n_origins"] = "Celkový původ",
    ["summary_n_targets"] = "Celkové cíle",
    ["summary_srv2cli"] = "Celkový cíl na původní provoz",
    ["summary_total"] = "Upozornění na celkový průtok",
    ["targets"] = "Cíle",
    ["type_alerts_by_type"] = "Upozornění toku podle typu",
    ["type_explorer"] = "Zadejte Průzkumník",
    ["visual_explorer"] = "Visual Explorer",
  },
  ["flow_checks"] = {
    ["application_detected"] = "Aplikace byla detekována",
    ["callback"] = "Flow Callback",
    ["callback_config"] = "Konfigurace",
    ["callback_elapsed_time"] = "Execution Time",
    ["callback_elapsed_time_avg"] = "Průtok/s",
    ["callback_enabled"] = "Povoleno",
    ["callback_function"] = "Funkce",
    ["callback_function_duration"] = "Doba trvání",
    ["callback_function_duration_fmt_long"] = "%{num_calls} volá %{time} [%{speed} Hovorů/s]",
    ["callback_function_duration_fmt_short"] = "%{time}",
    ["callback_function_duration_simple_view"] = "Latest Run",
    ["callback_function_num_flows"] = "Toky",
    ["callback_function_throughput"] = "Rychlost zpracování",
    ["callback_latest_run"] = "Latest Run",
    ["idle"] = "Nečinný",
    ["no_callbacks_defined"] = "Nebyla nalezena žádná zpětná volání",
    ["note_add_custom_scripts"] = "%{product} hledá v nich vlastní skripty <a href=\"%{url}\"> <i class=\"fas fa-folder\"></i> adresáře</a>.",
    ["note_create_custom_scripts"] = "Dokumentace k vytvoření vlastních skriptů pro provádění zpětných volání je k dispozici zde <a class='ntopng-external-link' href=\"%{url}\">link <i class=\"fas fa-external-link-alt\"></i></a>.",
    ["note_flow_application_detected"] = "\"Application Detected\" zpětná volání jsou prováděna ihned po detekci aplikace. K tomu dochází v prvních 12 paketech toku pro rozhraní paketů nebo bezprostředně po přijetí toku pro rozhraní ZMQ.",
    ["note_flow_idle"] = "\"Nečinnný\" zpětná volání jsou prováděna, když tok ukončil svou činnost a je nečinný.",
    ["note_flow_lifecycle"] = "Zpětná volání jsou prováděna v určitých okamžicích životního cyklu toku.",
    ["note_flow_periodic_update"] = "\"Periodická aktualizace\" zpětná volání jsou prováděna pravidelně poté, co byl tok aktivní déle než pět minut.",
    ["note_flow_staus_changed"] = "\"Stav změněn\" zpětná volání jsou prováděna pokaždé, když dojde ke změně stavu v toku. Například když se objeví problémy s připojením, jako jsou opakované přenosy.",
    ["notes"] = "POZNÁMKY",
    ["periodic_update"] = "Pravidelná aktualizace",
    ["status_changed"] = "Stav změněn",
  },
  ["flow_checks_config"] = {
    ["blacklisted"] = "Tok na černé listině",
    ["blacklisted_description"] = "Pokud je na seznamu zakázaných alespoň jeden mezi klientem a serverem, aktivujte upozornění",
    ["no_input"] = "Není nutná žádná konfigurace",
    ["score"] = "Skóre toku",
    ["suspicious_countries"] = "Podezřelé země / Státy",
    ["suspicious_countries_description"] = "Spustit upozornění, když alespoň jeden z klientů a serverů je z podezřelé země",
    ["udp_unidirectional"] = "Jednosměrný tok UDP",
    ["udp_unidirectional_description"] = "Spustit výstrahu, když je detekován jednosměrný tok UDP",
  },
  ["flow_details"] = {
    ["acceptable_label"] = "Přijatelný",
    ["actual_peak_throughput"] = "Skutečná / maximální propustnost",
    ["additional_alert_type"] = "Další stav toku",
    ["additional_flow_elements"] = "Další prvky toku",
    ["alert_type"] = "Stav toku",
    ["application_latency"] = "Latence aplikace",
    ["average_cpu_load"] = "Průměrné zatížení CPU",
    ["bittorrent_hash"] = "BitTorrent hash",
    ["blacklisted_flow"] = "Klient, server nebo doména jsou na černé listině",
    ["blacklisted_flow_detailed"] = "Černá listina %{who}",
    ["c_ip_addresses"] = "C IP Addresses",
    ["call_canceled"] = "Hovor byl zrušen",
    ["call_completed"] = "Hovor byl dokončen",
    ["call_error"] = "Chyba volání",
    ["call_id"] = "Call-ID",
    ["call_initiator"] = "Zavolejte Iniciátor",
    ["call_quality_indicators"] = "Indikátory kvality hovorů",
    ["call_started"] = "Hovor byl zahájen",
    ["call_state"] = "Call State",
    ["called_party"] = "Called Party",
    ["cancel_bye_failure_reason_cause"] = "Cancel/Bye/Failure Reason Cause",
    ["certificates_not_match"] = "Certifikáty se neshodují",
    ["client_container_information"] = "Client Container Information",
    ["client_process_information"] = "Informace o procesu klienta",
    ["client_requested"] = "Vyžádán klient",
    ["computed_as_tcp_window_size_rtt"] = "Computed as TCP Window Size / RTT",
    ["container_id"] = "Container ID",
    ["could_not_add_host_to_category"] = "Nepodařilo se přidat hostitele \"%{host}\" do \"%{category}\".",
    ["data_exfiltration"] = "Exfiltrace dat",
    ["desirable_label"] = "Žádoucí",
    ["dns_invalid_query"] = "Neplatný dotaz DNS",
    ["dns_query"] = "Dotaz DNS",
    ["docker"] = "Dotaz DNS",
    ["docker_name"] = "Název",
    ["drop_flow_traffic_btn"] = "Drop Flow Traffic",
    ["dropped_packets"] = "Dropped Packets",
    ["dtmf_tones_sent"] = "Tóny DTMF odeslané během hovoru",
    ["dump_flow_traffic"] = "Dump Flow Traffic",
    ["elephant_exceeded"] = "Překračuje %{vol}",
    ["elephant_flow"] = "Elephant Flow",
    ["elephant_flow_descr"] = "Elephant toky, které přenášejí více než určité nakonfigurované množství dat. Správci mohou nakonfigurovat toky Elephant z předvoleb.",
    ["elephant_flow_l2r"] = "Elephant Flow (Lokální do vzdálených)",
    ["elephant_flow_r2l"] = "Elephant Flow (Vzdálené do lokálních)",
    ["existing_rules_note"] = "Stávající pravidla lze nalézt na <a href=\"%{url}\">%{name}</a> stránce.",
    ["external_alert"] = "Detekováno %{scope} upozornění: %{msg} [%{maker}]",
    ["first_last_flow_sequence"] = "První / poslední sekvence toku",
    ["flow_active_msg"] = "Tok je aktivní.",
    ["flow_alerted"] = "Tok byl upozorněn",
    ["flow_blocked_by_bridge"] = "Tok byl blokován kvůli nakonfigurovaným politikám",
    ["flow_cannot_be_found_message"] = "Tento tok nelze nalézt.",
    ["flow_completed_msg"] = "Tok je uzavřen.",
    ["flow_connecting_msg"] = "Tok se připojuje.",
    ["flow_details"] = "Podrobnosti o toku",
    ["flow_emitted"] = "Tok byl emitován, když bylo upozorněno síťové rozhraní",
    ["flow_marker"] = "Značka toku",
    ["flow_peer_roles_inaccurate_msg"] = "Tok je aktivní, ale začátek toku nebyl viděn a peer roles (klient / server) mohou být nepřesné.",
    ["flow_peers_client_server"] = "Flow Peers [Klient / Server]",
    ["flow_quota"] = "Kvóta toku",
    ["flow_reset_by_resetter_msg"] = "Resetování toku pomocí %{resetter}.",
    ["flow_reset_msg"] = "Tento tok byl resetován",
    ["flow_score"] = "Skóre toku",
    ["flow_shapers"] = "Flow Shapers",
    ["flow_traffic_is_dropped"] = "Tok provozu je přerušen",
    ["forward"] = "Vpřed",
    ["gsm_cell_identifier"] = "GSM Cell Identifier",
    ["gsm_cell_lac"] = "GSM Cell LAC (Location Area Code)",
    ["host_successfully_added_to_category"] = "Host \"%{host}\" úspěšně přidán do <a href=\"%{url}\">%{category}</a> kategorie. Pravidlo bude mít vliv pouze na nové toky.",
    ["http_method"] = "HTTP Method",
    ["icmp_info"] = "ICMP Info",
    ["ids_alert"] = "Detekováno %{scope} upozornění: %{msg} [%{maker}]",
    ["imsi"] = "IMSI (International mobile Subscriber Identity)",
    ["io_wait_time_percentage"] = "Procento čekací doby I / O",
    ["ip_packet_analysis"] = "Analýza paketů IP",
    ["jitter"] = "Jitter",
    ["k8s"] = "Kubernetes",
    ["k8s_name"] = "Název",
    ["k8s_ns"] = "Namespace",
    ["k8s_pod"] = "Pod",
    ["longlived_exceeded"] = "Překračuje %{amount}",
    ["longlived_flow"] = "Dlouhoživotní tok",
    ["longlived_flow_descr"] = "Dlouhoživvotné toky jsou takové, které vydrží více než určité nakonfigurované množství času. Správci mohou nakonfigurovat toky Elephant z předvoleb.",
    ["looks_like_idle_flow_message"] = "Vypadá to jako<font color=red>nečinný tok</font> s periodickými přenosy, jen aby to zůstalo naživu.",
    ["lost_packets"] = "Ztracené pakety",
    ["low_goodput"] = "\9Low Goodput",
    ["malicious_ja3_signature"] = "Možná škodlivé %{cli_or_srv} Signature [JA3: <a href=\"%{url}\">%{signature}</a> %{icon}]",
    ["max_estimated_tcp_throughput"] = "Maximální (odhadovaná) propustnost TCP",
    ["max_packet_interarrival_time"] = "Maximální doba vzájemného příjmu paketů",
    ["memory_actual_peak"] = "Aktuální paměť / vrchol",
    ["mibehaving_flows"] = "Nesprávné toky",
    ["normal"] = "Normalní",
    ["not_recommended_label"] = "Nedoporučeno",
    ["now_purged"] = "Tento tok již není aktivní a měl by být vyčištěn z paměti.",
    ["nsapi"] = "NSAPI",
    ["ongoing_call"] = "Probíhající hovor",
    ["packet_inter_arrival_time"] = "Čas mezi příletem paketu <br>[ Minimum / Průměr / Maximální ]",
    ["payload_type"] = "Typ užitečného zatížení",
    ["potentially_dangerous_protocol"] = "Potenciálně nebezpečný protokol",
    ["process_information_report_warning"] = "Zpráva s informacemi o procesu je omezená, pokud nepoužíváte ntopng <A HREF='%{url}'>nProbe</A> a sprobe plugin",
    ["process_pid_name"] = "Process PID/Name",
    ["profile_name"] = "Jméno profilu",
    ["pseudo_mos"] = "(Pseudo) MOS",
    ["r_factor"] = "R-Factor",
    ["reach_connection_label"] = "Dosah připojení",
    ["remote_to_remote"] = "Vzdálený klient a vzdálený server",
    ["response_code"] = "Kód odezvy",
    ["reverse"] = "Obrátit",
    ["round_trip_time"] = "Doba zpáteční cesty",
    ["rtp_codecs"] = "RTP Codecs",
    ["rtp_flow"] = "RTP Flow",
    ["rtp_protocol_information"] = "RTP Protocol Information",
    ["rtp_stream_peers"] = "RTP Stream Peers",
    ["rtp_transit_in_out"] = "RTP Transit IN / OUT",
    ["rtt_breakdown"] = "Rozpis doby zpáteční cesty",
    ["rtt_distance"] = "Odhadovaná vzdálenost klient / server",
    ["rule_type"] = "Typ pravidla",
    ["sac_service_area_code"] = "SAC (Service Area Code)",
    ["server_certificate"] = "Cetifikát serveru",
    ["server_container_information"] = "Informace o Container serveru",
    ["server_name"] = "Název serveru",
    ["server_process_information"] = "Informace o procesu serveru",
    ["sip_call_id"] = "SIP Call-ID",
    ["sip_protocol_information"] = "Informace o protokolu SIP",
    ["slow_application_header"] = "Slow Application Header",
    ["slow_data_exchange"] = "Pomalá výměna dat",
    ["slow_tcp_connection"] = "Pomalé připojení TCP",
    ["son_of_father_process"] = "syn od <a href ='%{url}'>%{proc_father_name} [pid: %{proc_father_pid}]</a>",
    ["ssh_signature"] = "SSH Signature",
    ["suspicious_client_device_protocol"] = "Klientská aplikace \"%{proto}\" není konfigurovaným povolena <a href=\"%{url}\">%{devtype} aplikační politikou</a>",
    ["suspicious_device_protocol"] = "Protokol podezřelého zařízení",
    ["suspicious_server_device_protocol"] = "Serverová aplikace \"%{proto}\"není konfigurovaným povolena <a href=\"%{url}\">%{devtype} aplikační politiku</a>",
    ["suspicious_tcp_probing"] = "Podezřelá sonda TCP",
    ["suspicious_tcp_syn_probing"] = "Podezřelá sonda TCP SYN",
    ["sync_source_id"] = "Sync Source ID",
    ["tcp_connection_issues"] = "Problémy s připojením TCP (Opakovaný přenos, OOO, Ztraceno)",
    ["tcp_connection_refused"] = "TCP spojení odmítnuto",
    ["tcp_packet_analysis"] = "Analýza paketů TCP",
    ["tcp_severe_connection_issues"] = "Závažné problémy s připojením TCP (Opakovaný přenos, OOO, Ztraceno)",
    ["throughput_trend"] = "Trend propustnosti",
    ["tls_certificate"] = "TLS Certificate",
    ["tls_certificate_mismatch"] = "Neshoda certifikátu TLS",
    ["tls_client_certificate"] = "Klientský certifikát",
    ["tls_old_protocol_version"] = "Zastaralá verze protokolu TLS",
    ["tls_server_certificate"] = "Certifikát serveru",
    ["tls_unsafe_ciphers"] = "Nebezpečné šifrovače TLS",
    ["udp_unidirectional"] = "Jednosměrný provoz UDP",
    ["unknown_status"] = "Neznámý stav (%{status})",
    ["url"] = "URL",
    ["user_name"] = "Uživatelské jméno",
    ["vm_page_faults"] = "VM Page Faults",
    ["web_mining_detected"] = "Web je známý pro těžbu kryptoměn na klientských zařízeních",
  },
  ["flow_devices"] = {
    ["active_sflow"] = "Aktivní sFlow zařízení",
    ["all_device_ports"] = "Všechny %{device} porty",
    ["all_flow_devices"] = "Všechna toková zařízení",
    ["all_sflow_devices"] = "Všechna zařízení sFlow",
    ["duplex"] = "Duplex",
    ["flow_device_x"] = "Tokové zařízení %{device}",
    ["full_duplex"] = "Full-Duplex",
    ["half_duplex"] = "Half-Duplex",
    ["in_errors"] = "V chybách",
    ["note_condition_1"] = "Zařízení %{device} musí podporovat SNMP a musí být nakonfigurováno v <a href=\"%{url}\">SNMP</a> stránce zařízení",
    ["note_condition_2"] = "Časové časy SNMP a tokových zařízení musí být povoleny od <A HREF=\"%{url}\"><i class=\"fas fa-flask\"></i> Preferences</A> (Expert View)",
    ["note_zmq_fields1"] = "Toková zařízení jsou určena pomocí ZMQ polí %%EXPORTER_IPV4_ADDRESS and %%NPROBE_IPV4_ADDRESS. Pokud jsou k dispozici obě pole, první má přednost před druhým.",
    ["note_zmq_fields2"] = "Rozhraní průtokových zařízení jsou určena pomocí ZMQ polí %%INPUT_SNMP and %%OUTPUT_SNMP",
    ["note_zmq_fields3"] = "sFlow zařízení jsou určena pomocí sFlow field deviceIP přijatých přes ZMQ (téma 'counter')",
    ["note_zmq_fields4"] = "Rozhraní zařízení sFlow jsou určena pomocí pole ifIndex přijatého přes ZMQ (téma 'counter')",
    ["out_errors"] = "Chyby",
    ["exporter_devices"] = "Zařízení pro exportér toku",
    ["exporter_ip"] = "Exporter IP",
    ["exporters"] = "Exporters",
    ["promisc"] = "Promisc",
    ["sflow_device_x"] = "sFlow Probe %{device}",
    ["sflow_snmp_ratio"] = "Počítadla / poměr SNMP",
    ["sflow_snmp_ratio_descr"] = "Poměr čítačů / SNMP se vypočítá vydělením celkového provozu rozhraní získaného pomocí vzorků čítačů sFlow a celkového provozu stejného rozhraní načteného prostřednictvím SNMP.",
    ["snmp_description"] = "SNMP Description",
    ["snmp_devmodel"] = "SNMP Device Model",
    ["snmp_devname"] = "SNMP Device Name",
    ["snmp_location"] = "SNMP Location",
    ["snmp_ratio"] = "Flow/SNMP Ratio",
    ["snmp_ratio_descr"] = "Poměr toku / SNMP se vypočítá dělením celkového provozu rozhraní získaného pomocí toků celkovým provozem stejného rozhraní načteného prostřednictvím SNMP. Protože v analýze založené na průtoku nejsou účtovány záhlaví non-IP a vrstvy 2, <br> typické hodnoty poměrů jsou v rozsahu 0,8, 0,0,9 (tj. 0,9 znamená, že bylo hlášeno 90 %% přijatého provozu pozorovaného prostřednictvím protokolu SNMP) v tokech). <br> Poměr se počítá každou hodinu, pouze pokud jsou splněny následující podmínky",
    ["this_page_contains_couters"] = "Tato stránka obsahuje čítače rozhraní, které byly získány pomocí sFlow. Pokud je nakonfigurován SNMP, můžete také vidět <A HREF=\"%{url}\">zobrazení SNMP</A> tohoto zařízení",
    ["timeseries_descr"] = "Časové toky zařízení toku lze aktivovat z <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preference</a>.K zobrazení prvních datových bodů je třeba jen pár minut",
  },
  ["flow_fields_description"] = {
    ["appl_latency_ms"] = "Latence aplikace (msec), a.k.a. doba odezvy serveru",
    ["application_id"] = "ID shromážděné aplikace (Cisco nebo IXIA)",
    ["application_name"] = "Palo Alto App-Id",
    ["biflow_direction"] = "1=initiator, 2=reverseInitiator",
    ["bittorrent_hash"] = "BITTORRENT hash",
    ["client_nw_latency_ms"] = "Network RTT/2 client <-> nprobe (msec)",
    ["community_id"] = "ID komunity",
    ["cumulative_icmp_type"] = "Kumulativní NEBO paketů typu ICMP",
    ["dhcp_client_ip"] = "Adresa IPv4 klienta DHCP",
    ["dhcp_client_mac"] = "MAC klienta DHCP",
    ["dhcp_client_name"] = "Název klienta DHCP",
    ["dhcp_message_type"] = "Typ zprávy DHCP",
    ["dhcp_remote_id"] = "ID vzdáleného agenta DHCP",
    ["dhcp_subscriber_id"] = "ID předplatitele DHCP",
    ["diameter_clr_cancel_type"] = "DIAMETER Cancellation Type",
    ["diameter_clr_flags"] = "DIAMETER CLR Flags",
    ["diameter_exp_res_result_code"] = "DIAMETER Response Experimental Result Code",
    ["diameter_exp_res_vendor_id"] = "Kód experimentu výsledku experimentu DIAMETER",
    ["diameter_hop_by_hop_id"] = "DIAMETER Hop by Hop Identifier",
    ["diameter_req_msg_type"] = "DIAMETER Typ požadavku Msg",
    ["diameter_req_origin_host"] = "DIAMETER Žádost o host původu",
    ["diameter_req_user_name"] = "DIAMETER Vyžádat uživatelské jméno",
    ["diameter_rsp_msg_type"] = "Typ odpovědi na zprávu DIAMETER",
    ["diameter_rsp_origin_host"] = "DIAMETER Původ Host odpověď",
    ["diameter_rsp_result_code"] = "Kód výsledku odpovědi DIAMETER",
    ["direction"] = "Směr toku [0=src->dst, 1=dst->src]",
    ["dns_num_answers"] = "DNS#počet vrácených odpovědí",
    ["dns_query"] = "DNS dotaz",
    ["dns_query_id"] = "ID transakce dotazů DNS",
    ["dns_query_type"] = "Typ dotazu DNS (např. 1 = A, 2 = NS ..)",
    ["dns_response"] = "Odpovědi (s) DNS “",
    ["dns_ret_code"] = "Návratový kód DNS (např. 0 = žádná chyba)",
    ["dns_ttl_answer"] = "TTL prvního záznamu A (pokud existuje)",
    ["dns_tx_id"] = "DNS Transaction ID",
    ["dot1q_dst_vlan"] = "Cílová VLAN (vnější VLAN v QinQ)",
    ["dot1q_src_vlan"] = "Zdroj VLAN (vnější VLAN v QinQ)",
    ["downstream_session_id"] = "Identifikátor následné relace (např. L2TP) nebo 0, pokud není znám",
    ["downstream_tunnel_id"] = "Identifikátor downstream tunelu (např. GTP TEID, VXLAN VNI) nebo 0, pokud není znám",
    ["dst_as"] = "Cílová BGP AS",
    ["dst_as_map"] = "Název organizace pro DST_AS",
    ["dst_as_path_1"] = "Dest AS path position 1",
    ["dst_as_path_10"] = "Dest AS path position 10",
    ["dst_as_path_2"] = "Dest AS path position 2",
    ["dst_as_path_3"] = "Dest AS path position 3",
    ["dst_as_path_4"] = "Dest AS path position 4",
    ["dst_as_path_5"] = "Dest AS path position 5",
    ["dst_as_path_6"] = "Dest AS path position 6",
    ["dst_as_path_7"] = "Dest AS path position 7",
    ["dst_as_path_8"] = "Dest AS path position 8",
    ["dst_as_path_9"] = "Dest AS path position 9",
    ["dst_father_proc_name"] = "Dst father process name",
    ["dst_father_proc_pid"] = "Dst father process PID",
    ["dst_fragments"] = "Num fragmentované pakety dst-> src",
    ["dst_ip_city"] = "Město, kde se nachází IP adresa dst",
    ["dst_ip_country"] = "Země / Stát, kde se nachází IP adresa dst",
    ["dst_ip_lat"] = "Zeměpisná šířka, kde se nachází IP adresa dst",
    ["dst_ip_long"] = "Zeměpisná délka, kde se nachází IP adresa dst",
    ["dst_proc_actual_memory"] = "Dst zpracovává skutečnou paměť (bajty)",
    ["dst_proc_average_cpu_load"] = "Průměrné zatížení procesu Dst (%% * 100)",
    ["dst_proc_name"] = "Název procesu DST",
    ["dst_proc_num_page_faults"] = "Dst process num pagefaults",
    ["dst_proc_pctg_iowait"] = "Src process iowait time %% (%% * 100)",
    ["dst_proc_peak_memory"] = "Top paměť procesu Dst (bajty)",
    ["dst_proc_pid"] = "Dst process PID",
    ["dst_proc_uid"] = "Dst process UID",
    ["dst_proc_user_name"] = "Uživatelské jméno procesu DST",
    ["dst_to_src_avg_throughput"] = "Dst to src average thpt (bps)",
    ["dst_to_src_max_throughput"] = "Dst to src max thpt (bps)",
    ["dst_to_src_min_throughput"] = "Dst to src min thpt (bps)",
    ["dst_tos"] = "TOS/DSCP (dst->src)",
    ["dst_vlan"] = "Cílová VLAN (vnitřní VLAN v QinQ)",
    ["duration_in"] = "Trvání proudu mezi klientem a serverem (msec)",
    ["duration_out"] = "Trvání proudu mezi klientem a serverem (msec)",
    ["engine_id"] = "Id engine s přepínáním průtoku",
    ["engine_type"] = "Proudový spínací engine",
    ["file_gaps"] = "Mezery v souborech",
    ["file_name"] = "Název souboru",
    ["file_size"] = "Velikost souboru",
    ["file_state"] = "Stav souboru",
    ["file_stored"] = "Soubor byl uložen",
    ["firewall_event"] = "Firewall Event 0 = ignorovat, 1 = vytvořený tok, 2 = tok vymazán, 3 = tok odmítnut, 4 = upozornění na tok, 5 = aktualizace toku",
    ["first_switched"] = "SysUptime (msec) prvního toku pkt",
    ["flow_active_timeout"] = "Časový limit aktivity položek vyrovnávací paměti toku",
    ["flow_duration_microseconds"] = "Trvání toku (usec)",
    ["flow_duration_milliseconds"] = "Trvání toku (msec)",
    ["flow_end_microseconds"] = "uSec (epocha) prvního toku paketu",
    ["flow_end_milliseconds"] = "Msec (epocha) posledního toku paketu",
    ["flow_end_reason"] = "Důvod ukončení toku",
    ["flow_end_sec"] = "Sekundy (epocha) posledního toku paketu",
    ["flow_id"] = "Identifikátor sériového toku",
    ["flow_inactive_timeout"] = "Časový limit nečinnosti položek mezipaměti toku",
    ["flow_proto_port"] = "Port L7, který identifikuje aplikaci toku, nebo 0, pokud není znám",
    ["flow_server_name"] = "Název serveru toku (pokud je znám)",
    ["flow_start_microseconds"] = "uSec (epocha) prvního toku paketu",
    ["flow_start_milliseconds"] = "Msec (epocha) prvního toku paketu",
    ["flow_start_sec"] = "Sekundy (epocha) prvního toku paketu",
    ["flow_user_name"] = "Uživatelské jméno toku tunelu (pokud je znám)",
    ["frame_length"] = "Původní délka framu L2",
    ["ftp_command"] = "Příkaz FTP klienta",
    ["ftp_command_ret_code"] = "Návratový kód příkazu FTP klienta",
    ["ftp_login"] = "Přihlášení klienta FTP",
    ["ftp_password"] = "Heslo klienta FTP",
    ["gtpv0_apn_name"] = "GTPv0 APN Name",
    ["gtpv0_end_user_ip"] = "IP adresa koncového uživatele GTPv0",
    ["gtpv0_end_user_msisdn"] = "Koncový uživatel GTPv0 MSISDN",
    ["gtpv0_rai_cell_lac"] = "GTPv0 Kód umístění buňky",
    ["gtpv0_rai_cell_rac"] = "Kód oblasti směrování buněk GTPv0",
    ["gtpv0_rai_mcc"] = "Mobilní kód země GTPv0",
    ["gtpv0_rai_mnc"] = "GTPv0 kód mobilní sítě",
    ["gtpv0_req_msg_type"] = "Typ požadavku zprávy GTPv0",
    ["gtpv0_response_cause"] = "GTPv0 Příčina operace",
    ["gtpv0_rsp_msg_type"] = "Typ zprávy GTPv0 s odpovědí",
    ["gtpv0_tid"] = "Identifikátor tunelu GTPv0",
    ["gtpv1_apn_name"] = "GTPv1 APN Name",
    ["gtpv1_c2s_teid_ctrl"] = "Klient GTPv1-> Řízení serveru TunnelId",
    ["gtpv1_c2s_teid_data"] = "Klient GTPv1-> Data serveru TunnelId",
    ["gtpv1_end_user_imei"] = "IMEI koncového uživatele GTPv1",
    ["gtpv1_end_user_imsi"] = "IMSI koncového uživatele GTPv1",
    ["gtpv1_end_user_ip"] = "IP adresa koncového uživatele GTPv1",
    ["gtpv1_end_user_msisdn"] = "Koncový uživatel GTPv1 MSISDN",
    ["gtpv1_rai_lac"] = "Kód oblasti umístění GTPv1 RAI",
    ["gtpv1_rai_mcc"] = "Mobilní kód země GTPv1 RAI",
    ["gtpv1_rai_mnc"] = "Kód mobilní sítě GTPv1 RAI",
    ["gtpv1_rai_rac"] = "Směrovací oblast GTPv1 RAI",
    ["gtpv1_rat_type"] = "Typ GTPv1 RAT",
    ["gtpv1_req_msg_type"] = "Typ požadavku GTPv1",
    ["gtpv1_response_cause"] = "GTPv1 Příčina operace",
    ["gtpv1_rsp_msg_type"] = "Typ požadavku GTPv1",
    ["gtpv1_s2c_teid_ctrl"] = "GTPv1 Server-> Řízení klientských tunelů",
    ["gtpv1_s2c_teid_data"] = "GTPv1 Server-> Data klienta TunnelId",
    ["gtpv1_uli_cell_ci"] = "GTPv1 ULI Cell CI",
    ["gtpv1_uli_cell_lac"] = "Kód oblasti umístění buňky ULI GTPv1",
    ["gtpv1_uli_mcc"] = "GTPv1 ULI mobilní kód země",
    ["gtpv1_uli_mnc"] = "Kód mobilní sítě ULI GTPv1",
    ["gtpv1_uli_sac"] = "GTPv1 ULI SAC",
    ["gtpv2_apn_name"] = "GTPv2 APN Name",
    ["gtpv2_c2s_s1u_gtpu_ip"] = "Klient GTPv2-> Svr S1U GTPU IP",
    ["gtpv2_c2s_s1u_gtpu_teid"] = "Klient GTPv2-> Svr S1U GTPU TEID",
    ["gtpv2_c2s_s5_s8_gtpc_ip"] = "Klient GTPv2-> Svr S5 / S8 GTPC IP",
    ["gtpv2_c2s_s5_s8_gtpu_ip"] = "Klient GTPv2-> Srv S5 / S8 PGW GTPU IP",
    ["gtpv2_c2s_s5_s8_gtpu_teid"] = "Klient GTPv2-> Srv S5 / S8 PGW GTPU TEID",
    ["gtpv2_c2s_s5_s8_sgw_gtpu_ip"] = "Klient GTPv2-> Srv S5 / S8 SGW GTPU IP",
    ["gtpv2_c2s_s5_s8_sgw_gtpu_teid"] = "Klient GTPv2-> Srv S5 / S8 SGW GTPU TEID",
    ["gtpv2_end_user_imei"] = "IMEI koncového uživatele GTPv2",
    ["gtpv2_end_user_imsi"] = "IMSI koncového uživatele GTPv2",
    ["gtpv2_end_user_msisdn"] = "Koncový uživatel GTPv2 MSISDN",
    ["gtpv2_pdn_ip"] = "IP adresa GTPV2 PDN",
    ["gtpv2_rat_type"] = "GTPv2 RAT Type",
    ["gtpv2_req_msg_type"] = "Typ zprávy GTPv2",
    ["gtpv2_response_cause"] = "Příčina operace GTPv2",
    ["gtpv2_rsp_msg_type"] = "Typ požadavku GTPv2",
    ["gtpv2_s2c_s1u_gtpu_ip"] = "GTPv2 Srv-> Klient S1U GTPU IP",
    ["gtpv2_s2c_s1u_gtpu_teid"] = "GTPv2 Srv-> Klient S1U GTPU TEID",
    ["gtpv2_s2c_s5_s8_gtpc_ip"] = "GTPv2 Svr-> Klient S5 / S8 GTPC IP",
    ["gtpv2_s2c_s5_s8_gtpu_ip"] = "GTPv2 Srv-> Klient S5 / S8 PGW GTPU IP",
    ["gtpv2_s2c_s5_s8_gtpu_teid"] = "GTPv2 Srv-> Klient S5 / S8 PGW GTPU TEID",
    ["gtpv2_s2c_s5_s8_sgw_gtpu_ip"] = "GTPv2 Srv-> Klient S5 / S8 SGW GTPU IP",
    ["gtpv2_s2c_s5_s8_sgw_gtpu_teid"] = "GTPv2 Srv-> Klient S5 / S8 SGW GTPU TEID",
    ["gtpv2_s5_s8_gtpc_teid"] = "GTPv2 S5/S8 SGW GTPC TEIDs",
    ["gtpv2_uli_cell_id"] = "Identifikátor buňky GTPv2",
    ["gtpv2_uli_cell_tac"] = "Kód oblasti sledování GTPv2",
    ["gtpv2_uli_mcc"] = "Mobilní kód země GTPv2",
    ["gtpv2_uli_mnc"] = "Kód mobilní sítě GTPv2",
    ["http_host"] = "Název hostitele HTTP (název hostitele IXIA)",
    ["http_length"] = "Délka obsahu HTTP",
    ["http_method"] = "METODA HTTP",
    ["http_mime"] = "HTTP Mime Type",
    ["http_protocol"] = "Protokol HTTP",
    ["http_referer"] = "HTTP Referer",
    ["http_ret_code"] = "Návratový kód HTTP (např. 200, 304 ...)",
    ["http_site"] = "HTTP server bez názvu hostitele",
    ["http_ua"] = "HTTP User Agent",
    ["http_url"] = "HTTP URL (IXIA URI)",
    ["http_via"] = "HTTP přes",
    ["http_x_forwarded_for"] = "HTTP X-Forwarded-For",
    ["icmp_ipv4_code"] = "Kód ICMP",
    ["icmp_ipv4_type"] = "Typ ICMP",
    ["icmp_type"] = "Typ ICMP * 256 + kód ICMP",
    ["imap_login"] = "Odesílatel pošty",
    ["in_bytes"] = "Příchozí tokové bajty (src-> dst)",
    ["in_dst_mac"] = "Cílová adresa MAC",
    ["in_pkts"] = "Pakety příchozího toku (src-> dst)",
    ["in_src_mac"] = "Zdrojová adresa MAC",
    ["in_src_osi_sap"] = "Zdroj OSI SAP (pouze provoz OSI)",
    ["ingress_vrfid"] = "Ingress VRF ID",
    ["input_snmp"] = "Vstupní rozhraní SNMP idx",
    ["ip_protocol_version"] = "[4=IPv4][6=IPv6]",
    ["ipfix_sampling_algorithm"] = "Algoritmus vzorkování",
    ["ipv4_dst_addr"] = "Cílová adresa IPv4",
    ["ipv4_dst_mask"] = "Maska podsítě IPv4 dest (/ <bits>)",
    ["ipv4_next_hop"] = "IPv4 next hop address",
    ["ipv4_src_addr"] = "Zdrojová Adresa IPv4",
    ["ipv4_src_mask"] = "Maska podsítě zdroje IPv4 (/ <bits>)",
    ["ipv6_dst_addr"] = "Cílová adresa IPv6",
    ["ipv6_dst_mask"] = "Cílová maska IPv6",
    ["ipv6_next_hop"] = "IPv6 next hop address",
    ["ipv6_src_addr"] = "Zdrojová adresa IPv6",
    ["ipv6_src_mask"] = "Maska zdroje IPv6",
    ["l4_dst_port"] = "Cílový port vrstvy 4",
    ["l4_dst_port_map"] = "Symbolický název cílového portu vrstvy 4",
    ["l4_src_port"] = "Port zdroje IPv4",
    ["l4_src_port_map"] = "Symbolické jméno zdrojového portu vrstvy 4",
    ["l4_srv_port"] = "Port serveru vrstvy 4",
    ["l4_srv_port_map"] = "Symbolické jméno portu serveru vrstvy 4",
    ["l7_proto"] = "Aplikace vrstvy 7 (numerická)",
    ["l7_proto_name"] = "Název aplikace vrstvy 7",
    ["last_switched"] = "SysUptime (msec) posledního toku pkt",
    ["longest_flow_pkt"] = "Nejdelší paket (bajtů) toku",
    ["max_ttl"] = "Maximální tok TTL",
    ["min_ttl"] = "Minimální tok TTL",
    ["mpls_label_1"] = "Štítek MPLS na pozici   1",
    ["mpls_label_10"] = "Štítek MPLS na pozici 10",
    ["mpls_label_2"] = "Štítek MPLS na pozici   2",
    ["mpls_label_3"] = "Štítek MPLS na pozici   3",
    ["mpls_label_4"] = "Štítek MPLS na pozici   4",
    ["mpls_label_5"] = "Štítek MPLS na pozici   5",
    ["mpls_label_6"] = "Štítek MPLS na pozici   6",
    ["mpls_label_7"] = "Štítek MPLS na pozici   7",
    ["mpls_label_8"] = "Štítek MPLS na pozici   8",
    ["mpls_label_9"] = "Štítek MPLS na pozici   9",
    ["mysql_appl_latency_usec"] = "Žádost MySQL -> zpoždění odpovědi (usec)",
    ["mysql_db"] = "Používaná databáze MySQL",
    ["mysql_query"] = "MySQL Query",
    ["mysql_response"] = "Odpověď serveru mySQL",
    ["mysql_server_version"] = "Verze serveru MySQL",
    ["mysql_username"] = "Uživatelské jméno MySQL",
    ["netbios_query_name"] = "Název dotazu NETBIOS",
    ["netbios_query_os"] = "NETBIOS Query OS",
    ["netbios_query_type"] = "Typ dotazu NETBIOS",
    ["netbios_response"] = "Odpověď na dotaz NETBIOS",
    ["nprobe_ipv4_address"] = "IPv4 adresa hostitele byla spuštěna nProbe",
    ["num_pkts_1024_to_1514_bytes"] = "# pakety, jejichž velikost IP> 1024 a <= 1514",
    ["num_pkts_128_to_256_bytes"] = "# pakety, jejichž velikost IP> 128 a <= 256",
    ["num_pkts_256_to_512_bytes"] = "# pakety, jejichž velikost IP> 256 a <512",
    ["num_pkts_512_to_1024_bytes"] = "# pakety, jejichž velikost IP> 512 a <1024",
    ["num_pkts_over_1514_bytes"] = "# pakety, jejichž velikost IP> 1514",
    ["num_pkts_ttl_128_160"] = "# pakety s TTL> 128 a <= 160",
    ["num_pkts_ttl_160_192"] = "# pakety s TTL> 160 a <= 192",
    ["num_pkts_ttl_192_224"] = "# pakety s TTL> 192 a <= 224",
    ["num_pkts_ttl_224_255"] = "# pakety s TTL> 224 a <= 255",
    ["num_pkts_ttl_2_5"] = "# pakety s TTL> 1 a TTL <= 5",
    ["num_pkts_ttl_32_64"] = "# pakety s TTL> 32 a <= 64",
    ["num_pkts_ttl_5_32"] = "# pakety s TTL> 5 a TTL <= 32",
    ["num_pkts_ttl_64_96"] = "# pakety s TTL> 64 a <= 96",
    ["num_pkts_ttl_96_128"] = "# pakety s TTL> 96 a <= 128",
    ["num_pkts_ttl_eq_1"] = "# pakety s TTL = 1",
    ["num_pkts_up_to_128_bytes"] = "# pakety, jejichž velikost IP <= 128",
    ["observation_point_id"] = "ID bodu pozorování",
    ["observation_point_type"] = "Typ pozorovacího bodu",
    ["ooorder_in_pkts"] = "Počet tokových paketů TCP mimo provoz (dst-> src)",
    ["ooorder_out_pkts"] = "Počet tokových paketů TCP mimo řádek (src-> dst)",
    ["oracle_query"] = "Oracle Query",
    ["oracle_query_duration"] = "Trvání Oracle Query (msec)",
    ["oracle_rsp_code"] = "Kód odezvy Oracle",
    ["oracle_rsp_string"] = "Řetězec odezvy Oracle",
    ["oracle_username"] = "Uživatelské jméno Oracle",
    ["out_bytes"] = "Odchozí tokové bajty (dst-> src) [Aliased to %%DST_TO_SRC_BYTES]",
    ["out_dst_mac"] = "Cílová adresa MAC, potenciálně upravená funkcí  middlebox za bodem pozorování",
    ["out_dst_osi_sap"] = "Cíl OSI SAP(Pouze provoz OSI)",
    ["out_pkts"] = "Odchozí tokové pakety(dst->src) [Aliased to %%DST_TO_SRC_PKTS]",
    ["out_src_mac"] = "Zdrojová adresa MAC, potenciálně upravená funkcí middlebox za bodem pozorován",
    ["output_snmp"] = "Výstupní rozhraní SNMP idx",
    ["packet_section_offset"] = "Posunutí části paketu",
    ["packets_observed"] = "Celkový počet viděných paketů",
    ["packets_selected"] = "Počet pkts vybraných pro odběr vzorků",
    ["payload_hash"] = "Počáteční hash užitečného toku toku",
    ["plugin_name"] = "Název pluginu použitý v tomto toku (pokud existuje)",
    ["pop_user"] = "Přihlášení uživatele POP3",
    ["post_napt_dst_transport_port"] = "Post NAPT Destination Transport Port",
    ["post_napt_src_transport_port"] = "Post NAPT Source Transport Port",
    ["post_nat_dst_ipv4_addr"] = "Post NAT Destination IPv4 Address",
    ["post_nat_src_ipv4_addr"] = "Post NAT Source IPv4 Address",
    ["exporter_ipv4_address"] = "Exporter IPv4 Address",
    ["exporter_ipv6_address"] = "Exporter IPv6 Address",
    ["protocol"] = "IP protokol bajtů",
    ["protocol_map"] = "Název protokolu IP",
    ["radius_acct_in_octets"] = "RADIUS vstupní oktety",
    ["radius_acct_in_pkts"] = "Vstupní pakety účetního RADIUS",
    ["radius_acct_out_octets"] = "Octects s účetním výstupem RADIUS",
    ["radius_acct_out_pkts"] = "Pakety účetního výstupu RADIUS",
    ["radius_acct_session_id"] = "Název účetní relace RADIUS",
    ["radius_acct_status_type"] = "Typ stavu účetnictví RADIUS",
    ["radius_called_station_id"] = "ID volané stanice RADIUS",
    ["radius_calling_station_id"] = "Id volací stanice RADIUS",
    ["radius_framed_ip_addr"] = "RADIUS Framed IP",
    ["radius_nas_identifier"] = "RADIUS NAS Identifier",
    ["radius_nas_ip_addr"] = "RADIUS NAS IP Address",
    ["radius_req_msg_type"] = "Typ požadavku RADIUS",
    ["radius_rsp_msg_type"] = "Typ odpovědi RADIUS",
    ["radius_user_imei"] = "RADIUS uživatel MSISDN (rozšíření)",
    ["radius_user_imsi"] = "RADIUS Uživatel IMSI (rozšíření)",
    ["radius_user_name"] = "Uživatelské jméno RADIUS (pouze přístup)",
    ["retransmitted_in_bytes"] = "Počet opakovaných přenosových tokových bajtů TCP (src-> dst)",
    ["retransmitted_in_pkts"] = "Počet opakovaných přenosových tokových paketů TCP (src-> dst)",
    ["retransmitted_out_bytes"] = "Počet opakovaných přenosových bajtů TCP (dst-> src)",
    ["retransmitted_out_pkts"] = "Počet opakovaných přenosových paketů TCP (dst-> src)",
    ["rtp_dtmf_tones"] = "DTMF Tones odeslané (pokud existují) během hovoru",
    ["rtp_first_seq"] = "Sekvenční číslo RTP prvního toku",
    ["rtp_first_ts"] = "Časové razítko prvního toku RTP",
    ["rtp_in_jitter"] = "RTP jitter (ms * 1000)",
    ["rtp_in_max_delta"] = "Max delta (ms * 100) mezi po sobě jdoucími pkts (src-> dst)",
    ["rtp_in_mos"] = "RTP pseudo-MOS (hodnota * 100) (src-> dst)",
    ["rtp_in_payload_type"] = "Typ užitečného zatížení RTP",
    ["rtp_in_pkt_drop"] = "Paket zahozený od Jitter Buffer (src-> dst)",
    ["rtp_in_pkt_lost"] = "Paket ztracen ve streamu (src-> dst)",
    ["rtp_in_r_factor"] = "RTP pseudo-R_FACTOR (hodnota * 100) (src-> dst)",
    ["rtp_in_transit"] = "Transit RTP (hodnota * 100) (src-> dst)",
    ["rtp_last_seq"] = "Sekvenční číslo RTP posledního toku",
    ["rtp_last_ts"] = "Časové razítko RTP posledního toku",
    ["rtp_mos"] = "RTP pseudo-MOS (hodnota * 100) (průměr oběma směry)",
    ["rtp_out_jitter"] = "RTP jitter (ms * 1000)",
    ["rtp_out_max_delta"] = "Max delta (ms * 100) mezi po sobě jdoucími pkts (dst-> src)",
    ["rtp_out_mos"] = "RTP pseudo-MOS (hodnota * 100) (dst-> src)",
    ["rtp_out_payload_type"] = "Typ užitečného zatížení RTP",
    ["rtp_out_pkt_drop"] = "Paket zahozený od Jitter Buffer (dst-> src)",
    ["rtp_out_pkt_lost"] = "Paket ztracen ve streamu (dst-> src)",
    ["rtp_out_r_factor"] = "RTP pseudo-R_FACTOR (hodnota * 100) (dst-> src)",
    ["rtp_out_transit"] = "Transit RTP (hodnota * 100) (dst-> src)",
    ["rtp_r_factor"] = "RTP pseudo-R_FACTOR (hodnota * 100) (průměr oběma směry)",
    ["rtp_rtt"] = "RTP zpáteční doba (ms)",
    ["rtp_sip_call_id"] = "SIP call-id odpovídající tomuto RTP proudu",
    ["rtp_ssrc"] = "ID zdroje synchronizace RTP",
    ["s1ap_cause_enb_to_mme"] = "S1AP Příčina od ENB do MME",
    ["s1ap_detailed_cause_enb_to_mme"] = "Podrobná příčina S1AP od ENB do MME",
    ["s1ap_enb_ue_s1ap_id"] = "S1AP ENB Identifier",
    ["s1ap_mme_ue_s1ap_id"] = "S1AP MME Identifier",
    ["s1ap_msg_emm_type_enb_to_mme"] = "Typ zprávy S1AP EMM od ENB do MME",
    ["s1ap_msg_emm_type_mme_to_enb"] = "Typ zprávy S1AP EMM z MME do ENB",
    ["s1ap_msg_esm_type_enb_to_mme"] = "Typ zprávy S1AP ESM od ENB do MME",
    ["s1ap_msg_esm_type_mme_to_enb"] = "Typ zprávy S1AP ESM z MME do ENB",
    ["sampled_packet_id"] = "ID vzorkovaného paketu",
    ["sampled_packet_size"] = "Velikost vzorkovaného paketu",
    ["sampling_algorithm"] = "Typ vzorkování (deterministický / náhodný)",
    ["sampling_interval"] = "Vzorkovací frekvence",
    ["sampling_population"] = "Výběr vzorku",
    ["sampling_size"] = "Počet paketů k vzorkování",
    ["selector_id"] = "Selector id",
    ["selector_name"] = "Sampler name",
    ["server_nw_latency_ms"] = "Síť RTT / 2 nprobe <-> server (msec)",
    ["shortest_flow_pkt"] = "Nejkratší paket (bajty) toku",
    ["sip_bye_ok_time"] = "SIP čas (epocha) BYE OK",
    ["sip_bye_time"] = "SIP čas (epocha) BYE",
    ["sip_c_ip"] = "IP adresy SIP C",
    ["sip_call_id"] = "SIP call-id",
    ["sip_call_state"] = "Stav volání SIP",
    ["sip_called_party"] = "SIP Called party",
    ["sip_calling_party"] = "Iniciátor SIP volání",
    ["sip_cancel_ok_time"] = "SIP čas (epocha) ZRUŠIT OK",
    ["sip_cancel_time"] = "SIP čas (epocha) ZRUŠIT",
    ["sip_invite_failure_time"] = "SIP čas (epocha) INVITE FAILURE",
    ["sip_invite_ok_time"] = "SIP čas (epocha) POZVAT OK",
    ["sip_invite_time"] = "Čas SIP (epocha) POZVAT",
    ["sip_reason_cause"] = "SIP Zrušení / Bye / Příčina selhání",
    ["sip_response_code"] = "Kód odpovědi na selhání SIP",
    ["sip_ringing_time"] = "SIP čas (epocha) zvonění",
    ["sip_rtp_codecs"] = "SIP RTP codecs",
    ["sip_rtp_ipv4_dst_addr"] = "SIP RTP stream přes IP",
    ["sip_rtp_ipv4_src_addr"] = "SIP RTP stream source IP",
    ["sip_rtp_l4_dst_port"] = "Cílový port toku SIP RTP",
    ["sip_rtp_l4_src_port"] = "Port zdroje proudu SIP RTP",
    ["sip_trying_time"] = "Čas SIP (epocha) pokusu",
    ["smtp_mail_from"] = "Odesílatel pošty",
    ["smtp_rcpt_to"] = "Příjemce pošty",
    ["src_as"] = "Source BGP AS",
    ["src_as_map"] = "Název organizace pro SRC_AS",
    ["src_as_path_1"] = "Src AS poloha pozice 1",
    ["src_as_path_10"] = "Src AS poloha pozice 10",
    ["src_as_path_2"] = "Src AS poloha pozice 2",
    ["src_as_path_3"] = "Src AS poloha pozice 3",
    ["src_as_path_4"] = "Src AS poloha pozice 4",
    ["src_as_path_5"] = "Src AS poloha pozice 5",
    ["src_as_path_6"] = "Src AS poloha pozice 6",
    ["src_as_path_7"] = "Src AS poloha pozice 7",
    ["src_as_path_8"] = "Src AS poloha pozice 8",
    ["src_as_path_9"] = "Src AS poloha pozice 9",
    ["src_father_proc_name"] = "Název procesu Father Src",
    ["src_father_proc_pid"] = "Src Father proces PID",
    ["src_fragments"] = "Počet fragmentovaných paketů src-> dst",
    ["src_ip_city"] = "Město, kde se nachází IP src",
    ["src_ip_country"] = "Země, kde se nachází IP src",
    ["src_ip_lat"] = "Zeměpisná šířka, kde se nachází adresa IP src",
    ["src_ip_long"] = "Zeměpisná délka, kde se nachází IP adresa src",
    ["src_proc_actual_memory"] = "Src zpracovává skutečnou paměť (bajty)",
    ["src_proc_average_cpu_load"] = "zatížení procesu vg src (%% * 100)",
    ["src_proc_name"] = "Název procesu Src",
    ["src_proc_num_page_faults"] = "Src process num pagefaults",
    ["src_proc_pctg_iowait"] = "Proces Src iowait time %% (%% * 100)",
    ["src_proc_peak_memory"] = "Src zpracovává vrcholnou paměť (bajty)",
    ["src_proc_pid"] = "Src proces PID",
    ["src_proc_uid"] = "Src proces UID",
    ["src_proc_user_name"] = "Uživatelské jméno procesu Src",
    ["src_to_dst_avg_throughput"] = "Src do dst průměrný thpt (bps)",
    ["src_to_dst_max_throughput"] = "Src do dst max thpt (bps)",
    ["src_to_dst_min_throughput"] = "Src do dst min thpt (bps)",
    ["src_tos"] = "TOS/DSCP (src->dst)",
    ["src_vlan"] = "Zdroj VLAN (vnitřní VLAN v QinQ)",
    ["ssdp_host"] = "SSDP Host",
    ["ssdp_method"] = "SSDP Metoda",
    ["ssdp_server"] = "SSDP Server",
    ["ssdp_type"] = "SSDP Typ",
    ["ssdp_usn"] = "SSDP USN",
    ["suricata_app_proto"] = "Protokol aplikace Suricata",
    ["suricata_flow_id"] = "ID toku Suricata",
    ["tcp_flags"] = "Souhrn všech příznaků TCP všech toků",
    ["tcp_win_max_in"] = "Max TCP Window (src-> dst)",
    ["tcp_win_max_out"] = "Max TCP Window (dst->src)",
    ["tcp_win_min_in"] = "Min TCP Window (src->dst)",
    ["tcp_win_min_out"] = "Min TCP Window (dst->src)",
    ["tcp_win_mss_in"] = "Maximální velikost segmentu TCP(src->dst)",
    ["tcp_win_mss_out"] = "Maximální velikost segmentu TCP (dst-> src)",
    ["tcp_win_scale_in"] = "TCP Window Scale (src-> dst)",
    ["tcp_win_scale_out"] = "TCP Window Scale (dst-> src)",
    ["tls_cert_after"] = "TLS Certificate After",
    ["tls_cert_dn"] = "TLS Certificate DN",
    ["tls_cert_not_before"] = "Certifikát TLS ne dříve",
    ["tls_cert_sha1"] = "TLS Certificate Fingerprint",
    ["tls_cert_sn"] = "TLS certifikát S / N",
    ["tls_cert_subject"] = "Předmět certifikátu TLS",
    ["tls_server_name"] = "Název serveru TLS",
    ["tls_version"] = "TLS Verze",
    ["total_bytes_exp"] = "Celkový počet exportovaných bytů",
    ["total_flows_exp"] = "Celkový počet exportovaných toků",
    ["total_pkts_exp"] = "Celkový počet exportovaných toků “,",
    ["untunneled_ipv4_dst_addr"] = "Cílová adresa untunneled IPv4",
    ["untunneled_ipv4_src_addr"] = "Zdrojová adresa untunneled IPv4",
    ["untunneled_ipv6_dst_addr"] = "Cílová adresa untunneled IPv6",
    ["untunneled_ipv6_src_addr"] = "Zdrojová adresa untunneled IPv6",
    ["untunneled_l4_dst_port"] = "Cílový Port Untunneled IPv4 ",
    ["untunneled_l4_src_port"] = "Zdrojový Port Untunneled IPv4",
    ["untunneled_protocol"] = "Bajt untunneled IP Protokol",
    ["upstream_session_id"] = "Identifikátor relace proti proudu (např. L2TP) nebo 0, pokud není znám",
    ["upstream_tunnel_id"] = "Identifikátor předřazeného tunelu (např. GTP TEID, VXLAN VNI) nebo 0, pokud není znám",
    ["user_name"] = "Uživatelské jméno",
  },
  ["flows_page"] = {
    ["active_flows"] = "Aktivní %{filter} toky",
    ["actual_throughput"] = "Skutečné Thpt",
    ["alerted"] = "Upozornění",
    ["all_alerted"] = "Vše upozorněno",
    ["all_ases"] = "Všechny ASes",
    ["all_categories"] = "Všechny kategorie",
    ["all_devices"] = "Všichni exporteři toku",
    ["all_flows"] = "Všechny toky",
    ["all_hosts"] = "Všichni hostitelé",
    ["all_inIfIdx"] = "Všechna vstupní rozhraní",
    ["all_ip_versions"] = "Všechny verze",
    ["all_l4_protocols"] = "Všechny protokoly",
    ["all_misbehaving"] = "Všechno chovající se špatně",
    ["all_outIfIdx"] = "Všechna výstupní rozhraní",
    ["all_proto"] = "Všechny aplikace",
    ["all_vlan_ids"] = "Všechny sítě VLAN",
    ["applications"] = "Aplikace",
    ["blocked"] = "Blokováno",
    ["client_as"] = "Klient AS",
    ["device_ip"] = "Exporter Toku",
    ["direction"] = "Směr",
    ["flows"] = "%{filter} Toky",
    ["flows_as_client"] = "Toky jako klient",
    ["flows_as_server"] = "Toky jako server",
    ["hosts"] = "Hosts",
    ["icmp_only"] = "Pouze ICMP",
    ["idle_flows_not_listed"] = "Neaktivní toky nejsou uvedeny.",
    ["inIfIdx"] = "Vstupní rozhraní",
    ["ip_version"] = "Verze IP",
    ["ipv4_only"] = "Pouze IPv4",
    ["ipv6_only"] = "Pouze IPv6",
    ["l4_protocol"] = "Protokol",
    ["local_cli_remote_srv"] = "Místní klient - vzdálený server",
    ["local_only"] = "Pouze místní",
    ["local_srv_remote_cli"] = "Lokální Server - Vzdálený Klient",
    ["misbehaving"] = "Chovajicí se spatně",
    ["multicast"] = "vysílání",
    ["network"] = " [ Síť %{network} ]",
    ["non_multicast"] = "Nevysílá",
    ["normal"] = "Normalní",
    ["one_way_multicast"] = "Jednosměrné vysílán",
    ["one_way_non_multicast"] = "One-Way Non-Multicast/Non-Broadcast",
    ["outIfIdx"] = "Výstupní rozhraní",
    ["exporters"] = "Exporteři Toku",
    ["recently_active_flows"] = "Nedávno aktivní %{filter} toky",
    ["remote_only"] = "Pouze Vzdálené",
    ["server_as"] = "Server AS",
    ["sflow_devices"] = "Zařízení sFlow",
    ["source_id"] = "ID zdroje",
    ["tcp_only"] = "Pouze TCP",
    ["tcp_state"] = "Stav TCP",
    ["tcp_state_closed"] = "Uzavřeno / Zavřeno",
    ["tcp_state_connecting"] = "Připojování",
    ["tcp_state_established"] = "stanovený",
    ["tcp_state_reset"] = " Resetovat",
    ["tcp_state_unknown"] = "Neznámý",
    ["total_bytes"] = "Celkem bajtů",
    ["total_bytes_rcvd"] = "Celkový počet přijatých bajtů",
    ["total_bytes_sent"] = "Celkový počet odeslaných bajtů",
    ["total_bytes_unknown"] = "Celkový počet neznámých bajtů aplikací",
    ["udp_only"] = "Pouze UDP",
    ["vlan"] = "VLAN",
  },
  ["geo_map"] = {
    ["browser_reported_home_map"] = "Poloha domovského chartu nahlášená prohlížečem",
    ["geo_map"] = "Geo Mapa",
    ["geolocation_error"] = "Chyba geolokace",
    ["hosts_geomap"] = "Hosts GeoMap",
    ["latitude"] = "Zeměpisná šířka",
    ["longitude"] = "Zeměpisná délka",
    ["note"] = "POZNÁMKA",
    ["note_active_flows"] = "Mají aktivní toky mezi vrstevníky s veřejnými IP adresami. “,„ Délka",
    ["note_compiled_ntopng_with_geolocation"] = "Zkompilovali software s geolokací a začali s ním.",
    ["note_google_maps_browser_api_key"] = "Je vyžadován klíč Google Maps API Key, který můžete vygenerovat <a href='%{url_google}'>Konzolí platformy Google Cloud Platform</a>:<br> vytvořte, prosím, nový projekt a vyberte Maps JavaScript API ->Vytvořit pověření -> klíč API. <br> Po vygenerování, klíč lze zadat prostřednictvím <a href='%{url_prefs}'><i class=\"fas fa-flask\"></i> Preference</a>.",
    ["note_html_browser_geolocation"] = "HTML <A HREF=%{url}>browser geolocation</A> se používá k umístění na hostitele mapy na základě neznámých míst.",
    ["note_requirements_visualize_maps"] = "Aby bylo možné vizualizovat mapy, musíte",
    ["note_working_internet_connection"] = "Mít funkční připojení k internetu.",
    ["unavailable_geolocation"] = "Geolokace nepodporuje váš prohlížeč ani není deaktivována.",
    ["using_default_location"] = "Používá výchozí umístění.",
  },
  ["graphs"] = {
    ["95_perc"] = "95. Perc",
    ["active_devices"] = "Aktivní zařízení",
    ["active_flows"] = "Aktivní toky",
    ["active_host_contacts"] = "Kontakty aktivního hostitele",
    ["active_hosts"] = "Aktivní hostitelé",
    ["active_http_servers"] = "Aktivní HTTP servery",
    ["actual_memory"] = "Skutečná paměť",
    ["arp_replies"] = "ARP odpovědi",
    ["arp_requests"] = "ARP požadavky",
    ["arp_rqst_sent_rcvd_rpls"] = "ARP odeslané žádosti / odpovědi Rcvd",
    ["average"] = "Průměrný",
    ["average_traffic"] = "Průměrný provoz / s",
    ["avg"] = "Avg",
    ["binary_operators_note"] = "Další informace o indikátorech EMA, SMA a RSI najdete na <a href=\"%{url}\">online dokumentacích</a>.",
    ["blocked_flows"] = "Blokované toky",
    ["bytes_sent_non_unicast"] = "Bajty odeslány bez unicastu",
    ["bytes_sent_unicast"] = "Bajty odeslané Unicast",
    ["custom"] = "Vlastní",
    ["dns_qry_rcvd_rsp_sent"] = "DNS Rcvd Dotazy / \9odeslané odpovědi",
    ["dns_qry_sent_rsp_rcvd"] = "Odeslané dotazy DNS / přojaté odpovedi",
    ["download_chart_data"] = "Stáhnout aktuální data chartu",
    ["echo_reply_packets"] = "Echo Reply Packets",
    ["echo_request_packets"] = "Echo Request Packets",
    ["export_flows_as_txt"] = "Exportovat toky jako soubor TXT",
    ["flows_status_overview"] = "%{protocol} Přehled stavu toků",
    ["flows_vs_local_hosts"] = "Aktivní toky vs. místní hositelé",
    ["flows_vs_traffic"] = "Aktivní toky vs. provoz",
    ["get_permanent_link"] = "Získejte trvalý odkaz",
    ["graph_info"] = "Informace o grafu",
    ["host_unreachable_flows"] = "Celkový počet nepřijatelných toků hostitele",
    ["max"] = "Max",
    ["memory_vs_hosts_flows"] = "Procesní paměť vs Hostitelé / Toky",
    ["minute_interface_top_stats"] = "Statistiky nejvyššího provozu na minutu",
    ["note_ases_rcvd"] = "Provoz přijímal provoz přijímaný autonomním systémem.",
    ["note_ases_sent"] = "Odeslaný provoz je přenos odeslaný autonomním systémem.",
    ["note_ases_traffic"] = "Zobrazený provoz je odesílán a přijímán autonomním systémem.",
    ["note_chart_zoom"] = "Klepnutím a přetažením v chartu přiblížíte, dvojitým kliknutím oddálíte.",
    ["note_protocols_shown"] = "Aplikace neviděné ve vybraném časovém rámci nejsou v rozevíracím seznamu uvedeny.",
    ["num_ms_rtt"] = "Doba zpáteční cesty ms",
    ["num_nfq_drops"] = "Spadlé Pakety",
    ["num_nfq_pct"] = "Vyplnit frontu %%",
    ["packet_drops"] = "Packet Drops",
    ["peak_memory"] = "Vrcholná Paměť",
    ["percentile"] = "95. <a href=\"%{url}\">procent</a>",
    ["permanent_link"] = "Trvalý odkaz",
    ["pkt_drops"] = "Pkt Drops",
    ["process_memory"] = "Paměť Procesu",
    ["query_too_much_time"] = "Dokončení dotazu trvá příliš dlouho",
    ["query_too_slow"] = "Dokončení dotazu trvalo příliš dlouho",
    ["query_was_aborted"] = "Dotaz byl přerušen",
    ["raw_flows"] = "Raw Flows",
    ["raw_proto_flows"] = "Raw %{proto} Toky",
    ["reset_zoom"] = "Reset Zoom",
    ["right_axis_note"] = "(right axis)",
    ["rtt"] = "RTT",
    ["tcp_finack_packets"] = "Pakety TCP FIN + ACK",
    ["tcp_packets"] = "Pakety TCP",
    ["tcp_packets_keep_alive"] = "TCP Packets KeepAlive",
    ["tcp_packets_lost"] = "Ztracené pakety TC",
    ["tcp_packets_ooo"] = "TCP Pakety jsou mimo provoz",
    ["tcp_packets_retr"] = "Přenosové pakety TCP",
    ["tcp_retr_ooo_lost"] = "Opakovaný přenos TCP je mimo provoz a ztracený",
    ["tcp_rst_packets"] = "TCP RST pakety",
    ["tcp_rx_stats"] = "Statistiky TCP RX",
    ["tcp_syn_packets"] = "TCP SYN Packety",
    ["tcp_syn_vs_tcp_synack"] = "TCP SYN vs SYN+ACK Pakety",
    ["tcp_synack_packets"] = "TCP SYN + ACK pakety",
    ["tcp_tx_stats"] = " Statistiky TCP TX",
    ["the_select_timeframe_too_small_top_talkers"] = "Zvolený časový frame je příliš malý na to, aby bylo možné určit Top Talkers. Vyberte prosím alespoň 1 minutový frame.",
    ["top_clients"] = "Top %{protocol} Klienti",
    ["top_interfaces"] = "Top rozhraní",
    ["top_l7_contacts"] = "Top %{protocol} L7 Kontakty",
    ["top_ndpi_categories"] = "Top kategorie",
    ["top_ndpi_protocols"] = "Top aplikace",
    ["top_profiles"] = "Top profily",
    ["top_receivers"] = "Top přijímače",
    ["top_senders"] = "Top Odesílatelé",
    ["top_servers"] = "Top %{protocol} Servery",
    ["total_misbehaving_flows"] = "Celkový počet chybných toků",
    ["total_unreachable_flows"] = "Celkový počet Portů nedostuných toků",
    ["traffic_rxtx"] = "Provoz RX / TX",
    ["traffic_vs_errors"] = "Provoz vs Chyby",
    ["trend"] = "Trend",
    ["udp_packets"] = "UDP Pakety",
    ["udp_sent_unicast_vs_non_unicast"] = "UDP poslal Unicast vs Non Unicast",
    ["zmq_flow_coll_drops"] = "Spadla kolekce toku",
    ["zmq_flow_coll_udp_drops"] = "Spadla kolekce soketů",
    ["zmq_msg_rcvd_vs_drops"] = "Shromážděné vs Dropped ZMQ zprávy",
    ["zmq_received_flows"] = "Shromážděné ZMQ Toky",
    ["metrics_prefixes"] = {
      ["broadcast_bytes"] = "Vysílání bajtů",
      ["drops"] = "Padá",
      ["num_devices"] = "Počet zařízení",
      ["num_flows"] = "Počet toků",
      ["num_hosts"] = "Počet hostitelů",
      ["num_http_hosts"] = "Počet HTTP hostitelů",
      ["num_ms_rtt"] = "RTT ms",
      ["packets"] = "Pakety",
    },
    ["metrics_suffixes"] = {
      ["by_as"] = "%{metric} by AS",
      ["egress"] = "Opouštějící",
      ["ingress"] = "Přicházející",
      ["inner"] = "Vnitřní",
      ["rcvd"] = "rcvd",
      ["sent"] = "poslat",
    },
  },
  ["host_config"] = {
    ["drop_all_host_traffic"] = "Přerušte veškerý provoz hostitele",
    ["hide_from_top"] = "Skrýt před Top Talkers",
    ["hide_host_from_top_descr"] = "Nepočítejte hostitele %{host} do top talkers výpočtu",
    ["host_alias"] = "Host Alias",
    ["host_pool"] = "Hostitelský Fond",
    ["host_traffic_policy"] = "Hostitelská politika provozu",
    ["modify_host_pool_policy_btn"] = "Upravit politiku fondu pro hostitele",
    ["trigger_alerts_for_host"] = "Spustit upozornění pro hostitele %{host}",
    ["trigger_host_alerts"] = "Spouštěcí upozornění hostitele",
    ["unblock_host_traffic"] = "Odblokovat provoz hostitele",
  },
  ["host_details"] = {
    ["active_alerted_flows"] = "Aktivní výstražné toky",
    ["blocked_traffic"] = "\9Blokovaný provoz",
    ["disabled_alert_type_help"] = "Vypnout generování výstrah toku na základě stavu toku",
    ["host"] = "Hostitel / Host",
    ["host_cannot_be_found_message"] = "Host %{host} nemůže být nalezen.",
    ["host_parameter_missing_message"] = "Chybí parametr hostitele (interní chyba?)",
    ["host_traffic_blocked_quota"] = "Některý provoz hostitele byl blokován překročenou kvótou",
    ["host_traffic_blocked_quota_and_shaper"] = "Některý provoz hostitele byl blokován překročenou kvótou a blokovacím blokem",
    ["host_traffic_blocked_shaper"] = "Některý provoz hostitele byl blokován blokovacím blokem",
    ["multiple_selection"] = "Stisknutím tlačítka CTRL lze vybrat více prvků",
    ["reset_host_stats"] = "Reset hostitelské statistiky",
    ["reset_host_stats_confirm"] = "Opravdu chcete resetovat \"%{host}\" statistiku runtime?",
    ["reset_host_stats_note"] = "<b>POZNÁMKA</b>: historické grafy pro tohoto hostitele mohou po resetování obsahovat mezeru.",
    ["reset_stats_in_progress"] = "Statistiky hostitele budou resetovány do 5 sekund",
    ["restore_from_cache_message"] = "Klikněte <a href=%{js_code}> zde</a> pro obnovení z mezipaměti.",
    ["rtt"] = "RTT",
    ["snmp"] = "SNMP",
    ["status_ignore"] = "Upozornění na stav toku zakázána",
    ["trace_debug_host_info"] = "Host:%{hostinfo}, Vlan: %{vlan}",
    ["trace_debug_host_ip"] = "Host:%{hostip}, Vlan: %{vlan}",
    ["trace_debug_restored_host_info"] = "Obnovené informace o hostiteli",
    ["unknown_device_type"] = "Neznámý typ zařízení",
  },
  ["host_pools"] = {
    ["active_pool_members"] = "Aktivní členové fondu",
    ["alias_or_manufacturer"] = "Alias / Výrobce",
    ["and_associated_members"] = "Jjeho historické údaje a případně přidružených členů",
    ["cannot_delete_cp"] = "Fond nelze odstranit, pokud je k němu přidružen jakýkoli uživatel Captive Portal",
    ["change_member_pool"] = "Změnit fond členů",
    ["change_pool"] = "Změnit Fond",
    ["children_safe"] = "Vhodné pro děti",
    ["confirm_delete_pool"] = "Opravdu chcete smazat hostitelský fond",
    ["confirm_empty_pool"] = "Opravdu chcete odebrat všechny členy z hostitelského fondu",
    ["confirm_remove_member"] = "Opravdu chcete člena odebrat?",
    ["confirm_reset_pool_quotas"] = "Opravdu chcete resetovat \"%{pool}\" počítače fondu?",
    ["confirm_reset_quotas"] = "Opravdu chcete resetovat všechny čítače kvót?",
    ["create_new_quotas_here"] = "Zde můžete vytvořit nové kvóty <a href=\"%{url}\">zde</a>.",
    ["create_pool_hint"] = "Na kartě Spravovat fondy můžete vytvořit nové fondy.",
    ["create_pools"] = "Spravovat Fondy",
    ["delete_pool"] = "Smazat fond",
    ["duplicate_member"] = "Duplicitní adresa člena",
    ["duplicate_pool"] = "Duplicitní název fondu",
    ["edit_host_pools"] = "Upravit hostitelské fondy",
    ["empty_pool"] = "Prázdný Fond",
    ["enforce_quotas_per_pool_member"] = "Kvóty na člena",
    ["enforce_shapers_per_pool_member"] = "Shapers na člena",
    ["from_pool"] = "z hostitelského fondu",
    ["host_pools"] = "Hostitelské Fondy",
    ["invalid_member"] = "Neplatný formát adresy člena",
    ["manage_pools"] = "Spravovat Fond Členství",
    ["manufacturer_filter"] = "Výrobce: %{manufacturer}",
    ["max_members_message"] = "S touto verzí ntopng můžete přiřadit pouze %{maxnum} členů na hostitelský fond. Chcete-li tento limit odstranit, upgradujte na verzi Enterprise.",
    ["max_pools_message"] = "S touto verzí ntopng můžete vytvářet pouze %{maxnum} hostiteslkých fondů. Chcete-li tento limit odstranit, upgradujte na verzi Enterprise.",
    ["member_address"] = "Adresa člena",
    ["member_exists"] = "Člen \"%{member_name}\" nepřidán. Je již přiřazen k fondu \"%{member_pool}\".",
    ["member_filter"] = "Člen: %{member}",
    ["members_limit_reached"] = "Bylo dosaženo limitu členů",
    ["network_normalized"] = "Síť \"%{network}\"má nenulový identifikátor hostitele. Použitím \"%{network_normalized}\".",
    ["new_pool"] = "Nové Fondy",
    ["no_pools_defined"] = "Nejsou definovány žádné hostitelské fondy.",
    ["per_member_quotas"] = "Když je nastavena možnost kvóty na člena, každý hostitel bude mít samostatný počet kvót. Pokud nebude nastaven, bude veškerý provoz hostitelů počítat jako celek do limitu kvóty",
    ["per_member_shapers"] = "Když je nastavena možnost Shapers pro jednotlivé členy, každý host bude mít své vlastní Shapers. Pokud nebude nastaven, budou všichni host patřící do stejné skupiny sdílet stejné Shapers.",
    ["pool"] = "Název Fondu",
    ["pool_name"] = "Název Fondu",
    ["pool_name_pattern_error"] = "Zadejte pouze malá písmena, čísla nebo podtržítka",
    ["remove_member"] = "Odebrat člena",
    ["reset_quotas"] = "Obnovit kvóty",
    ["search_member"] = "Vyhledat člena",
    ["select_new_pool"] = "Vyberte nový fond z rozevíracího seznamu níže a přiřaďte člena \"%{member}\" do:",
    ["specify_member_address"] = "Zadejte prosím IPv4 / IPv6 adresu nebo síť nebo MAC adresu",
    ["specify_pool_name"] = "Zadejte název fondu",
    ["view"] = "Pohled",
  },
  ["hosts_comparison"] = {
    ["hosts_parameter_missing_message"] = "Chybí parametr hostitelů (interní chyba?)",
  },
  ["hosts_stats"] = {
    ["all"] = "Vše",
    ["all_hosts"] = "Všichni hostitelé",
    ["as_geolocation"] = "AS Geolocation",
    ["as_info"] = "AS Info",
    ["as_path"] = "AS Cesta",
    ["as_prefixes"] = "AS Předpony",
    ["asn_title"] = "Pro AS %{asn}",
    ["bgp_updates"] = "BGP aktualizace",
    ["blacklisted"] = "Černá listina",
    ["blacklisted_hosts_only"] = "Pouze hostitelé na černé listině",
    ["blocking_traffic_policy_popup_msg"] = "Provoz hostitele je ovlivňován blokováním politiky provozu",
    ["broadcast_domain_hosts_only"] = "Vysílat pouze hostitelské domény",
    ["country_title"] = "Pro zemi %{country}",
    ["filter_hosts"] = "Filtrovat hostitelé",
    ["filtered"] = "Filtrovaný",
    ["filtered_hosts_only"] = "Hostitelé s blokovaným provozem",
    ["host_pool"] = " Hostitelský fond %{pool_name}",
    ["hosts"] = "Hostitelé",
    ["hosts_list"] = "Hostitelský Seznam",
    ["hosts_page_title"] = "%{all} %{traffic_type} %{local_remote} %{protocol} %{network_cidr} %{network} %{ip_version} %{os} Hosts %{country_asn_or_mac} %{vlan}",
    ["idle_hosts_not_listed"] = "Neaktivní hostitelé nejsou uvedení.",
    ["in_network"] = "%{network}",
    ["ipver_title"] = "IPv%{version_num}",
    ["label_blacklisted_host"] = "Černá listina",
    ["label_broadcast_domain_host"] = "Vysílací doména",
    ["label_local_host"] = "Lokální",
    ["label_remote_host"] = "Vzdálený",
    ["local"] = "Lokalní",
    ["local_hosts_only"] = "Pouze lokální hostitelé",
    ["location"] = "Umístění",
    ["mac_title"] = "S Mac %{mac}",
    ["more_info_about_as_popup_msg"] = "Více informací o AS",
    ["pool_title"] = "Pro fond %{poolname}",
    ["remote"] = "Vzdálený",
    ["remote_hosts_only"] = "Pouze vzdálení Hosts",
    ["source_id"] = "ID zdroje",
    ["traffic_type_all"] = "Všichni hostitelé",
    ["traffic_type_one_way"] = "Jednosměrný provoz",
    ["traffic_type_two_ways"] = "Obousměrný provoz",
    ["user"] = "Uživatel %{pool_name}",
    ["user_title"] = "Pro uživatele %{poolname}",
    ["vlan_title"] = "VLAN %{vlan}",
  },
  ["http_page"] = {
    ["distribution"] = "Distribuce",
    ["http_queries"] = "HTTP dotazy odeslány",
    ["http_responses"] = "Přijaté odpovědi HTTP",
    ["method"] = "Metoda",
    ["other_method"] = "Jiná Metoda",
    ["requests"] = "Žádosti",
    ["requests_served"] = "Vyřízené žádosti",
    ["response_code"] = "Kód odpovědi",
    ["response_code_1xx"] = "1xx (Informační)",
    ["response_code_2xx"] = "2xx (Úspěch)",
    ["response_code_3xx"] = "3xx (přesměrování)",
    ["response_code_4xx"] = "4xx (chyba klienta)",
    ["response_code_5xx"] = "5xx (chyba serveru)",
    ["responses"] = "Odpovědi",
    ["traffic_received"] = "Provoz přijat",
    ["traffic_sent"] = "Provoz odeslán",
    ["virtual_hosts"] = "Virtuální hostitelé",
  },
  ["http_servers_stats"] = {
    ["actual_requests"] = "Skutečné žádosti",
    ["bytes_received"] = "Bajty byly přijaty",
    ["bytes_sent"] = "Bajty byly odeslány",
    ["http_server_ip"] = "IP adresa HTTP serveru",
    ["http_servers"] = "HTTP server",
    ["http_virtual_host"] = "HTTP Virtual Host",
    ["local_http_servers"] = "Lokální servery HTTP",
    ["total_requests"] = "Celkový počet žádostí",
  },
  ["icmp_page"] = {
    ["icmp_message"] = "Zpráva ICMP",
    ["icmp_port_unreachable_extra"] = "%{unreach_protocol} port %{unreach_port} nedostupný na %{unreach_host}",
    ["last_rcvd_peer"] = "Naposledy přijatý Peer",
    ["last_sent_peer"] = "Posledně odeslaný Peer",
    ["packets_received"] = "Přijaté pakety",
    ["packets_sent"] = "Odeslané pakety",
  },
  ["icmp_v6_types"] = {
    ["type_0_reserved"] = "Rezervováno",
    ["type_100_private_experimentation"] = "Soukromé experimentování",
    ["type_101_private_experimentation"] = "Soukromé experimentování",
    ["type_127_reserved_for_expansion_of_icmpv6_error_messages"] = "Vyhrazeno pro rozšíření chybových zpráv ICMPv6",
    ["type_128_echo_request"] = "Echo Žádost",
    ["type_129_echo_reply"] = "Echo Odpověď",
    ["type_130_multicast_listener_query"] = "Dotaz posluchače vícesměrového vysílání",
    ["type_131_multicast_listener_report"] = "Zpráva vícesměrového vysílání",
    ["type_132_multicast_listener_done"] = "Posluchač vícesměrového vysílání je hotový",
    ["type_133_router_solicitation"] = "Router Solicitation",
    ["type_134_router_advertisement"] = "Router Advertisement",
    ["type_135_neighbor_solicitation"] = "Neighbor Solicitation",
    ["type_136_neighbor_advertisement"] = "Neighbor Advertisement",
    ["type_137_redirect_message"] = "Přesměrování zprávy",
    ["type_138_router_renumbering"] = "Přečíslování směrovače",
    ["type_139_icmp_node_information_query"] = "Informační dotaz na uzel ICMP",
    ["type_140_icmp_node_information_response"] = "Informační odpověď uzlu ICMP",
    ["type_141_inverse_neighbor_discovery_solicitation_message"] = "Inverzní zpráva o Neighbour Discovery",
    ["type_142_inverse_neighbor_discovery_advertisement_message"] = "Reklamní zpráva o inverzním Neighbour Discovery",
    ["type_143_version_2_multicast_listener_report"] = "Zpráva Multicast posluchače verze 2",
    ["type_144_home_agent_address_discovery_request_message"] = "Zpráva s žádostí o nalezení adresy domovského agenta",
    ["type_145_home_agent_address_discovery_reply_message"] = "Home Agent Address Discovery Reply Message",
    ["type_146_mobile_prefix_solicitation"] = "Mobile Prefix Solicitation",
    ["type_147_mobile_prefix_advertisement"] = "Mobile Prefix Advertisement",
    ["type_148_certification_path_solicitation_message"] = "Zpráva o žádosti o certifikační cestu",
    ["type_149_certification_path_advertisement_message"] = "Reklamní zpráva o certifikační cestě",
    ["type_150_icmp_messages_utilized_by_experimental_mobility_protocols"] = "Zprávy ICMP využívané experimentálními protokoly mobility",
    ["type_151_multicast_router_advertisement"] = "Multicast Router Advertisement",
    ["type_152_multicast_router_solicitation"] = "Multicast Router Solicitation",
    ["type_153_multicast_router_termination"] = "Multicast Router Termination",
    ["type_154_fmipv6_messages"] = "FMIPv6 Zprávy",
    ["type_155_rpl_control_message"] = "Řídicí zpráva RPL",
    ["type_156_ilnpv6_locator_update_message"] = "Zpráva o aktualizaci lokátoru ILNPv6",
    ["type_157_duplicate_address_request"] = "Žádost o duplicitní adresu",
    ["type_158_duplicate_address_confirmation"] = "Potvrzení duplicitní adresy",
    ["type_159_mpl_control_message"] = "Řídicí zpráva MPL",
    ["type_1_destination_unreachable"] = "Cíl nedosažitelný",
    ["type_200_private_experimentation"] = "Soukromé experimentování",
    ["type_201_private_experimentation"] = "Soukromé experimentování",
    ["type_255_reserved_for_expansion_of_icmpv6_informational_messages"] = "Vyhrazeno pro rozšíření informačních zpráv ICMPv6",
    ["type_2_packet_too_big"] = "Paket je příliš velký",
    ["type_3_time_exceeded"] = "Čas byl překročen",
    ["type_4_parameter_problem"] = "Problém s parametrem",
  },
  ["if_stats_config"] = {
    ["companion_interface"] = "Doprovodné rozhraní",
    ["custom_name"] = "Vlastní jméno",
    ["custom_name_popup_msg"] = "Zadejte alias rozhraní",
    ["dump_flows_to_database"] = "Výpis toků do databáze",
    ["hide_from_top_networks"] = "Skrýt před top sítěmi",
    ["hide_from_top_networks_descr"] = "např. %{example}",
    ["interface_network_discovery"] = "Pravidelné zjišťování síťového rozhraní",
    ["interface_one_way_hosts_rrd_creation"] = "Vytvářejte Timeseries jednosměrného provozu",
    ["interface_rrd_creation"] = "Vytvoření časových rozhraní rozhraní",
    ["interface_speed"] = "Rychlost rozhraní (Mbit / s)",
    ["interface_speed_popup_msg"] = "Určete maximální rychlost rozhraní",
    ["interface_top_talkers_creation"] = "Vytvořit rozhraní Top Talkers",
    ["is_mirrored_traffic"] = "Zrcadlový provoz",
    ["scaling_factor"] = "Míra vzorkování vstupních paketů",
    ["scaling_factor_popup_msg"] = "To by mělo odpovídat vzorkovací frekvenci snímacího rozhraní",
    ["show_dyn_iface_traffic"] = "Duplicitní disagregovaný provoz",
    ["show_dyn_iface_traffic_note"] = "Povolením této možnosti bude v hlavním rozhraní stále zobrazen provoz směrovaný na dynamická nebo vlastní dílčí rozhraní",
    ["trigger_interface_alerts"] = "Spouštěcí výstrahy rozhraní",
  },
  ["if_stats_networks"] = {
    ["note_ghost_bcast_domains"] = " %{ghost_icon} zdůrazňuje ghosts vysílací domény (tj. nepatří k žádné ze sítí IP adres rozhraní).",
    ["note_iface_addresses"] = "IP adresy se načítají z konfigurace rozhraní.",
    ["note_iface_bcast_domains"] = "Vysílací domény jsou odvozeny inspekcí ARP provozu.",
  },
  ["if_stats_overview"] = {
    ["active"] = "Aktivní",
    ["all_counters"] = "Všechny čítače",
    ["blocked_flows"] = "Blokované toky",
    ["bridged_traffic"] = "Mostový provoz",
    ["buffer_full"] = "Buffer Full",
    ["collected_flows"] = "Shromážděné toky",
    ["dropped_flows"] = "Přerušené toky",
    ["dropped_packets"] = "Vypuštěné pakety",
    ["drops_only"] = "Pouze vypuštěné",
    ["dumped_files"] = "Zahozené soubory",
    ["dumped_packets"] = "Zahozené pakety",
    ["egress_packets"] = " Odchozí pakety",
    ["exported_flows"] = "Exportované toky",
    ["family"] = "Rodina",
    ["flows_export_statistics"] = "Statistiky exportu toků",
    ["has_traffic_directions"] = "S pokyny RX / TX",
    ["id"] = "Id",
    ["iface_switch_active_msg"] = "Vybrané rozhraní <b>%{interface}</b> [ifid: %{ifid}] je nyní aktivní",
    ["iface_switch_empty_session_msg"] = "Prázdná relace",
    ["iface_switch_error_msg"] = "Chyba při přepínání rozhraní",
    ["in_path_interface"] = "Rozhraní In-Path (Náraz do drátu)",
    ["ingress_packets"] = "Vstupní pakety",
    ["ingress_traffic"] = "Vstupní provoz",
    ["interface_ip"] = "Rozhraní IP",
    ["interface_name"] = "Rozhraní",
    ["interface_rx_updates"] = "Aktualizace rozhraní",
    ["nf"] = "Netfilter",
    ["nf_enobufs"] = "Žádná vyrovnávací paměť",
    ["nf_handle_packet_failed"] = "Selhání zpracování paketů ve frontě",
    ["nf_queue_dropped"] = "Vypuštěné pakety (fronta plná)",
    ["nf_queue_pct"] = "Úroveň naplnění fronty",
    ["nf_queue_total"] = "Pakety ve frontě",
    ["nf_queue_user_dropped"] = "Vypuštěné pakety (nelze je odeslat do uživatelského prostoru)",
    ["note"] = "POZNÁMKA",
    ["note_drop_ifstats_dynamic"] = "Spadlé soubory jsou k dispozici v hlavním rozhraní",
    ["note_drops_sflow"] = "Spadlé soubory jsou zobrazeny pouze pro sFlow, protože je NetFlow nehlásí.<br><A HREF=https://www.ietf.org/rfc/rfc3176.txt>sFlow</A> spadlé soubory počítají, kolikrát agent sFlow zjistil, že je paket označený jako vzorek, tak byl vyřazen kvůli nedostatku zdrojů. Počítadlo spadlých souborů hlásí celkový počet detekovaných selháných souborů od posledního resetu agenta. Vysoká míra poklesu znamená, že agent správy není schopen zpracovat vzorky tak rychle, jak jsou generovány hardwarem. Zvýšení vzorkovací frekvence sFlow sníží rychlost klesání. Poznámka: Agent, který nedokáže detekovat spadlé soubory, bude vždy hlásit nulu.",
    ["note_packets"] = "V ethernetových sítích má každý paket <A HREF=\"https://en.wikipedia.org/wiki/Ethernet_frame\"> režii 24 bytů</A> [preamble (7 bytes), začátek framu (1 byte), CRC (4 bytes), a <A HREF=\"http://en.wikipedia.org/wiki/Interframe_gap\">IFG</A> (12 bytes)]. Takovou režii je třeba započítat do provozu na rozhraní, ale nepřidává se k provozu, který se vyměňuje mezi IP adresami. Je tomu tak proto, že taková data přispívají k zatížení rozhraní, ale nemohou být započítána do provozu, který si vyměňují hostitelé, a proto očekávají malé rozdíly mezi hodnotami provozu mezi hostitelem a rozhraním.",
    ["note_probe_zmq_drops_export_queue_full"] = "Vzdálená sonda tyto toky úspěšně zpracovala, ale nemohla je zařadit do fronty pro export, protože exportní fronta byla plná.",
    ["note_probe_zmq_drops_flow_collection_drops"] = "Pakety s přerušeným tokem (NetFlow v9) nebo přerušené toky (NetFlow v5/IPFIX)",
    ["note_probe_zmq_drops_flow_collection_udp_socket_drops"] = "Vypuštěné tokové pakety na soketu kolekce nProbe",
    ["paused"] = "Pozastaveno",
    ["probe_ip"] = "Sonda IP",
    ["probe_timeout_idle"] = "Časový limit nečinnosti",
    ["probe_timeout_lifetime"] = "Životní časový limit",
    ["probe_zmq_drops_export_queue_full"] = "Plné přerušené toky ve frontě",
    ["probe_zmq_drops_flow_collection_drops"] = "Flow Collection Drops",
    ["probe_zmq_drops_flow_collection_udp_socket_drops"] = "Collection Socket Drops",
    ["probe_zmq_num_endpoints"] = "Koncové body aktivní sondy ZMQ",
    ["probe_zmq_num_flow_exports"] = "Exportované toky",
    ["public_probe_ip"] = "IP veřejné sondy",
    ["received_traffic"] = "Přijatý provoz",
    ["remote_probe"] = "Vzdálená sonda",
    ["remote_probe_collector_mode"] = "Sběratelský režim",
    ["reset_counters"] = "Reset čítačů",
    ["rrd_timeseries"] = "RRD Timeseries",
    ["send_error"] = "Chyba při odesílání",
    ["sflow_counter_updates"] = "Aktualizace čítačů",
    ["shaped_filtered_packets"] = "Shaped / filtrované pakety",
    ["snmp"] = "SNMP",
    ["state"] = "Země / Stát",
    ["traffic_breakdown"] = "Porucha provozu",
    ["traffic_statistics"] = "Statistiky provozu",
    ["zmq_avg_msg_flows"] = "Průměrné toky na zprávu",
    ["zmq_message_drops"] = "Zrušené zprávy ZMQ",
    ["zmq_message_rcvd"] = "Shromážděné zprávy ZMQ",
    ["zmq_rx_statistics"] = "Statistiky ZMQ",
  },
  ["index_page"] = {
    ["applications"] = "Aplikace",
    ["asns"] = "ASNs",
    ["dashboard"] = "Přístrojová deska",
    ["hosts"] = "Hosts / Hostitelé",
    ["live_update"] = "Live update",
    ["minute"] = "Minuta",
    ["never"] = "Nikdy",
    ["no_packet_warning"] = "Na rozhraní zatím nebyl přijat žádný paket %{ifname}.<p> prosím čekejte %{countdown} sekund, než se tato stránka znovu načte.",
    ["refresh"] = "Obnovit",
    ["refresh_frequency"] = "Obnovovací frekvence",
    ["refresh_graph_popup_msg"] = "Aktualizovat graf",
    ["seconds"] = "Sekund",
    ["senders"] = "Odesílatelé",
    ["top_flow_talkers"] = "Top Flow Talkers",
  },
  ["internals"] = {
    ["hash_entries"] = "Hash Entries",
    ["hash_table"] = "Hash Table",
    ["state_idle"] = "Položky ve stavu nečinnosti",
    ["state_ready_to_be_purged"] = "Záznamy ve státě připravené k očištění",
  },
  ["live_capture"] = {
    ["active_live_captures"] = "Živý provoz",
    ["note"] = "Zachyťte živý provoz hostitele %{hostinfo}. Stream se automaticky zastaví po 1 minutě nebo 100 000 paketech.",
  },
  ["live_traffic"] = {
    ["error_generic"] = "Obecná chyba",
    ["error_not_found"] = "Nenalezeno",
    ["error_not_granted"] = "Žádosti nebylo vyhověno",
    ["modal_vlan_tagged_with_bpf_confirmation"] = "Tento hostitel je označen VLAN. Filtr BPF odeslaný, aby správně odpovídal paketům, musí obsahovat VLAN 51. VLAN lze ve filtru zadat jako <br> <pre>vlan %{vlan} and <i>...rest of the filter...</i></pre>",
    ["modal_vlan_tagged_with_bpf_continue"] = "Pokračovat",
    ["modal_vlan_tagged_with_bpf_title"] = "Host pcap Download",
  },
  ["local_flow_matrix"] = {
    ["error_no_local_hosts"] = "Nebyli nalezeni žádní místní hostitelé",
    ["local_flow_matrix"] = "Matice lokálního toku",
    ["local_hosts_active_flows_matrix"] = "Local hosts active flows matrix",
  },
  ["local_hosts_stats"] = {
    ["criteria"] = "Kritéria",
    ["looking_glass"] = "Looking Glass",
  },
  ["locales"] = {
    ["de"] = "Německý",
    ["en"] = "Anglický",
    ["it"] = "Italský",
    ["jp"] = "Japonský",
    ["pt"] = "Portugalský",
  },
  ["login"] = {
    ["add_captive_portal_user"] = "Přidat uživatele zajatého portálu",
    ["add_web_user"] = "Přidat webového uživatele",
    ["auth_success"] = "Ověření úspěšné",
    ["blacklisted_ip_notice"] = "Příliš mnoho neúspěšných pokusů o ověření. Zkuste to prosím znovu po 5 minutách.",
    ["change_password"] = "Změnit heslo",
    ["confirm_password"] = "Potvrďte heslo",
    ["device_label"] = "Štítek zařízení",
    ["donation"] = "Pokud si myslíte, že  je %{product} užitečný, prosím, podpořte nás zde <A href=\"%{donation_url}\">donation</A>. Vaše financování pomůže řídit a podporovat rozvoj tohoto projektu. Děkuji.",
    ["enter_credentials"] = "Zadejte prosím své přihlašovací údaje pro přístup k této síti.",
    ["informative_captive_join"] = "Přístup na internet",
    ["informative_captive_portal_tos"] = "Přečetl jsem a souhlasil s <a target='_blank' href='%{url}'>podmínky služby</a>.",
    ["internet_redirecting"] = "Přesměrujeme vás na internet...",
    ["license"] = "%{product} je propuštěn pod <a href=\"%{license_url}\">%{license}</a>.",
    ["logging_out"] = "Odhlášování...",
    ["login"] = "Přihlásit se",
    ["logout"] = "Odhlásit se",
    ["logout_user_x"] = "Odhlásit %{user}",
    ["must_change_password"] = "Výchozí heslo správce musí být změněno. Níže zadejte nové heslo.",
    ["password"] = "Heslo",
    ["password_mismatch"] = "Hesla se neshodují",
    ["password_not_valid"] = "Zadejte jiné heslo",
    ["password_pattern_error"] = "Zadejte alespoň 5 platných znaků.",
    ["password_ph"] = "Heslo (výchozí správce)",
    ["passwords_dont_match"] = "Hesla se neshodují.",
    ["unsupported_browser"] = "Váš prohlížeč není podporován. <br> Zvažte použití nedávného prohlížeče Firefox nebo Chrome.",
    ["username"] = "Uživatelské jméno",
    ["username_ph"] = "Uživatelské jméno (výchozí správce)",
    ["web_users"] = "Uživatelé webu",
    ["welcome_to"] = "Vítejte v %{product}",
  },
  ["mac_details"] = {
    ["json_error_inactive"] = "Chyba JSON: neaktivní host očištěn nebo %{product} ukončen?",
    ["mac"] = "Mac",
    ["mac_cannot_be_found_message"] = "Mac %{mac} nemůže být nalezen.",
    ["mac_parameter_missing_message"] = "Chybí parametr Mac (interní chyba?)",
    ["reset_mac_stats"] = "Resetování statistik Mac",
    ["reset_mac_stats_note"] = "<b>POZNÁMKA</b>: historické charts pro tuto mac adresu mohou mít po resetu mezeru.",
    ["reset_stats_in_progress"] = "Statistiky Mac budou resetovány do 5 sekund",
  },
  ["mac_stats"] = {
    ["all_devices"] = "Vše",
    ["all_layer_2_devices"] = "Všechna zařízení",
    ["all_manufacturers"] = "Všichni výrobci",
    ["arp_total"] = "ARP",
    ["dev_layer_2_devices"] = "%{device_type} zařízení",
    ["dhcp_only"] = "Jen DHCP",
    ["filter_macs"] = "Filtrujte Mac",
    ["idle_devices_not_listed"] = "Nečinná zařízení nejsou uvedena.",
    ["layer_2_dev_devices"] = "%{device_type} uařízení",
    ["layer_2_devices_with_manufacturer"] = "%{manufacturer} %{title}",
    ["layer_2_source_devices"] = "%{device_type} zařízení",
    ["manufacturer"] = "Výrobce",
    ["source_macs"] = "Pouze zdroj",
  },
  ["manage_data"] = {
    ["all_hosts"] = "Vše",
    ["delete"] = "Odstranit data hostitele",
    ["delete_active_interface"] = "Odstranit data rozhraní",
    ["delete_inactive_interfaces"] = "Odstranit neaktivní data rozhraní",
    ["delete_system_interface_data"] = "Odstraňte data systémového rozhraní",
    ["delete_tab"] = "Odstranit",
    ["export"] = "Export dat hostitele",
    ["export_tab"] = "Export",
    ["hosts"] = "Hosts / Hostitelé",
    ["ip_or_mac_address"] = "IP nebo MAC adresa nebo / 24",
    ["local_hosts"] = "Lokální",
    ["mac_or_ip_required"] = "Vložte prosím platnou adresu IP nebo MAC",
    ["manage_data"] = "Správa dat",
    ["remote_hosts"] = "Vzdálený",
    ["single"] = "Singl",
    ["system_interface_note"] = "Data rozhraní systému zahrnují všechna data umístěná v položce nabídky System, například data CPU, InfluxDB a SNMP.",
  },
  ["manage_users"] = {
    ["add_new_user"] = "Přidat nového uživatele",
    ["administrator"] = "Správce",
    ["allowed_interface"] = "Povolené rozhraní",
    ["allowed_networks"] = "Povolené sítě",
    ["allowed_networks_descr"] = "Seznam sítí oddělených čárkami, které může tento uživatel zobrazit. Například:",
    ["allowed_passwd_charset"] = "Povolené znaky jsou velká a malá písmena, čísla a speciální symboly ISO 8859-1 (latin1)",
    ["any_interface"] = "Jakékoli rozhraní",
    ["authentication_lifetime"] = "Životnost autentizace",
    ["change_user_password"] = "Změnit heslo uživatele",
    ["change_user_preferences"] = "Změnit předvolby uživatele",
    ["confirm_delete_user"] = "Jste si jistí, že chcete smazat %{user}?",
    ["enable_captive_portal"] = "<a href=\"%{url}\">Aktivace zajatého portálu</a> umožňuje definovat uživatele portálu v zajetí",
    ["expires_after"] = "Platnost končí",
    ["group"] = "Skupina",
    ["host_pool_id"] = "ID hostitelského fondu",
    ["manage"] = "Spravovat",
    ["manage_user_x"] = "Spravovat uživatele %{user}",
    ["manage_users"] = "Spravovat uživatele",
    ["new_password"] = "Nové Heslo",
    ["new_password_confirm"] = "Potvrďte nové heslo",
    ["no_host_pools"] = "Nejsou definovány žádné hostitelské fondy. Vytvořte je prosím zde <a href='%{url}'>zde</a>",
    ["non_privileged_user"] = "Uživatel bez oprávnění",
    ["old_password"] = "Staré heslo",
    ["the_auth_can_be_perpetual"] = "Ověřování může být trvalé nebo může vypršet po stanovené době",
    ["the_host_pool_associated"] = "Fond hostitelů, který bude při úspěšném ověření přidružen k uživateli",
    ["unlimited"] = "Neomezený",
    ["user_role"] = "Uživatelská role",
    ["web_captive_users"] = "Uživatelé portálu Web / Captive Portal",
  },
  ["metrics"] = {
    ["days"] = "Dny",
    ["hours"] = "Hodiny",
    ["mins"] = "Minuty",
    ["secs"] = "Sekundy",
  },
  ["ndpi_page"] = {
    ["custom_applications"] = "Vlastní aplikace",
    ["live_flows_count"] = "Počet živých toků",
    ["note"] = "POZNÁMKA",
    ["note_historical_per_protocol_traffic"] = "Historická %{what} provozní data lze povolit prostřednictvím <a href='%{url}'>%{flask_icon} Preference</a>.",
    ["note_live_flows_chart"] = "Tento chart zobrazuje pouze připojení TCP",
    ["note_possible_probing_alert"] = "Ikona jako %{icon} označuje možnou výstrahu sondování (nebo výpadku aplikačního serveru), protože hostitel přijal provoz pro konkrétní aplikaci, aniž by poslal zpět jakákoli data. Můžete použít <A HREF='%{url}'>historické zprávy</A> aby jste podrobněji rozebrali tento problém.",
    ["note_protocol_usage_time"] = "Doba využití aplikace se počítá v diskrétních intervalech slotů.",
    ["overview"] = "%{what} přehled",
    ["rcvd"] = "Rcvd",
    ["received_only"] = "Pouze přijato",
    ["sent"] = "Odesláno",
    ["sent_only"] = "Pouze odesláno",
    ["total_since_startup"] = "Celkem (od spuštění)",
    ["unable_to_find_host"] = "Neschopen najít %{host_ip} (data vypršela?)",
  },
  ["nedge"] = {
    ["a_member_address_is"] = "Členská adresa je pravidlo pro přiřazení zařízení uživateli. Platí následující pořadí:",
    ["a_zero_quota_is_unlimited"] = "Nulová kvóta znamená neomezený provoz.",
    ["active_user"] = "Aktivní uživatel",
    ["add_gateway"] = "Přidat bránu",
    ["add_member"] = "Přidat člena",
    ["add_port_forwarding_rule"] = "Přidat pravidlo předávání portů",
    ["add_routing_policy"] = "Přidat politiku směrování",
    ["add_some_gateways_first"] = "Nejsou definovány žádné brány. Určete některé brány zde <a href=\"%{url}\">zde</a>.",
    ["add_static_lease"] = "Přidat statický pronájem",
    ["add_static_route"] = "Přidat statickou trasu",
    ["add_system_user"] = "Přidat uživatele systému",
    ["add_user_member"] = "Přidat uživatele",
    ["applied_policy"] = "Aplikovaná politika",
    ["apply_and_reboot"] = "Použít a restartovat",
    ["apply_and_restart_self"] = "Použít a restartovat",
    ["apply_configuration"] = "Použít konfiguraci",
    ["apply_configuration_and_reboot"] = "Chystáte se použít novou konfiguraci. Síťová rozhraní budou překonfigurována podle zadaných nastavení a systém bude restartován. Špatné nastavení může způsobit, že systém ztratí připojení IP. Pokračujte pouze v případě, že jste si velmi jistí, že jsou nastavení správná.",
    ["apply_configuration_and_restart_self"] = "Chystáte se použít novou konfiguraci. To způsobí %{product} restartování a může způsobit, že toto webové GUI přestane reagovat na několik sekund.",
    ["apply_the_initial_device_configuration"] = "Použijte počáteční konfiguraci zařízení.",
    ["authentication_gui_and_captive_portal"] = "Metody ověřování platí pro %{product} gui a <a href=\"%{url}\">Captive Portal</a> přístup",
    ["bandwidth_allocation"] = "Přidělení šířky pásma",
    ["bind_to_any"] = "Jakékoli rozhraní",
    ["bind_to_lan"] = "Rozhraní LAN",
    ["cannot_rename_gateway"] = "Nelze přejmenovat bránu.",
    ["cannot_rename_policy"] = "Nelze přejmenovat politiku.",
    ["cannot_rename_static_route"] = "Statickou trasu nelze přejmenovat.",
    ["captive_portal_other_methods"] = "Portál Captive Portal používá metody ověřování definované v <a href=\"%{url}\">Předvolbě ověřování</a> (např. poloměr).",
    ["categories_policies"] = "Politiky kategorií",
    ["configure_routing_policies"] = "Konfigurace politiky směrování",
    ["configured_members"] = "Konfigurovaní členové",
    ["confirm_delete_gateway"] = "Opravdu chcete smazat bránu \"%{gw}\" ?",
    ["confirm_delete_policy"] = "Opravdu chcete politiku odstranit  \"%{policy}\" ?",
    ["confirm_delete_port_forwarding_rule"] = "Opravdu chcete odstranit zadané pravidlo?",
    ["confirm_delete_static_lease"] = "Opravdu chcete smazat \"%{hostname}\" statický pronájem?",
    ["confirm_delete_static_route"] = "Opravdu chcete smazat statickou trasu \"%{sr}\" ?",
    ["confirm_remove_member_from_user"] = "Opravdu chcete člena odebrat %{member} od uživatele %{user}?",
    ["could_not_add_port_forwarding"] = "Nelze přidat pravidlo předávání portů",
    ["custom"] = "Vlastní",
    ["custom_datetime"] = "Aktuální čas",
    ["custom_datetime_descr"] = "Ručně nastavuje datum a čas systému.",
    ["custom_policy"] = "Vlastní politika",
    ["data_reset"] = "Reset dat",
    ["data_reset_msg"] = "Opravdu chcete resetovat všechna data zařízení? Data zahrnují uložené časové úseky, toky, upozornění, Redis cache a čítače hostitele. Reset zařízení nebude mít vliv na konfiguraci zařízení a nastavení systému. <br> To způsobí restartování%{product} a to může způsobit, že toto webové GUI přestane reagovat na několik sekund.",
    ["date_time"] = "Datum a čas",
    ["default_categories"] = "Výchozí politiky kategorií",
    ["default_categories_with_a_defined_policy"] = "Výchozí politika vlastní kategorie",
    ["default_categories_with_a_defined_quota"] = "Výchozí politika kategorií kvót",
    ["default_categories_with_policy_x"] = "Výchozí%{x} politika kategorií",
    ["default_gateway"] = "Výchozí brána",
    ["default_policy"] = "Výchozí politika",
    ["default_protocols"] = "Výchozí politika aplikace",
    ["default_protocols_with_a_defined_policy"] = "Výchozí politika vlastní aplikace",
    ["default_protocols_with_a_defined_quota"] = "Výchozí politika aplikace kvót",
    ["default_protocols_with_policy_x"] = "Výchozí%{x} aplikační politika",
    ["default_shaper"] = "Pass",
    ["default_shaper_descr"] = "Výchozí procento šířky pásma rychlosti rozhraní.",
    ["delete_gateway"] = "Smazat bránu",
    ["delete_policy"] = "Smazat politiku",
    ["delete_port_forwarding_rule"] = "Odstranit pravidlo předávání portů",
    ["delete_static_lease"] = "Odstranit statický lease",
    ["delete_static_route"] = "Smazat statickou trasu",
    ["device_protocol_policy_has_higher_priority"] = "Politika zařízení má vyšší prioritu než politika aplikace.",
    ["device_protocols_blocked_warning"] = "Provoz bude <b>nebude</b> blokován, protože %{device_protocols_policies} jsou zakázány",
    ["device_protocols_policies"] = "Politika zařízení",
    ["dhcp_disabled_warning"] = "Pokud ve vaší síti není k dispozici žádný jiný DHCP server, vaši klienti se nebudou moci automaticky připojit.",
    ["dhcp_first_ip"] = "První IP adresa",
    ["dhcp_first_ip_descr"] = "První adresa IP fondu adres DHCP",
    ["dhcp_last_ip"] = "Poslední IP adresa",
    ["dhcp_last_ip_descr"] = "Poslední adresa IP fondu adres DHCP",
    ["dhcp_server"] = "DHCP Server",
    ["dhcp_server_description"] = "Povolte server DHCP.",
    ["dhcp_server_not_enabled"] = "Server DHCP není povolen. Můžete ho povolit zde <a href=\"%{url}\">zde</a>.",
    ["dns_configuration"] = "Konfigurace DNS",
    ["dns_server_preset"] = "Předvolba serveru DNS",
    ["dns_server_preset_descr"] = "Ze seznamu můžete vybrat vybrané servery DNS nebo určit vlastní servery DNS.",
    ["download_description"] = "Maximální rychlost stahování rozhraní.",
    ["download_speed"] = "Rychlost stahování",
    ["edit_gateway"] = "Upravit bránu",
    ["edit_quotas"] = "Upravit kvóty",
    ["edit_routing_policy"] = "Upravit směrování politiky",
    ["edit_static_route"] = "Upravit statickou trasu",
    ["edit_user"] = "Upravit uživatele",
    ["edit_users"] = "Upravit uživatelé",
    ["enable_device_protocols_policies"] = "Politika aplikací zařízení",
    ["enable_interface"] = "Povolit rozhraní",
    ["enable_interface_descr"] = "Povolení nebo zakázání síťového rozhraní.",
    ["enable_nat"] = "Povolit NAT",
    ["enable_nat_descr"] = "Pokud je povolena, budou IP adresy klientů maqueraded s IP adresou rozhraní WAN.",
    ["enforce_global_dns"] = "Vynutit globální DNS",
    ["enforce_global_dns_description"] = "Povolte Forging DNS, aby zařízení donutila používat zadaný globální DNS.",
    ["enternal_port_overlap"] = "Externí port se překrývá s portem %{port} přiřazen k %{ip}",
    ["external_port"] = "Externí port (WAN)",
    ["external_port_or_range"] = "Externí port nebo rozsah portů",
    ["factory_reset"] = "Obnovení do továrního nastavení",
    ["factory_reset_msg"] = "Opravdu chcete zařízení resetovat do tovární konfigurace? Veškerá konfigurace a data budou ztracena.",
    ["filter_policies"] = "Politika filtrování",
    ["gateway"] = "Brána",
    ["gateway_exists"] = "Brána %{gw} již existuje.",
    ["gateway_interface_descr"] = "Určete síťové rozhraní, které se použije k určení IP adresy brány",
    ["gateway_name"] = "Název brány",
    ["gateway_type"] = "Režim",
    ["gateway_type_address_descr"] = "Zadejte IP adresu brány.",
    ["gateway_x"] = "Brána %{gw}",
    ["gateways"] = "Brány",
    ["gateways_status"] = "Stav brán",
    ["global_dns"] = "Globální DNS",
    ["global_shapers_rates"] = "Globální kontrola šířky pásma",
    ["high_priority"] = "Vysoká priorita",
    ["higher_priority"] = "Vyšší priorita",
    ["hostname"] = "Název hostitele",
    ["hostname_lease_exists"] = "Statický lease s názvem hostitele \"%{hostname}\" již existuje.",
    ["interfaces_configuration"] = "Konfigurace rozhraní",
    ["internal_ip"] = "Interní IP (LAN)",
    ["internal_port"] = "Interní port (LAN)",
    ["internal_port_number"] = "Vnitřní číslo portu",
    ["internal_port_overlap"] = "Interní port se překrývá s %{internal_port} již mapováno na externí port %{external_port}",
    ["invalid_dhcp_range"] = "Neplatný rozsah DHCP. Ujistěte se, že IP adresy DHCP jsou uvnitř rozsahu sítě LAN, jinak vaše zařízení nebude moci procházet web.",
    ["invalid_port_range"] = "Neplatný rozsah portů",
    ["ip_address_takes_preced"] = "IP adresa má přednost před síťovou adresou",
    ["ip_lease_exists"] = "Statický lease s IP \"%{ip}\" již existuje",
    ["lan"] = "LAN",
    ["lan_ip_addr"] = "IP adresa LAN",
    ["lan_ip_addr_descr"] = "Zadejte IP adresu rozhraní LAN.",
    ["lan_recovery_ip"] = "LAN Recovery IP",
    ["lan_recovery_ip_descr"] = "Další adresa IP k dosažení zařízení%{product} v rozhraní LAN.",
    ["lan_recovery_warning"] = "Ujistěte se, že to nekoliduje s žádnou jinou definovanou sítí.",
    ["link_not_ready"] = "Odkaz není připraven",
    ["linkdown"] = "Link Down",
    ["low_priority"] = "Nízká priorita",
    ["lower_priority"] = "Nižší priorita",
    ["mac_address_takes_preced"] = "Mac adresa má přednost před IP adresou",
    ["mac_lease_exists"] = "Statický lease pro Mac \"%{mac}\" již existuje.",
    ["max_bps_per_host"] = "Max %{bps} na hostitele",
    ["max_perc"] = "Max %{perc}%%",
    ["max_rrt"] = "Max RTT",
    ["max_rrt_description"] = "Maximální doba zpáteční cesty směrem k adrese monitoru. Pokud naměřená RTT překročí tuto hodnotu, brána se považuje za spadlou.",
    ["maximum_enforced"] = "Maximální vynucení",
    ["maximum_enforced_descr"] = "Pokud je nastaveno na maximální vynucení, bude maximální přidělování šířky pásma vynuceno bez ohledu na dostupnou šířku pásma.",
    ["member_address"] = "Adresa člena",
    ["member_exists"] = "Člen %{member} nepřidán, protože je již přiřazen k uživateli %{existing_user}",
    ["members"] = "Členové",
    ["members_for_user_x"] = "Členové uživatele %{user}",
    ["min_perc"] = "Min %{perc}%%",
    ["minimum_guaranteed"] = "Minimální zaručená",
    ["minimum_guaranteed_descr"] = "Pokud je nastavena na minimální zaručené, bude zaručeno pouze minimální přidělení šířky pásma.",
    ["mode"] = "Režim",
    ["nedge"] = "nEdge",
    ["network_conf_dhcp"] = "DHCP",
    ["network_conf_iface_descr"] = "Určete režim adresy IP rozhraní.",
    ["network_conf_iface_gw"] = "IP adresa výchozí brány rozhraní (např. 192.168.1.1).",
    ["network_conf_iface_ip"] = "IP adresa rozhraní (např. 192.168.1.10).",
    ["network_conf_iface_nmask"] = "Maska sítě rozhraní (např. 255.255.255.0).",
    ["network_conf_iface_title"] = "%{ifrole} Rozhraní %{ifname}",
    ["network_conf_static"] = "Statický",
    ["network_conf_vlan_trunk"] = "VLAN Trunk",
    ["no_gateways_defined"] = "Nejsou definovány žádné brány.",
    ["no_interfaces_available"] = "Nejsou k dispozici žádná rozhraní.",
    ["no_routing_policies_defined"] = "Nejsou definovány žádné politiky směrování",
    ["no_rules"] = "Bez pravidel",
    ["no_static_leases"] = "Žádné statické leases",
    ["no_static_routes_defined"] = "Není definována žádná statická trasa.",
    ["ntp_sync"] = "NTP Synchronizace",
    ["ntp_sync_descr"] = "Přepněte synchronizaci se serverem NTP.",
    ["per_ip_rates"] = "Řízení šířky pásma na hostitele",
    ["ping_address"] = "Sledovat adresu",
    ["ping_address_description"] = "Adresa, kterou chcete sledovat a ověřit stav brány.",
    ["please_fill_out_this_field"] = "Prosím, vyplňte toto pole.",
    ["policy_due_to_source"] = "%{policy} kvůli %{source}",
    ["policy_name"] = "Název politiky",
    ["port_forwarding"] = "Port Forwarding",
    ["power_off"] = "Vypnout",
    ["power_off_confirm"] = "Opravdu chcete zařízení vypnout?",
    ["priority_x"] = "Přednost %{x}",
    ["protocol_policy_has_higher_priority"] = "Politika aplikace má vyšší prioritu než politika kategorie.",
    ["protocols_policies"] = "Politika aplikace",
    ["reboot"] = "Restartujte",
    ["reboot_corfirm"] = "Chcete zařízení restartovat?",
    ["remove_all_members"] = "Odebrat všechny členy",
    ["remove_all_members_confirm"] = "Opravdu chcete odstranit všechny členy uživatele %{user}?",
    ["reset_and_reboot"] = "Reset a restartování",
    ["reset_and_restart_self"] = "Reset a restartartování",
    ["restrict_weg_gui_access_description"] = "Omezte přístup k tomuto webovému rozhraní pro správu, aby bylo přístupné pouze z rozhraní LAN (bezpečnější) nebo z jakéhokoli rozhraní systému (méně zabezpečené).",
    ["restrict_weg_gui_access_title"] = "Správa přístupu k webovému GUI",
    ["router"] = "Router",
    ["router_mode_requires_enterprise"] = "Režim směrovače je k dispozici pouze v edici nedge Enterprise.",
    ["routing"] = "Směrování",
    ["routing_policies"] = "Politiky směrování",
    ["routing_policy"] = "Politika směrování",
    ["routing_policy_exists"] = "Politika směrování \"%{policy}\" již existuje.",
    ["safe_search_description"] = "Nevhodný obsah blokujte pomocí DNS bezpečného pro děti.",
    ["search_categories"] = "Hledat kategorie",
    ["search_protocols"] = "Prohledat aplikace",
    ["security"] = "Zabezpečení",
    ["set_the_device_mode"] = "Nastavte provozní režim zařízení.",
    ["setup_apply"] = "Aplikovat",
    ["setup_config_edited_descr"] = "Použijte změny, aby byla nová konfigurace účinná, nebo je zahoďte, abyste ji nadále používali.",
    ["setup_config_edited_title"] = "Konfigurace systému byla upravena!",
    ["setup_discard"] = "Zahodit",
    ["setup_mode"] = "Pracovní režim",
    ["setup_network"] = "Síť",
    ["shapers"] = "Řízení šířky pásma",
    ["single_port_router"] = "Single Port Router",
    ["slow_pass_shaper_descr"] = "Procento šířky pásma pomalého průchodu rychlosti rozhraní.",
    ["slower_pass_shaper_descr"] = "Procento pomalejší propustnosti rychlosti rozhraní.",
    ["specify_a_protocol"] = "Určete aplikaci",
    ["static_dhcp_leases"] = "Statické leases serveru DHCP",
    ["static_route_address_descr"] = "Určete cíl pro statickou trasu.",
    ["static_route_exists"] = "Statická trasa %{sr} již existuje.",
    ["static_route_is_local_descr"] = "Určete, zda se jedná o statickou cestu do místní sítě. Všichni hostitelé na statické cestě do místní sítě jsou považováni za místní hostitele.",
    ["static_route_is_local_title"] = "Statická trasa místní sítě",
    ["static_route_name"] = "Statický název trasy",
    ["static_route_netmask_descr"] = "Určete masku sítě, která se použije pro cíl statické trasy.",
    ["static_route_via_descr"] = "Zadejte adresu IP, která se použije jako další směrování pro statickou trasu.",
    ["static_route_x"] = "Statická trasa %{sr}",
    ["static_routes"] = "Statické trasy",
    ["static_routes_in_policies"] = "Statické cesty jsou aplikovány na (a mají přednost před) některou z definovaných <a href=\"%{url}\"> politik směrování</a>.",
    ["status_activate"] = "Aktivovat",
    ["status_connected"] = "Připojeno",
    ["status_connecting"] = "Připojování",
    ["status_deactivate"] = "Deaktivovat",
    ["status_disabled"] = "Vypnuto",
    ["status_disconnected"] = "Odpojeno",
    ["status_down"] = "Down",
    ["status_failed"] = "Selhalo",
    ["status_inactive"] = "Neaktivní",
    ["status_unreachable"] = "Nedostupné",
    ["status_up"] = "Up",
    ["system_setup"] = "Nastavení systému",
    ["system_users"] = "Uživatelé systému",
    ["test_policies"] = "Politika testování",
    ["test_policies_page_description"] = "Tato stránka může být použita k ověření, jaké budou politiky použité na internetu %{user} zařízení na základě aktuální konfigurace.",
    ["the_fallback_policy"] = " <a href=\"%{url}\">Záložní politika</a> se použije, když je nastavena jako uživatel, tak globální politika pro danou aplikaci a její odpovídající kategorii \"Výchozí\".",
    ["the_not_assigned_user_contains"] = " \"Nepřiřazené\" uživatele lze použít k definování politiky pro zařízení, která nejsou přiřazena žádnému uživateli.",
    ["the_primary_dns_server"] = "Primární server DNS",
    ["the_secondary_dns_server"] = "Sekundární server DNS",
    ["timezone"] = "Časové pásmo",
    ["timezone_descr"] = "Nastavuje časové pásmo systému.",
    ["upload_description"] = "Maximální rychlost odesílání rozhraní.",
    ["upload_speed"] = "Rychlost nahrávání",
    ["user"] = "Uživatel",
    ["user_categories"] = "Politika kategorií pro uživatele %{user}",
    ["user_categories_with_a_defined_policy"] = "Politika vlastní kategorie pro uživatele %{user}",
    ["user_categories_with_a_defined_quota"] = "Politika kategorií kvót pro uživatele %{user}",
    ["user_categories_with_policy_x"] = "%{x} Politika kategorií pro uživatele %{user}",
    ["user_category_policies"] = "Politika kategorií uživatele",
    ["user_device_protocols"] = "Politika aplikace pro aplikační politiky pro %{user} zařízení",
    ["user_protocols"] = "Politika aplikace pro uživatele %{user}",
    ["user_protocols_with_a_defined_policy"] = "Vlastní aplikační politiky pro uživatele %{user}",
    ["user_protocols_with_a_defined_quota"] = "Politika aplikace kvót pro uživatele %{user}",
    ["user_protocols_with_policy_x"] = "%{x} Politika aplikace pro uživatele %{user}",
    ["users_list"] = "Seznam uživatelů",
    ["view_quotas"] = "Zobrazit kvóty",
    ["wan"] = "WAN",
    ["wan_interface"] = "WAN Rozhrání",
    ["with_quota"] = "S kvótou",
    ["x_shaper_per_host_descr"] = " %{shaper} maximální přidělení šířky pásma na hostitele. 0 je pro neomezené.",
    ["you_can_assign_routing_policy"] = "Můžete přiřadit politiky směrování <a href=\"%{url}\">uživatelům </a>.",
    ["you_can_assign_shapers_to_users_protocols"] = "Můžete přiřadit politiku šířky pásma <a href=\"%{url}\">uživatelům</a> konkrétní aplikace nebo je nastavit globálně jako <a href=\"%{url2}\">Záložní politika</a>.",
    ["you_can_set_static_dhcp_lease_here"] = "Můžete nakonfigurovat statické leases DHCP zde <a href=\"%{url}\">zde</a>.",
    ["you_can_use_gateways_in_policies"] = "Priority bran můžete určit v <a href=\"%{url}\">politikách směrování</a>.",
    ["policy_source_labels"] = {
      ["policy_source_category"] = "Politika kategorií",
      ["policy_source_default"] = "Neznámý",
      ["policy_source_device_protocol"] = "Politika aplikace zařízení",
      ["policy_source_pool"] = "Výchozí politika",
      ["policy_source_protocol"] = "Politika aplikace",
    },
  },
  ["network_alert_config"] = {
    ["trigger_alerts_for_network"] = "Spusťte výstrahy pro síť %{network}",
    ["trigger_network_alerts"] = "Spusťte výstrahy sítě",
  },
  ["network_details"] = {
    ["network"] = "Síť",
    ["network_alias"] = "Alias sítě",
    ["network_parameter_missing_message"] = "Chybí parametr sítě (interní chyba?)",
    ["no_available_stats_for_network"] = "Žádné dostupné statistiky pro síť %{network}",
  },
  ["network_stats"] = {
    ["network_list"] = "Seznam sítí",
    ["network_name"] = "Jméno sítě",
    ["networks"] = "Sítě",
    ["networks_traffic_with_ipver"] = "%{networks} s IPv%{ipver} provozem",
    ["note_broader_network"] = "Širší síť nebude zahrnovat hostitelé definované v menších sítích.",
    ["note_overlapping_networks"] = "<b>POZNÁMKA</b>:V případě, že jste definovali překrývající se sítě:",
    ["note_see_both_network_entries"] = "Ve výše uvedené tabulce uvidíte obě síťové položky.",
  },
  ["os_stats"] = {
    ["hosts_by_operating_system"] = "Hostitelé podle operačního systému",
  },
  ["packets_page"] = {
    ["arp_distribution"] = "Distribuce ARP",
    ["ip_version_distribution"] = "Distribuce verze IP",
    ["lost"] = "Ztracený",
    ["out_of_order"] = "Mimo provoz",
    ["received_distribution"] = "Přijatá distribuce",
    ["retransmissions"] = "Opakované přenosy",
    ["sent_distribution"] = "Odeslána distribuce",
    ["sent_vs_rcvd_distribution"] = "Sent / Rcvd Distribuce",
    ["size_distribution"] = "Distribuce velikosti",
    ["tcp_flags_distribution"] = "Distribuce příznaků TCP",
    ["tcp_flags_vs_arp_distribution"] = "TCP Flags / ARP Distribuce",
    ["tcp_packets_analysis"] = "Analýza paketů TCP",
    ["version_vs_flags_distribution"] = "IP version / TCP Flags Distribuce",
  },
  ["peers_page"] = {
    ["host"] = "Host",
    ["no_active_flows_message"] = "Pro zadaného hostitele nebyly zpozorovány žádné aktivní toky",
    ["top_peer_protocol"] = "Top aplikace Peer",
    ["top_peers_for_host"] = "Top %{hostkey} Peers",
    ["traffic_volume"] = "Traffic Volume",
  },
  ["please_wait_page"] = {
    ["command"] = "Příkaz",
    ["database"] = "Databáze",
    ["host"] = "Host / Hostitel",
    ["id"] = "Id",
    ["info"] = "Info",
    ["operations_on_database_msg"] = "Aktuálně prováděné operace v databázi jsou následující:",
    ["state"] = "Stav",
    ["time"] = "Čas",
    ["user"] = "Uživatel",
    ["waiting_for_db_msg"] = "Probíhá migrace schématu databáze, čekání na databázi <b>%{dbname}</b> aby byla funkční. Jakmile bude databáze připravena, budete přesměrováni. V závislosti na velikosti existující databáze může tato operace trvat dlouho. Migrace se provádí pouze jednou a pouze během hlavních upgradů verzí. Pokud máte pochybnosti, kontaktujte vývojáře na adrese <a href='mailto:info@ntop.org'>info@ntop.org</a>.",
  },
  ["policy_presets"] = {
    ["business"] = "Podnikání",
    ["business_description"] = "Předvolba pro zaměstnance obchodní společnosti",
    ["child"] = "Dítě",
    ["child_description"] = "Předvolba pro děti. Blokuje sociální sítě a omezuje herní čas",
    ["default"] = "Výchozí",
    ["guests"] = "Hosté",
    ["guests_description"] = "Předvolba pro hosty. Povolena je pouze základní navigace",
    ["no_obfuscation"] = "Žádné zmatení",
    ["no_obfuscation_description"] = "Předvolba, která zabrání zmatení provozu",
    ["walled_garden"] = "Walled Garden",
    ["walled_garden_description"] = "Blokuje VPN a sociální sítě",
  },
  ["pool_details"] = {
    ["host_pool"] = "Hostitelský fond",
    ["host_pool_timeseries_enable_message"] = "Časový rozvrh hostitelského fondu lze povolit z <A HREF=\"%{url}\">%{icon_flask} Preference</A>. K zobrazení prvních datových bodů je třeba jen pár minut.",
    ["no_available_data_for_host_pool_message"] = "Pro hostitelský fond nejsou k dispozici žádná data '%{pool_name}'.",
    ["pool_parameter_missing_message"] = "Chybí parametr (interní chyba?)",
  },
  ["pool_stats"] = {
    ["host_pool_list"] = "Seznam hostitelských fondů",
  },
  ["port_details"] = {
    ["active_flows_for_host_and_port"] = "Aktivní toky pro %{host}:%{port}",
    ["active_flows_on_port"] = "Aktivní toky na portu %{port}",
    ["active_flows_on_port_symbolic"] = "Aktivní toky na portu %{port} [%{symbolic_port}]",
    ["l4_port"] = "L4 Port",
  },
  ["ports_page"] = {
    ["client_ports"] = "Klientské porty",
    ["server_ports"] = "Porty serveru",
  },
  ["prefs"] = {
    ["active_local_host_cache_interval_description"] = "Interval mezi po sobě jdoucími výpisy z mezipaměti aktivníhi místního hostitele. Výchozí: 1 hodina.",
    ["active_local_host_cache_interval_title"] = "Interval mezipaměti místního hostitele",
    ["admin_group_description"] = "Název skupiny, do které se musí uživatel patřit, aby se mohl autentizovat jako správce.",
    ["admin_group_title"] = "LDAP Admin Group",
    ["alert_entity"] = "Varovná entita",
    ["alerts_notifications"] = "Koncové body výstrah",
    ["alerts_retention"] = "Uchovávání výstrah",
    ["alerts_settings"] = "Nastavení výstrah",
    ["all"] = "Vše",
    ["auth_methods_order"] = "Pořadí ověření metod ověření je stejné jako výše uvedené pořadí výpisu, např. pokud jsou povoleny jako LDAP, tak i místní autorizace, LDAP bude nejprve zkontrolována a pokud selže autentizace, bude dále zkontrolována lokální autorizace.",
    ["authentication"] = "Ověřování",
    ["authentication_duration"] = "Doba autentizace",
    ["authentication_duration_descr"] = "Doba, po které je relace ověřeného uživatele ukončena a je nutné znovu autentizovat. Změny ovlivní pouze nově vytvořené relace.",
    ["authentication_duration_title"] = "Trvání ověřené relace",
    ["authentication_midnight_expiration_descr"] = "Přepíná ukončení relací o půlnoci a nutí všechny autentizované uživatele, aby se znovu autentizovali po půlnoci.",
    ["authentication_midnight_expiration_title"] = "Ověřené ukončení relace o půlnoci",
    ["bind_dn_description"] = "Vázat rozlišující název serveru LDAP. Příklad:",
    ["bind_dn_title"] = "LDAP Bind DN",
    ["bind_pwd_description"] = "Bind heslo používané k ověření pomocí serveru LDAP.",
    ["bind_pwd_title"] = "LDAP Bind ověřovací heslo",
    ["both"] = "Oba",
    ["cache_settings"] = "Nastavení mezipaměti",
    ["captive_portal_disabled_message"] = "Toto tlačítko je <b>vypnuté</b> ,protože webové GUI ntopng NENÍ spuštěno na portu 80, který je vyžadován portálem v zajetí (parametr příkazového řádku -w, např. -w 80,3000).",
    ["captive_portal_url_description"] = "Adresa URL, na kterou budou vaši klienti přesměrováni po úspěšné autentizaci portálu",
    ["captive_portal_url_title"] = "Adresa URL přesměrování",
    ["client_x509_auth"] = "Ověření klienta HTTPS",
    ["client_x509_auth_descr"] = "Přepněte ověřování klientů na základě jejich certifikátu X.509. Pokud se klient X.509 Common Name (CN) rovná jednomu z uživatelů ntopng, je klient autentizován jako uživatel ntopng. Změny tohoto nastavení vyžadují restartování ntopng.",
    ["client_x509_auth_title"] = "Ověření certifikátu klienta X.509",
    ["could_not_contact_influxdb"] = "Nelze kontaktovat databázi InfluxDB: %{msg}",
    ["data_retention"] = "Uchovávání dat",
    ["data_retention_descr"] = "Počet dní, po které se budou uchovávat dumpingové toky, historické časy a Top Talkers. Výchozí: 30 dní.",
    ["default_snmp_community_description"] = "Výchozí komunita SNMP se používá při pokusu o procházení SNMP MIB vybraného lokálního hostitele, který nebyl nakonfigurován na stránce zařízení SNMP..",
    ["default_snmp_community_title"] = "Výchozí komunita SNMP",
    ["default_snmp_proto_version_description"] = "Výchozí verze protokolu SNMP.",
    ["default_snmp_proto_version_title"] = "Výchozí verze SNMP",
    ["device_identifier"] = "Identifikátor zařízení",
    ["device_identifier_descr"] = "Obvykle jsou zařízení identifikována pomocí MAC adresy. Pokud jsou však zařízení za routerem, je místo toho identifikovatelná IP adresa.",
    ["disable_alerts_generation_description"] = "Přepněte celkové generování výstrah.",
    ["disable_alerts_generation_title"] = "Povolit upozornění",
    ["dns"] = "DNS",
    ["dns_service"] = "Servis",
    ["dump_settings"] = "Výpis databáze toku",
    ["dynamic_interfaces_creation_description"] = "Aktivovat Alertsntopng může pomocí kritéria rozdělit příchozí provoz. Když je vybráno kritérium rozdělování, ntopng použije hodnotu kritéria k přesměrování příchozího provozu na dynamicky vytvořená rozhraní. Například při výběru kritéria „VLAN Id“ bude pro každé pozorované ID VLAN vytvořeno dynamické rozhraní a příchozí provoz bude přesměrován na jedno dynamické rozhraní v závislosti na hodnotě ID VLAN.",
    ["dynamic_interfaces_creation_note_0"] = "Rozdělení VLAN Id je podporováno jak pro fyzická rozhraní, tak pro toky přijaté přes ZMQ. Ostatní kritéria pro rozdělování jsou podporována pouze pro toky ZMQ a pro fyzická rozhraní nebudou účinná.",
    ["dynamic_interfaces_creation_note_1"] = "Změny kritérií neovlivní stávající rozhraní. <b>A Aby se změna projevila, je nutné restartovat ntopng</b>.",
    ["dynamic_interfaces_creation_note_2"] = "Při použití kritéria „Ingress Interface“ na zařízeních bez proudu, %%INPUT_SNMP se musí objevit v nprobe šabloně.",
    ["dynamic_interfaces_creation_note_3"] = "'Rozdělovací kritérium rozhraní přidává jakýkoli tok do dvou dynamických rozhraní. Hodnota %%INPUT_SNMP se používá k výběru prvního dynamického rozhraní, zatímco hodnota %% OUTPUT_SNMP se používá k výběru druhého.",
    ["dynamic_interfaces_creation_note_4"] = "Vlastní disagregace provozu pomocí filtrů typu BPF je k dispozici také deaktivací dynamického disagregace provozu (nastaveno na „Žádná“) na kartě Vlastní disagregace provozu.",
    ["dynamic_interfaces_creation_title"] = "Dynamická disagregace provozu",
    ["dynamic_network_interfaces"] = "Dynamická síťová rozhraní",
    ["elephant_flow_local_to_remote_bytes_description"] = "Množství dat, které může tok nahrát, než se považuje za Elephant Tok",
    ["elephant_flow_local_to_remote_bytes_title"] = "Prahová hodnota Elephant Toků  (místní až vzdálené)",
    ["elephant_flow_remote_to_local_bytes_description"] = "Množství dat, které může tok stáhnout, než se považuje za Elephant Tok",
    ["elephant_flow_remote_to_local_bytes_title"] = "Práhová hodnota Elephant Toků (místní až vzdálené)",
    ["email_notification"] = "Email upozornění",
    ["email_notification_recipient_description"] = "E-mailová adresa příjemce.",
    ["email_notification_recipient_title"] = "Příjemce",
    ["email_notification_sender_description"] = "E-mailová adresa odesílatele.",
    ["email_notification_sender_title"] = "Odesílatel",
    ["email_notification_server_description"] = "Server SMTP k doručení e-mailu.",
    ["email_notification_server_title"] = "SMTP Server",
    ["email_send_error"] = "Chyba při odesílání e-mailu. Podívejte se prosím na <a href='%{url}'>online dokumentaci</a> pro více podrobností.",
    ["email_sent_successfully"] = "Email úspěšně odeslán",
    ["errors"] = "Chyby",
    ["errors_and_warnings"] = "Chyby a varování",
    ["ewma_alpha_percent_description"] = "Exponentially Weighted Moving Average (EWMA) alpha coefficient,vyjádřeno v procentech. Používá se k odhadu doby zpoždění autonomních systémů.",
    ["ewma_alpha_percent_title"] = "EWMA alfas koeficient (v procentech)",
    ["expert_view"] = "Expert View",
    ["featured_dns_description"] = "Následuje seznam zabezpečených serverů DNS. Můžete je použít jako globální servery DNS nebo jako poskytovatele bezpečí pro dítě",
    ["featured_dns_title"] = "Doporučené servery DNS",
    ["flow_interface"] = "Rozhrání",
    ["flow_max_idle_description"] = "Čas nečinnosti, po kterém je tok považován za nečinný. Účinné pouze pro rozhraní paketů. U rozhraní ZMQ je časový limit stanoven automaticky. Výchozí: 1 min.",
    ["flow_max_idle_title"] = "Flow Idle Timeout",
    ["flows_dump_limited_days"] = "Výpis toku je omezen na %{days} dnů v této verzi ntopng. Chcete-li tento limit odstranit, upgradujte na podnikovou verzi.",
    ["global_dns_description"] = "Server DNS pro přesměrování požadavků klientů DNS na hostitelské fondy, které nejsou bezpečné pro děti. Pokud je prázdné, přesměrování je zakázáno a použije se výchozí DNS.",
    ["global_dns_title"] = "Global Primary DNS",
    ["google_apis_browser_key_description"] = "Geomapy grafických hostitelů jsou založeny na rozhraní API Map Google. Google nedávno změnil politiku přístupu k rozhraní Maps API a nyní vyžaduje, aby byl pro každou žádost odeslán klíč API prohlížeče. Podrobné informace o tom, jak získat klíč API, lze nalézt zde <a href=\"%{url}\">zde</a>. Jakmile je klíč API získán, lze jej vložit do tohoto pole.",
    ["google_apis_browser_key_title"] = "Klíč prohlížeče Google APIs Browser Key",
    ["host_mask"] = "IP adresy hostitele masky",
    ["http_auth"] = "Ověřování HTTP",
    ["http_auth_server_description"] = "URL serveru HTTP, který se použije k ověření uživatelů.",
    ["http_auth_server_title"] = "HTTP Server",
    ["idle_timeout_settings"] = "Nastavení časového limitu nečinnosti",
    ["ignored_interfaces_description"] = "Pokud je jako kritérium rozčlenění vybráno „Ingress Interface“, nepřidávejte do dynamického rozhraní žádný tok, který má jeho %%INPUT_SNMP v tomto seznamu. Pokud je vybrána „Rozdělení rozhraní“, nepřidávejte do prvního (druhého) dynamického rozhraní žádný tok, který má jeho %%INPUT_SNMP (%%OUTPUT_SNMP) v tomto seznamu. Určete jeden nebo více ID čárek rozhraní SNMP oddělených čárkami. Změny vyžadují restartování%{product}.",
    ["ignored_interfaces_title"] = "Ignorovaná rozhraní",
    ["incompatible_influxdb_version_found"] = "Nekompatibilní verze InfluxDB: povinné \"%{required}\", found \"%{found}\". Nainstalujte prosím aktualizovanou verzi z <a href='%{url}'> oficiální stránky</a>.",
    ["influxdb_auth_description"] = "Povolit ověřování InfluxDB.",
    ["influxdb_auth_title"] = "Ověřování InfluxDB",
    ["influxdb_create_error"] = "Nelze vytvořit \"%{db}\" databáze: %{msg}",
    ["influxdb_dbname_description"] = "Databáze, která se použije pro ukládání časových řad. Stávající data nebudou migrována.",
    ["influxdb_dbname_title"] = "InfluxDB Databáze",
    ["influxdb_password_description"] = "Heslo k ověření pomocí databáze InfluxDB.",
    ["influxdb_retention_error"] = "Nelze nastavit politiku uchování databáze \"%{db}\": %{msg}",
    ["influxdb_storage_note"] = "<b>POZNÁMKA</b>: data budou vymazána v intervalech %{interval}, což odpovídá InfluxDB <a href='%{url}'>době Shard</a>.",
    ["influxdb_url_description"] = "URL směřující na běžící instanci InfluxDB.",
    ["influxdb_url_title"] = "InfluxDB URL",
    ["influxdb_username_description"] = "Uživatelské jméno pro ověření pomocí databáze InfluxDB.",
    ["ingress_flow_interface"] = "Vstupní rozhraní",
    ["ingress_vrf_id"] = "Vstupní VRF Id",
    ["interfaces_timeseries"] = "Rozhraní Timeseries",
    ["internal_log"] = "Interní protokol",
    ["is_influxdb_running"] = "Je InfluxDB spuštěn?",
    ["l2_devices_timeseries"] = "Zařízení Timeseries",
    ["ldap_authentication"] = "Ověřování LDAP",
    ["ldap_server_address_description"] = "IP adresa a port serveru LDAP (např. Ldaps: // localhost: 636). Výchozí: \"ldap://localhost:389\".",
    ["ldap_server_address_title"] = "Adresa serveru LDAP",
    ["license"] = "Licence",
    ["local_auth"] = "Místní ověřování",
    ["local_host_cache_duration_description"] = "Čas, po kterém je lokální hostitel z meipaměti. Výchozí: 1 hodina.",
    ["local_host_cache_duration_title"] = "Trvání mezipaměti místního hostitel",
    ["local_host_mask"] = "Mask Local Hosts",
    ["local_host_max_idle_description"] = "Čas nečinnosti, po kterém je místní hostitel považován za nečinného (s). Nečinní místní hostitelé jsou uloženi do mezipaměti, takže jejich čítače mohou být obnoveny v případě, že se znovu aktivují. Čítače zahrnují, ale nejsou omezeny na pakety a bajty celkem a na aplikaci Layer-7. Výchozí: 5 min.",
    ["local_host_max_idle_title"] = "Časový limit místního nečinného hostitele",
    ["local_hosts_cache_settings"] = "Nastavení mezipaměti místních hostitelů",
    ["local_hosts_timeseries"] = "Timeseries místních hostitelů",
    ["logging"] = "Přihlašování",
    ["longlived_flow_duration_description"] = "Minimální doba trvání toku, která má být považována za dlouhodobý tok.",
    ["longlived_flow_duration_title"] = "Doba trvání dlouhodobých toků",
    ["max_num_alerts_per_entity_description"] = "Maximální počet výstrah na poplachovou entitu. Alarmovatelnými entitami jsou hostitelé, sítě, rozhraní. Výstrahy jsou pravidelně kontrolovány a v případě, že skutečný počet výstrah překročí maximální počet pro danou entitu, nejstarší výstrahy budou vymazány, aby se zachoval počet výstrah rovnajících se 80 %% maximálního nakonfigurovaného počtu. Výchozí: 1024.",
    ["max_num_alerts_per_entity_title"] = "Maximální počet upozornění na entitu",
    ["max_num_bytes_per_tiny_flow_description"] = "Maximální počet bajtů, aby tok byl považován za malý tok. Výchozí: 64.",
    ["max_num_bytes_per_tiny_flow_title"] = "Maximální počet bajtů na malý tok",
    ["max_num_flow_alerts_description"] = "Maximální počet výstrah toku. Výstrahy jsou pravidelně kontrolovány a v případě, že skutečný počet výstrah toku překročí nakonfigurovaný maximální počet, nejstarší výstrahy budou odstraněny, aby se zachoval počet výstrah rovnajících se 80 %% maximálního nakonfigurovaného počtu. Výchozí: 16384.",
    ["max_num_flow_alerts_title"] = "Maximální počet výstrah toku",
    ["max_num_packets_per_tiny_flow_description"] = "Maximální počet paketů, aby byl tok považován za malý tok. Výchozí: 3.",
    ["max_num_packets_per_tiny_flow_title"] = "Maximální počet paketů na malý tok",
    ["max_ui_strlen_description"] = "Zkraťte řetězce aby jich bylo míň než je zadaný maximální počet znaků.",
    ["max_ui_strlen_title"] = "Maximální zobrazená délka řetězce",
    ["mgmt_acl_title"] = "Seznam řízení přístupu",
    ["misc"] = "Různé",
    ["multiple_ldap_account_type_description"] = "Vyberte typ účtu",
    ["multiple_ldap_account_type_title"] = "Typ účtů LDAP",
    ["multiple_timeseries_database_description"] = "Ovladač se používá pro ukládání a načítání dat časové řady.",
    ["multiple_timeseries_database_title"] = "Ovladač Timeseries",
    ["mysql"] = "MySQL",
    ["n2disk_license_description"] = "Průběžné zaznamenávání provozu vyžaduje licenci n2disk, jednu si zakupte na adrese <a href=\"%{purchase_url}\">e-shop</a>. Pokud jste nezisková, výzkumná nebo vzdělávací instituce, přečtěte si prosím <a href=\"%{universities_url}\">toto</a>.",
    ["n2disk_license_systemid"] = "SystemID: %{systemid}",
    ["n2disk_license_title"] = "Licenční klíč n2disk",
    ["n2disk_license_version"] = "n2disk verze: %{version}",
    ["n2n_supernode_description"] = "Adresa <a class='ntopng-external-link' href=\"%{url}\">n2n <i class=\"fas fa-external-link-alt\"></i></a> supernode. Nastavte si vlastní supernod, abyste měli plně soukromý vzdálený přístup.<br><b>POZNÁMKA</b>: tato změna se projeví až po restartování služby vzdálená asistance.",
    ["n2n_supernode_title"] = "Supernode",
    ["network_discovery"] = "Objevy sítí",
    ["network_discovery_interval_description"] = "Interval mezi po sobě jdoucími objevy sítí. Výchozí: 15 min.",
    ["network_discovery_interval_title"] = "Interval zjišťování sítě",
    ["network_interfaces"] = "Síťová rozhraní",
    ["no_host_mask"] = "Nemaskuj hostitele",
    ["non_local_host_max_idle_description"] = "Čas nečinnosti, po kterém je vzdálený hostitel považován za nečinného. Výchozí: 1 min.",
    ["non_local_host_max_idle_title"] = "Vzdálená doba nečinnosti hostitele",
    ["none"] = "Žádný",
    ["note_timeseries_resolution_disabled"] = "<b>POZNÁMA</b>: to je zakázáno, protože \"%{pref}\" není nastavena na výchozí hodnotu.",
    ["note_update_frequency_disabled"] = "<b>POZNÁMKA</b>: toto je zakázáno kvůli \"%{pref}\" požadavku.",
    ["other_timeseries"] = "Other Timeseries",
    ["per_category"] = "Na kategorie",
    ["per_protocol"] = "Na aplikace",
    ["policy_target_type"] = "Typ cíle politiky",
    ["policy_target_type_description"] = "Určete, jaký druh cíle politiky chcete použít.",
    ["posix"] = "Posix",
    ["preferences"] = "Preference",
    ["primary_dns"] = "Primary DNS",
    ["probe_ip_address"] = "Sonda IP",
    ["protocols"] = "Aplikace",
    ["radius_admin_group_description"] = "Uživatel je autentizován jako administrátor, když hodnota párů Filtr-ID atribut-hodnota vrácená RADIUS odpovídá hodnotě uvedené v tomto poli. Pokud neexistuje shoda, je uživatel ověřen jako neprivilegovaný.",
    ["radius_admin_group_title"] = "ID správce filtru RADIUS",
    ["radius_auth"] = "RADIUS Authentication",
    ["radius_secret_descroption"] = "Sdílené tajemství pro ověření se serverem RADIUS.",
    ["radius_secret_title"] = "RADIUS tajemství",
    ["radius_server_description"] = "Hostitel a port serveru RADIUS (např.%{Example}).",
    ["radius_server_title"] = "Adresa serveru RADIUS",
    ["recording"] = "Záznam provozu",
    ["remote_host_mask"] = "Mask Remote Hosts",
    ["report"] = "Nahlásit",
    ["restart_needed"] = "Prosím restartujte %{product} za účelem provedení změn",
    ["runtime_prefs"] = "Předvolby procesu",
    ["safe_search_dns_description"] = "Server DNS, který se má použít k provedení <a href='%{url}'>Child Safe</a> dotazu.<br>Child Safe lze povolit pro jednotlivé host fondy z konfigurační stránky hostitelských fondů. Výchozí: 208.67.222.123.",
    ["safe_search_dns_title"] = "DNS bezpečné pro děti",
    ["samaccount"] = "sAMAccount",
    ["search_path_description"] = "Kořenová cesta používaná k vyhledávání uživatelů.",
    ["search_path_title"] = "Vyhledávací cesta LDAP",
    ["search_preferences"] = "Předvolby vyhledávání",
    ["secondary_dns"] = "Sekundární DNS",
    ["secondary_dns_description"] = "Záložní server DNS, který se použije, když globální primární server DNS není k dispozici.",
    ["secondary_dns_title"] = "Globální sekundární DNS",
    ["security_alerts"] = "Bezpečnostní upozornění",
    ["send_test_mail"] = "Odeslat zkušební e-mail",
    ["send_test_slack"] = "Odeslat testovací zprávu",
    ["send_test_webhook"] = "Odeslat testovací zprávu",
    ["sender_username_description"] = "Nastavení uživatelského jména odesílatele nevybavených oznámení",
    ["sender_username_title"] = "Uživatelské jméno odesílatele oznámení",
    ["simple_view"] = "Jednoduché zobrazení",
    ["slack_channel"] = "Slack Channel",
    ["slack_channel_names"] = "Názvy kanálů",
    ["slack_channel_names_descr"] = "Nakonfigurujte Slack kanály, na které budou zasílány jednotlivé výstrahy. Aby bylo možné výstrahu správně zobrazit, musí existovat kanály.",
    ["slack_integration"] = "Slack Integration",
    ["slack_notification_severity_preference_description"] = "Chyby (pouze chyby), Chyby a varování (chyby a varování, žádné informace), Vše (budou upozorňovány všechny druhy upozornění).",
    ["slack_notification_severity_preference_title"] = "Závažnost oznámení",
    ["slack_send_error"] = "Chyba při odesílání zprávy Slack.",
    ["slack_sent_successfully"] = " Slack zpráva byla odeslána do #%{channel} kanálu.",
    ["slack_webhook_description"] = "Zašlete své oznámení na tuto Slack adresu URL",
    ["slack_webhook_title"] = "Oznámení Webhook",
    ["snmp"] = "SNMP",
    ["snmp_port_load_threshold_description"] = "Nastavte práhovou hodnotu (jako procento rychlosti portu), aby se spouštěla upozornění, když zatížení portu překročí zadaný limit (v průměru 5 minut).",
    ["snmp_port_load_threshold_title"] = "Varování prahové hodnoty zatížení rozhraní",
    ["stats_reset"] = "Reset statistik",
    ["status_alerts"] = "Stavová upozornění",
    ["successfully_connected_influxdb"] = "Úspěšně inicializovaná databáze \"%{db}\" na InfluxDB(%{version})",
    ["syslog_alert_format_description"] = "Vyberte výstupní formát výstrah syslog.",
    ["syslog_alert_format_json"] = "JSON",
    ["syslog_alert_format_plaintext"] = "Prostý text",
    ["syslog_alert_format_title"] = "Formát upozornění na Syslog",
    ["syslog_notification"] = "Syslog Notification",
    ["telemetry"] = "Telemetrie",
    ["telemetry_contribute"] = "Přispět",
    ["telemetry_do_not_contribute"] = "Nepřispívat",
    ["telemetry_email_description"] = "Uveďte e-mailovou adresu, pokud chcete být kontaktováni týmem ntop v případě zjištění anomálií v telemetrii. ntop vás nebude moci identifikovat, pokud tuto informaci nezadáte.",
    ["telemetry_email_title"] = "Kontakt",
    ["timeseries"] = "Timeseries",
    ["timeseries_database"] = "Databáze Timeseries",
    ["timeseries_resolution_resolution_description"] = "Interval mezi datovými body po sobě jdoucích časů pro místní hostitele. Účinné pouze pro rozhraní paketů.<br><b>POZNÁMKA</b>:<ul><li>Lze nastavit retenční časy Timeseries <A HREF=\"prefs.lua?tab=retention\">zde</a></li></ul>",
    ["timeseries_resolution_resolution_title"] = "Rozlišení Timeseries",
    ["toggle_access_log_description"] = "Přepnout vytvoření protokolu přístupu HTTP v adresáři výpisu dat. Nastavení se projeví po příštím %{product} spuštění.",
    ["toggle_access_log_title"] = "Povolit protokol přístupu HTTP",
    ["toggle_active_local_host_cache_enabled_description"] = "Přepnout vytváření položek mezipaměti pro aktivní místní hostitele. Pravidelné ukládání do mezipaměti aktivních místních hostitelů může být užitečné pro ochranu čítačů hostitele před poruchami (např. Ztrátami energie). To je zvláště důležité pro místní hostitele, kteří jsou jen zřídka nečinní, protože zaručuje, že jejich čítače budou uloženy v mezipaměti po zadaném časovém intervalu.",
    ["toggle_active_local_host_cache_enabled_title"] = "Vyrovnávací paměť aktivních místních hostitelů",
    ["toggle_alert_probing_description"] = "Přepnout upozornění generovaná při detekci pokusů o sondování.",
    ["toggle_alert_probing_title"] = "Upozornění na sondy",
    ["toggle_alert_syslog_description"] = "Přepnout protokolování výstrah do systémového syslogu.",
    ["toggle_alert_syslog_title"] = "Přepíná protokolování výstrah do systému syslog. Přepnout upozornění na Syslog",
    ["toggle_alerts_notifications_description"] = "Přepněte hlášení výstrah do koncových bodů třetích stran.",
    ["toggle_alerts_notifications_title"] = "Upozornění na koncové body třetích stran",
    ["toggle_asn_rrds_description"] = "Přepněte vytváření bajtů a aplikačních časů pro autonomní systémy.",
    ["toggle_asn_rrds_title"] = "Autonomní systémy",
    ["toggle_autologout_description"] = "Přepněte automatické odhlášení uživatelů webového rozhraní s vypršenými relacemi.",
    ["toggle_autologout_title"] = "Automatické odhlášení",
    ["toggle_captive_portal_description"] = "Povolte webový zajatý portál pro ověření uživatelů sítě.",
    ["toggle_captive_portal_title"] = "Captive Portal",
    ["toggle_country_rrds_description"] = "Přepněte vytváření bajtových časových adres pro země.",
    ["toggle_country_rrds_title"] = "Země / Státy",
    ["toggle_data_exfiltration_description"] = "Přepněte heuristiku pro detekci exfiltrace dat a generování výstrah.",
    ["toggle_data_exfiltration_title"] = "Záznamy o filtraci dat",
    ["toggle_device_activation_alert_description"] = "Přepnout upozornění generovaná při připojení nebo odpojení zařízení od sítě.",
    ["toggle_device_activation_alert_title"] = "Upozornění na připojení / odpojení zařízení",
    ["toggle_device_first_seen_alert_description"] = "Přepnout upozornění generovaná, když se v síti objeví nová neviditelná zařízení.",
    ["toggle_device_first_seen_alert_title"] = "Připojení nových zařízení",
    ["toggle_device_protocols_description"] = "Přepnout upozornění generovaná, když je anomální aplikace detekována podle nakonfigurovaných <a href=\"%{url}\">politik aplikací zařízení</a>.",
    ["toggle_device_protocols_description_nedge"] = "Přepnout upozornění generovaná při anomálním protokolu. <i>Nepřiřazená</i> zařízení jsou detekována podle nakonfigurovaných <a href=\"%{url}\">politik aplikací zařízení</a>.",
    ["toggle_device_protocols_title"] = "Upozornění na aplikace zařízení",
    ["toggle_dns_alerts_description"] = "Přepnout upozornění generovaná v případě, že je dotaz DNS neplatný",
    ["toggle_dns_alerts_title"] = "Upozornění DNS",
    ["toggle_dropped_flows_alerts_description"] = "Povolit informativní výstrahy generované při blocích toků kvůli nakonfigurované politice",
    ["toggle_dropped_flows_alerts_title"] = "Povolit upozornění na zablokované toky",
    ["toggle_dst_with_post_nat_dst_description"] = "Vyměňte cílové adresy IPv4 (%%IPV4_DST_ADDR) a porty (%%L4_DST_PORT) s jejich post-nat hodnotami (%%POST_NAT_DST_IPV4_ADDR and %%POST_NAPT_DST_TRANSPORT_PORT).",
    ["toggle_dst_with_post_nat_dst_title"] = "Použijte cílové IPv4 adresy a porty",
    ["toggle_elephant_flows_alerts_description"] = "Přepnout výstrahy generované po zjištění Elephant toků. To je užitečné pro detekci nežádoucího chování (např. Exfiltrace dat).",
    ["toggle_elephant_flows_alerts_title"] = "Elephant Flows Alerts",
    ["toggle_email_notification_description"] = "Přepínání upozornění prostřednictvím e-mailu.",
    ["toggle_email_notification_title"] = "Přepnout oznámení e-mailem",
    ["toggle_external_alert_description"] = "Přepnout upozornění generovaná externími systémy (např. Suricata)",
    ["toggle_external_alert_title"] = "Externí upozornění",
    ["toggle_flow_alerts_iface_description"] = "Povolit generování výstrah toku, když je upozorněno síťové rozhraní.",
    ["toggle_flow_alerts_iface_title"] = "Povolit výstrahy toku",
    ["toggle_flow_rrds_description"] = "Přepněte vytváření bajtových časových adres pro každý port vzdáleného zařízení, jak bylo přijato prostřednictvím ZMQ (např. SFlow / NetFlow / SNMP). <br> Pro zařízení, která nejsou sFlow, %%INPUT_SNMP and %%OUTPUT_SNMP se musí objevit v nprobe šabloně.",
    ["toggle_flow_rrds_title"] = "Průtoková zařízení",
    ["toggle_host_mask_description"] = "Z důvodů ochrany soukromí může být nutné maskovat adresy IP hosts. Například pokud jste poskytovatelem internetových služeb, neměli byste vědět, které místní adresy přistupují ke vzdáleným hosts.",
    ["toggle_host_mask_title"] = "Mask Host IP Addresses",
    ["toggle_host_pools_log_description"] = "Přepnout vytváření protokolů souvisejících s host fondy. Protokoly zahrnují přidružení a disociace hosts do jejich hostitelských fondů.",
    ["toggle_host_pools_log_title"] = "Povolit protokol událostí host fondu",
    ["toggle_host_tskey_description"] = "Klíč, který se má použít pro výpis dat a časových výpisů pro hostitele v místní doméně vysílání. V síti DHCP je obvykle vhodné vybrat 'Mac Address'.",
    ["toggle_host_tskey_title"] = "Identifikátor hostitelského lokálního vysílání domény",
    ["toggle_http_auth"] = "Přepnout ověřování HTTP",
    ["toggle_http_auth_descr"] = "Přepnout ověřování gui pomocí autentizátoru HTTP.",
    ["toggle_ids_alert_description"] = "Přepnout upozornění generovaná systémy detekce narušení. Podívejte se na integraci Suricata prostřednictvím syslogu.",
    ["toggle_ids_alert_title"] = "Upozornění IDS",
    ["toggle_informative_captive_portal_description"] = "Neověřujte uživatele. Než uživatelům povolíte přístup na internet, zobrazte pouze informativní stránku.",
    ["toggle_informative_captive_portal_title"] = "Informativní",
    ["toggle_ip_reassignment_description"] = "Přepnout upozornění generovaná, když je IP adresa, dříve viděná s MAC adresou, nyní vidět s jinou MAC adresou. Toto upozornění může znamenat pokus o spoof ARP.",
    ["toggle_ip_reassignment_title"] = "Upozornění na změnu přiřazení IP",
    ["toggle_ldap_anonymous_bind_description"] = "Povolit anonymní vazbu.",
    ["toggle_ldap_anonymous_bind_title"] = "LDAP anonymní vazba",
    ["toggle_ldap_auth"] = "Přepnout ověření LDAP",
    ["toggle_ldap_auth_descr"] = "Přepnout ověřování gui pomocí protokolu LDAP.",
    ["toggle_ldap_referrals_description"] = "Určuje, zda má klient automaticky sledovat doporučení vrácená servery LDAP.",
    ["toggle_ldap_referrals_title"] = "Postupujte podle doporučení",
    ["toggle_local_auth"] = "Přepnout místní ověřování",
    ["toggle_local_auth_descr"] = "Přepnout ověřování gui podle %{product} definovaných uživatelů.",
    ["toggle_local_host_cache_enabled_description"] = "Přepnout vytváření položek mezipaměti pro nečinné místní počítače. Čítače lokálních hosts s mezipamětí se po detekci dalšího provozu host automaticky obnoví na své předchozí hodnoty.",
    ["toggle_local_host_cache_enabled_title"] = "Cache lokálního hostitele nečinnosti",
    ["toggle_log_to_file_description"] = "Namísto použití syslogu přepněte vytváření ntopng.log v adresáři výpisu dat. Nastavení se projeví při příštím %{product} spuštění.",
    ["toggle_log_to_file_title"] = "Povolit záznam trasování.",
    ["toggle_logging_level_description"] = "Vyberte úroveň protokolování runtime.",
    ["toggle_logging_level_title"] = "Úroveň protokolu",
    ["toggle_longlived_flows_alerts_description"] = "Přepnout upozornění generovaná, když byl detekován tok s dlouhou životností. To je užitečné pro detekci nežádoucího chování (např. Exfiltrace dat).",
    ["toggle_longlived_flows_alerts_title"] = "Upozornění na dlouhodobé toky",
    ["toggle_malware_probing_description"] = "Přepínání upozornění generovaných provozem odeslaným / přijatým hostitelem označeným malwarem. Seznamy škodlivého softwaru lze konfigurovat pomocí <a href=\"%{url}\">Stránka Seznamy kategorií</a>.",
    ["toggle_malware_probing_title"] = "Upozornění na malware",
    ["toggle_midnight_stats_reset_description"] = "Přepněte automatické resetování statistik o půlnoci. To zahrnuje statistiky počítačů a hostitelů",
    ["toggle_midnight_stats_reset_title"] = "Reset Statistik o Půlnoci",
    ["toggle_mining_alerts_description"] = "Přepnout upozornění generovaná, když je detekován provoz z / do hostitelů, o kterých je známo, že provádějí těžbu kryptoměn",
    ["toggle_mining_alerts_title"] = "Upozornění na těžbu",
    ["toggle_mysql_check_open_files_limit_description"] = "Povolit generování výstrah MySQL kvůli pravidelným kontrolám MySQL open_files_limit.<br>The open_files_limit , kontrola je užitečná při zjišťování, kdy je počet otevřených souborů MySQL vysoký, což by mohlo vést k chybám vložení databáze.",
    ["toggle_mysql_check_open_files_limit_title"] = "Povolit upozornění MySQL",
    ["toggle_ndpi_flows_rrds_description"] = "Přepněte vytváření Timeseries pro celkový počet toků na aplikaci Layer-7.",
    ["toggle_ndpi_flows_rrds_title"] = "Celkové toky vrstvy 7",
    ["toggle_ndpi_timeseries_creation_description"] = "Přepněte vytváření aplikačních Timeseries vrstvy 7. Vytváření časových úložišť pro jednu aplikaci vyžaduje více místa na disku a další I / O a obecně to není nutné.",
    ["toggle_ndpi_timeseries_creation_title"] = "Aplikace vrstvy 7",
    ["toggle_network_discovery_description"] = "Přepínejte periodický objev síťových zařízení pomocí více technik, které zahrnují skenování ARP, MDNS a SSDP. Přepínejte periodický objev síťových zařízení pomocí více technik, které zahrnují skenování ARP, MDNS a SSDP.<p><b><b>POZNÁMKA</b>:</b> zjišťování lze povolit pouze <u> </u> na fyzických rozhraních (tj. bez ZMQ), kde můžeme odesílat / přijímat provoz do sítě (tj. rozhraní pouze pro čtení, jako jsou rozhraní připojená k Mirror Ports, nebudou fungovat).",
    ["toggle_network_discovery_title"] = "Aktivní vyhledávání sítí",
    ["toggle_pool_activation_alert_description"] = "Přepnout upozornění generovaná při připojení prvního hostitele nebo odpojení posledního hostitele od některého fondu.",
    ["toggle_pool_activation_alert_title"] = "Upozornění na připojení / odpojení hostitelských fondů",
    ["toggle_pools_rrds_description"] = "Přepněte vytváření Timeseries bajtů a aplikací pro definované hostitelské fondy.",
    ["toggle_pools_rrds_title"] = "Hostistelské Fondy",
    ["toggle_potentially_dangerous_protocols_description"] = "Přepnout výstrahy generované při detekci potenciálně nebezpečného protokolu v toku.",
    ["toggle_potentially_dangerous_protocols_title"] = "Potenciálně nebezpečné protokoly",
    ["toggle_quota_exceed_alert_description"] = "Povolit generování výstrah vždy, když hostitelský fond překročí nakonfigurovanou kvótu.",
    ["toggle_quota_exceed_alert_title"] = "Povolit upozornění na překročení kvóty",
    ["toggle_radius_auth"] = "Přepnout ověření RADIUS",
    ["toggle_radius_auth_descr"] = "Přepněte ověřování gui prostřednictvím serveru RADIUS.",
    ["toggle_remote_to_remote_alerts_description"] = "Přepnout výstrahy generované, když jsou klient a server toku vzdáleni.",
    ["toggle_remote_to_remote_alerts_title"] = "Remote to Remote Alerts",
    ["toggle_send_telemetry_data_description"] = "Přispějte do projektu zasláním šifrovaného, <a href=\"%{url}\">anonymních telemetrických dat</a> to <a href=\"%{ntop_org}\">ntop.org</a>. Údaje se týkají pouze stavu %{product} (např. dostupnost, stav, zprávy o selhání). Nic ohledně sledovaného provozu nebude nikdy zasláno.",
    ["toggle_send_telemetry_data_title"] = "Telemetrická data",
    ["toggle_shaping_directions_description"] = "Povolte tuto možnost, abyste mohli nastavit různé politiky Shaping  pro vstup a výstup.",
    ["toggle_shaping_directions_title"] = "Split Shaping Directions",
    ["toggle_slack_notification_description"] = "Přepnout upozornění na upozornění pomocí Slack. Viz integrační pokyny zde <a href='%{url}'>zde</a>.",
    ["toggle_slack_notification_title"] = "Přepnout <a href=\"%{url}\">Slack</a> Oznámení",
    ["toggle_snmp_alerts_port_duplexstatus_change_description"] = "Přepnout upozornění generovaná při změně stavu duplexu rozhraní",
    ["toggle_snmp_alerts_port_duplexstatus_change_title"] = "Upozornění na změnu stavu duplexu rozhraní",
    ["toggle_snmp_alerts_port_errors_description"] = "Přepnout výstrahy generované při zvýšení počtů výmětů nebo chyb na rozhraní",
    ["toggle_snmp_alerts_port_errors_title"] = "Varování o výmazech / chybách rozhraní",
    ["toggle_snmp_alerts_port_status_change_description"] = "Přepnout upozornění generovaná při změně stavu rozhraní",
    ["toggle_snmp_alerts_port_status_change_title"] = "Upozornění na změnu stavu rozhraní",
    ["toggle_snmp_rrds_description"] = "Přepněte vytváření bajtových Timeseries pro každý port zařízení SNMP. Pro každé zařízení bude vytvořen port timeseries s vstupními / výstupními bajty.",
    ["toggle_snmp_rrds_title"] = "SNMP Devices Timeseries",
    ["toggle_src_and_dst_using_ports_description"] = "Určete zdroj a cíl přijatých toků pomocí čísel portů. Dolní číslo portu se považuje za cílový port. Vyšší číslo portu je považováno za zdrojový port. Důvodem je, že zdroje obecně využívají pomíjivé porty pro připojení ke známým cílovým portům a pomíjivé porty jsou obecně větší než známé. Pokud je tato možnost povolena, zdroj a cíl budou zaměněny, pokud se zjistí, že cílový port je větší než zdrojový port.",
    ["toggle_src_and_dst_using_ports_title"] = "Pomocí čísel portů určete zdroj a cíl",
    ["toggle_src_with_post_nat_src_description"] = "Vyměňte zdrojové adresy IPv4 (%%IPV4_SRC_ADDR) a portů (%%L4_SRC_PORT) s jejich post-nat hodnotami (%%POST_NAT_SRC_IPV4_ADDR and %%POST_NAPT_SRC_TRANSPORT_PORT).",
    ["toggle_src_with_post_nat_src_title"] = "Použijte adresy a porty IPv4 po zdroji",
    ["toggle_tcp_flags_rrds_description"] = "Přepnout vytváření příznaků TCP SYN, SYN + ACK, FIN + ACK a RST pro síťová rozhraní.",
    ["toggle_tcp_flags_rrds_title"] = "TCP Flags",
    ["toggle_tcp_retr_ooo_lost_rrds_description"] = "Přepněte vytváření Timeseries pro segmenty TCP mimo pořadí, ztracené a znovu odeslané. Časy budou vytvořeny pro síťová rozhraní, autonomní systémy, místní sítě a vlans.",
    ["toggle_tcp_retr_ooo_lost_rrds_title"] = "Segmenty TCP mimo provoz, ztracené a opakované přenosy",
    ["toggle_thpt_content_description"] = "Vyberte průchodnou jednotku, která se má zobrazit v provozních zprávách.",
    ["toggle_thpt_content_title"] = "Průchozí jednotka",
    ["toggle_tiny_flows_dump_description"] = "Přepněte export malých toků, které jsou toky s několika pakety nebo bajty. Snižuje kardinálnost toku v databázích, urychluje vkládání a vyhledávání. Vyladění malých toků může pomoci omezit kardinálnost toku, aniž by se snížila viditelnost dumpingových informací.",
    ["toggle_tiny_flows_dump_title"] = "Export malých toků",
    ["toggle_tls_alerts_description"] = "Přepnout upozornění generovaná v případě, že certifikát TLS poskytovaný serverem neodpovídá certifikátu Common Name.",
    ["toggle_tls_alerts_title"] = "TLS Alerts",
    ["toggle_top_sites_description"] = "Přepněte vytváření nejvíce navštěvovaných webových stránek pro místní hostitele. Top weby jsou vytvářeny pomocí <a href=\"%{url}\">heuristic</a> které udržují ne více než 20 webů na místního hostitele. Heuristika plně pracuje v paměti a nevyžaduje žádnou interakci s diskem. Top stránky jsou vymazány každých 5 minut. Historický archiv nejnavštěvovanějších webových stránek lze pro každého lokálního hostitele vytvořit periodickým dotazováním na JSON <i class=\"fas fa-download fa-sm\"></i> odkaz ke stažení přístupný ze stránky podrobností hostitele.",
    ["toggle_top_sites_title"] = "Top HTTP servery",
    ["toggle_traffic_rrd_creation_description"] = "Přepněte vytváření Timeseries bajtů a paketů.",
    ["toggle_traffic_rrd_creation_title"] = "Provoz",
    ["toggle_users_rrds_description"] = "Přepnout vytváření bajtů a Timeseries aplikací pro definované uživatele.",
    ["toggle_users_rrds_title"] = "Uživatelé",
    ["toggle_vlan_rrds_description"] = "Přepnout vytváření Timeseries bajtů a aplikací pro VLAN.",
    ["toggle_vlan_rrds_title"] = "VLANs",
    ["toggle_webhook_notification_description"] = "Přepnout upozornění na upozornění pomocí webhook (HTTP).",
    ["toggle_webhook_notification_title"] = "Přepnout oznámení Webhook",
    ["topk_heuristic_precision_description"] = "Při sestavování provozních hlášení použijte heuristiku při agregaci historických top hostitelů, zemí atd. Užitečné při sestavování zpráv po dlouhou dobu.",
    ["topk_heuristic_precision_title"] = "Top-K Heuristic",
    ["traffic_bridging"] = "Provozní Bridging",
    ["traffic_shaping"] = "Provozní Shaping",
    ["user_authentication"] = "Ověření uživatele",
    ["user_group_description"] = "Název skupiny, do které musí uživatel patřit, aby se mohl autentizovat jako uživatel bez oprávnění.",
    ["user_group_title"] = "Skupina uživatelů LDAP",
    ["vlan"] = "VLAN Id",
    ["web_user_interface"] = "Webové uživatelské rozhraní",
    ["webhook_notification"] = "Webhook Oznámení",
    ["webhook_notification_severity_preference_description"] = "Chyby (pouze chyby), Chyby a varování (chyby a varování, žádné informace), Vše (budou upozorňovány všechny druhy upozornění).",
    ["webhook_notification_severity_preference_title"] = "Závažnost oznámení",
    ["webhook_password_description"] = "Heslo, které se použije v případě ověření HTTP (volitelné).",
    ["webhook_send_error"] = "Chyba při odesílání zprávy na webhook.",
    ["webhook_sent_successfully"] = "Na webhook byla odeslána zpráva",
    ["webhook_sharedsecret_description"] = "Nastavit (definované uživatelem) tajemství, které má být ověřeno příjemcem (volitelné).",
    ["webhook_sharedsecret_title"] = "Sdílené tajemství",
    ["webhook_url_description"] = "Odeslat oznámení na tuto adresu URL ve formátu JSON.",
    ["webhook_url_title"] = "Adresa URL oznámení",
    ["webhook_username_description"] = "Uživatelské jméno, které se má použít v případě ověření HTTP (volitelné).",
    ["zmq_interfaces"] = "Rozhraní ZMQ",
  },
  ["processes_stats"] = {
    ["active_processes_title"] = "Aktivní procesy: Zobrazení v reálném čase",
    ["active_since"] = "Aktivní od",
    ["flows_count"] = "Počet toků",
    ["legend"] = "Legenda",
    ["lines"] = "Lines",
    ["missing_pid_name_message"] = "Chybí jméno pid",
    ["no_traffic_detected"] = "U tohoto procesu nebyl detekován žádný provoz, proces toku vypršel nebo proces byl ukončen.",
    ["processes_timeline_title"] = "Časová osa procesů",
    ["stack"] = "Stack",
    ["timeline"] = "Časová osa",
    ["top_hosts"] = "Top hostitelé",
    ["top_hosts_traffic"] = "Provoz top hostitelů",
    ["traffic_rcvd"] = "Provoz Rcvd",
    ["traffic_sent"] = "Provoz odeslán",
    ["type"] = "Typ",
  },
  ["report"] = {
    ["application_breakdown"] = "Aplikační Breakdown",
    ["applications"] = "Aplikace",
    ["begin_date_time"] = "Počáteční datum / čas",
    ["date"] = "%{month}-%{day}-%{year}",
    ["end_date_time"] = "Datum a čas ukončení",
    ["filter_report"] = "Filtrovat zprávu",
    ["generate"] = "generovat",
    ["invalid_begin"] = "Neplatný začátek",
    ["invalid_begin_date"] = "Neplatné datum zahájení",
    ["invalid_begin_end"] = "Neplatný začátek / konec",
    ["invalid_to"] = "Neplatné do",
    ["local_networks"] = "Lokální sítě",
    ["local_remote"] = "Localní/Vzdálený",
    ["network_interface"] = "Síťové rozhraní",
    ["period"] = "Interval",
    ["please_check_format"] = "zkontrolujte jeho formát",
    ["please_choose_valid"] = "Vyberte prosím platné datum a čas zahájení / ukončení",
    ["please_choose_valid_date_and_time"] = "Vyberte prosím platné datum a čas",
    ["receivers"] = "Přijímače",
    ["remote_local"] = "vzdálené / lokální",
    ["report_for_subject"] = "Zpráva - %{num_min} - pro %{subject} začínající %{dt}",
    ["reports_professional_only"] = "Zprávy jsou k dispozici pouze ve verzi Professional",
    ["senders"] = "Odesílatelé",
    ["starting"] = "Začínající",
    ["submit_filter"] = "Předložit filtr",
    ["symbolic_host_name_at_visualization"] = "Symbolické názvy hostitelů jsou rozlišeny během vizualizace\9.",
    ["toggle_all"] = "Přepnout vše",
    ["top_asn"] = "Top ASN",
    ["top_countries"] = "Top země / Státy",
    ["top_local_hosts"] = "Top lokalní hostilelé",
    ["top_local_os"] = "Top Localní OS",
    ["top_networks"] = "Top Sítě",
    ["top_non_local_os"] = "Top nelokální OS",
    ["top_remote_hosts"] = "Top vzdálení hostitelé",
    ["top_talkers"] = "Top Talkers",
    ["total_traffic"] = "Celkový provoz",
    ["traffic_report"] = "Zpráva o Provozu",
    ["use_server_timezone"] = "Použijte časové pásmo serveru",
  },
  ["sflows_stats"] = {
    ["active_flows"] = "Aktivní toky",
    ["client_peer"] = "Klient Peer",
    ["client_process"] = "Klientský proces",
    ["server_peer"] = "Server Peer",
    ["server_process"] = "Proces serveru",
    ["total_bytes"] = "Bajty celkem",
  },
  ["shaping"] = {
    ["applied_to"] = "Aplikován na",
    ["bandwidth_manager"] = "Správce šířky pásma",
    ["confirm_delete_all_policies"] = "Opravdu chcete odstranit všechny \"%{pool_name}\" politiky fondu",
    ["confirm_delete_policy"] = "Opravdu chcete odstranit",
    ["confirm_delete_shaper"] = "Opravdu chcete odstranit shaper",
    ["daily_time"] = "Denní čas (aktuální / kvóta))",
    ["daily_time_quota"] = "Denní časová kvóta",
    ["daily_traffic"] = "Denní provoz (aktuální / kvóta)",
    ["daily_traffic_quota"] = "Denní provozní kvóta",
    ["delete_all_policies"] = "Odstraňte všechny politiky",
    ["delete_policy"] = "Odstranit politiku",
    ["delete_shaper"] = "Odtranit Shaper",
    ["for_dropping_all_traffic"] = "za upuštění veškerého provozu",
    ["for_no_shaping"] = "for no shaping",
    ["initial_clone_protocols"] = "Počáteční pravidla aplikace budou klonována",
    ["initial_empty_protocols"] = "Počáteční pravidla aplikace budou prázdná",
    ["manage_policies"] = "Spravovat politiky",
    ["no_quota_applied"] = "Žádná kvóta",
    ["no_quota_data"] = "Není stanovena žádná kvóta",
    ["no_quota_traffic"] = "Dosud žádný provoz související s kvótami",
    ["no_shapers_available"] = "K dispozici nejsou žádné Shapers",
    ["note_default_pool_config"] = "Politiky a kvóty se vztahují pouze na uživatelem definované hostitelské fondy. Vyberte jiný fond nebo vytvořte nový zde <a href='%{url}'>zde</a>.",
    ["note_drop_core"] = "Vypuštění některých základních protokolů může mít vedlejší účinky na jiné protokoly. Například pokud blokujete DNS,<br> symbolická jména hostitelů již nejsou vyřešena, a proto funguje pouze komunikace s numerickými IP.",
    ["note_quota_unlimited"] = "Pro neomezený provoz nastavte provoz a časovou kvótu na 0.",
    ["note_target_type"] = "Co můžete zobrazit do sloupce Cíl, můžete změnit pomocí pole Typ cíle politiky v poli <a href=\"%{url}\">Předvolby překlenutí provozu</a> expertního pohledu..",
    ["note_traffic_categories"] = "Kategorie můžete konfigurovat z <a href=\"%{url}\">stránky aplikací</a>.",
    ["notes"] = "POZNÁMKY",
    ["policy_from_pool"] = "Politika z fondu",
    ["protocol_families"] = "Application Families",
    ["protocol_policy"] = "politika provozu",
    ["protocols"] = "Aplikace",
    ["protocols_policies"] = "pPolitika aplikací",
    ["see_quotas_here"] = "Navštivte hostitelský fond <a href='%{url}'>stránky s kvótami</a> pro úplný přehled kvót aktivního hostitelského fondu.",
    ["select_to_clone"] = "Vyberte existující síť, ze které chcete klonovat pravidla aplikace",
    ["set_max_rate_to"] = "Nastavte maximální rychlost na",
    ["shaper0_message"] = "Shaper 0 je výchozí shaper používaný pro místní hostitele, kteří ještě nemají definován Shaper",
    ["shaper_id"] = "Shaper Id",
    ["shapers_in_use_message"] = "Shapers lze odstranit pouze v případě, že nejsou použity v žádné síti",
    ["traffic_from"] = "Provoz z",
    ["traffic_to"] = "Provoz do",
  },
  ["show_alerts"] = {
    ["1_day"] = "1 den",
    ["1_hour"] = "1 hodina",
    ["1_month"] = "1 měsíc",
    ["1_week"] = "1 týden",
    ["1_year"] = "1 rok",
    ["30_min"] = "30 minut",
    ["5_min"] = "5 minut",
    ["6_months"] = "6 měsíců",
    ["alarmable"] = "Alarmující",
    ["alert_actions"] = "Akce",
    ["alert_count"] = "Spočítat",
    ["alert_counts"] = "Počítá",
    ["alert_datetime"] = "Datum / Čas",
    ["alert_description"] = "Popis",
    ["alert_duration"] = "Doba trvání",
    ["alert_severity"] = "Vážnost",
    ["alert_type"] = "Typ upozornění",
    ["alerts"] = "Upozornění",
    ["alerts_are_disabled_message"] = "Upozornění jsou deaktivována. Zkontrolujte prosím stránku předvoleb a aktivujte je.",
    ["alerts_to_purge"] = "Upozornění na očištění",
    ["confirm_delete_alert"] = "Opravdu chcete uvedené upozornění smazat?",
    ["confirm_release_alert"] = "Opravdu chcete uvedené upozornění vydat?",
    ["daily"] = "Denně",
    ["delete_alert"] = "Odstrani upozornění",
    ["delete_alerts_configuration"] = "Smazat konfiguraci",
    ["delete_all"] = "Smazat vše",
    ["delete_config_btn"] = "Odstranit %{conf} běžnou konfiguraci",
    ["delete_config_message"] = "Opravdu chcete smazat společné %{granularity} konfigurace %{conf}s",
    ["detected_alerts"] = "Zjištěná upozornění",
    ["disable_alerts"] = "Zakázat",
    ["disable_alerts_message"] = "Opravdu chcete zakázat \"%{type}\" upozornění na %{entity_value}?",
    ["disable_alerts_title"] = "Zakázat upozornění",
    ["disabled_alerts"] = "Zakázané upozornění",
    ["dropped_alerts"] = "Vynechaná upozornění",
    ["enable_alerts"] = "Povolit",
    ["enable_alerts_message"] = "Opravdu chcete povolit \"%{type}\" upozornění na %{entity_value}?",
    ["enable_alerts_title"] = "Povolit upozornění",
    ["engaged"] = "Engaged",
    ["engaged_alerts"] = "Engaged Alerts",
    ["explorer"] = "Prozkoumat",
    ["five_minutes"] = "Pět minut",
    ["flow_alerts"] = "Výstrahy toku",
    ["flush_data"] = "Vyplachovací data",
    ["host_delete_config_btn"] = "Odstranit hostitelskou %{host} konfiguraci",
    ["host_delete_config_confirm"] = "Opravdu chcete odstranit %{granularity} konfigurace pro hostitele",
    ["hourly"] = "Hodinově",
    ["iface_delete_config_btn"] = "Odstranit rozhraní %{iface} konfigurace",
    ["iface_delete_config_confirm"] = "Opravdu chcete odstranit %{granularity} konfiguraci rozhraní",
    ["in_the_selected_time_frame"] = "ve vybraném časovém období",
    ["interface_drops_threshold"] = "Rozhraní Packets Drops Alert",
    ["interface_drops_threshold_descr"] = "Maximální procento vyřazených paketů z celkového počtu pozorovaných paketů rozhraní\9",
    ["last_day"] = "Poslední den",
    ["last_hour"] = "Poslední hodina",
    ["last_minute"] = "Poslední minuta",
    ["minute"] = "Minuta",
    ["network_delete_config_btn"] = "Odtsranit síťovou %{network} konfiguraci",
    ["network_delete_config_confirm"] = "Opravdu chcete odstranit %{granularity} konfiguraci pro síť",
    ["no_recorded_alerts_message"] = "Žádná zaznamenaná upozornění pro rozhraní %{ifname}",
    ["num_ignored_alerts"] = "Ignorovaná upozornění",
    ["older_1_day_ago"] = " starší než 1 den",
    ["older_1_hour_ago"] = "starší než 1 hodina",
    ["older_1_month_ago"] = "starší než před 1 měsícem",
    ["older_1_week_ago"] = "starší než 1 týden",
    ["older_1_year_ago"] = "starší než před 1 rokem",
    ["older_30_minutes_ago"] = "starší než 30 minut",
    ["older_5_minutes_ago"] = "starší než 5 minut",
    ["older_6_months_ago"] = "starší než 6 měsíců",
    ["older_than"] = "starší než",
    ["past"] = "Minulost",
    ["past_alerts"] = "Minulá upozornění",
    ["past_flow"] = "Minulý tok",
    ["purge_num_alerts"] = "Pročistit [%{num_alerts} upozornění]",
    ["purge_subj_alerts"] = "Pročistit %{subj} upozornění",
    ["purge_subj_alerts_confirm"] = "Opravdu chcete pročistit všechny %{subj} upozornění?",
    ["release_alert"] = "Vydání upozornění",
    ["release_alert_action"] = "Vydat",
    ["reset_alert_database"] = "Flush Alerts Data",
    ["reset_alert_database_message"] = "Tato akce odstraní veškerá data související s upozenění včetněg<ul><li> Runtime alerts status </li> <li>Alerts configuration </li> <li> Persistent alerts SQLite storage</li></ul><br>Opravdu chcete pokračovat?",
    ["rtt"] = "RTT",
    ["startup"] = "Spuštění",
    ["trigger_alert_descr"] = "Povolit upozornění na tuto alarmující událost",
  },
  ["sites_page"] = {
    ["contacts"] = "Kontakty",
    ["current_sites"] = "Aktuální stránky",
    ["last_5_minutes_sites"] = "Stránky za posledních 5 minut",
    ["sites"] = "Stránky",
    ["top_sites_not_enabled_message"] = "Chcete-li sledovat navštívené weby, povolte vytváření top navštěvovaných webových stránek pro místní hostitele z <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preference</a>.",
    ["top_sites_not_seen"] = "Aktuální místní hostitel dosud nenavštívil žádný web.",
    ["top_visited_sites"] = "Top navštěvované stránky",
  },
  ["snmp"] = {
    ["AlertDescription"] = "Popis výstrahy",
    ["ConsoleDisplayBufferText"] = "Zobrazit text",
    ["GeneralSerialNumber"] = "Sériové číslo",
    ["InputCurrentLevel"] = "Současná úroveň",
    ["InputDimUnit"] = "Dim Unit",
    ["InputMaxCapacity"] = "Maximální kapacita",
    ["InputMediaDimFeedDirDeclared"] = "InputMediaDimFeedDirDeclared",
    ["InputMediaDimXFeedDirDeclared"] = "InputMediaDimXFeedDirDeclared",
    ["InputName"] = "InputName",
    ["MarkerColorantValue"] = "Marker Colorant",
    ["MarkerLifeCount"] = "Životnost markeru",
    ["MarkerSuppliesDescription"] = "Marker Supplies Description",
    ["MarkerSuppliesLevel"] = "Marker Supplies Level",
    ["MarkerSuppliesMaxCapacity"] = "Marker Supplies Max Capacity",
    ["PrinterCurrentStatus"] = "Aktuální stav",
    ["PrinterOperationalStatus"] = "Provozní stav",
    ["absolute_errors"] = "Chyby od spuštění",
    ["actual_errors"] = "Errors Since Last Poll",
    ["add_device"] = "Přidat nové zařízení",
    ["add_snmp_devices"] = "Přidat zařízení SNMP",
    ["alerted_interfaces"] = "Rozhraní s chybami",
    ["all_interfaces"] = "Všechna rozhraní",
    ["all_snmp_interface_types"] = "Všechny typy",
    ["all_snmp_statuses"] = "Všechny stavy",
    ["and_one_more_interface"] = "a <a href='%{url}'>1 další rozhraní</a>",
    ["bound_interface_description"] = "Vazba síťového rozhraní na rozhraní SNMP je užitečná pro porovnání síťového provozu monitorovaného pomocí ntopng s tím, který hlásí SNMP",
    ["caching_in_progress"] = "Probíhá procházení zařízení SNMP. To může trvat až 5 minut. Stránka se bude pravidelně aktualizovat.",
    ["contact"] = "Kontakt",
    ["delete_all_devices"] = "Odstraňte všechna zařízení",
    ["device_example"] = "Příklad: %{example}",
    ["device_ip"] = "IP zařízení",
    ["device_model"] = "Model zařízení",
    ["device_polling"] = "Device Polling",
    ["device_polling_desc"] = "Provádějte periodické walk SNMP pro sběr dat zařízení, včetně provozu a stavu rozhraní zařízení.",
    ["device_status"] = "Stav zařízení",
    ["disable_port_monitor"] = "Zakázat sledování portu",
    ["discover_devices"] = "Objevte zařízení",
    ["enable_port_monitor"] = "Povolit sledování portu",
    ["errors_filter"] = "Filtr chyb",
    ["errors_since"] = "Chyby od",
    ["ifName"] = "Název rozhraní",
    ["ifindex"] = "Index",
    ["in_bytes"] = "V bajtech",
    ["in_discards"] = "Ve vyřazených",
    ["in_errors"] = "V chybách",
    ["interface_device"] = "Rozhraní %{interface} [ %{device} ]",
    ["interfaces_with_discards"] = "Rozhraní s vyřazení",
    ["interfaces_with_errors"] = "Rozhraní s chybami",
    ["interfaces_with_errors_or_discards"] = "Rozhraní s chybami / vyřazení",
    ["last_change"] = "Poslední změna",
    ["low_port_speed"] = "Nízká rychlost portu",
    ["multiple_macs_non_trunk"] = "Multiple MACs on non-trunk port",
    ["no_answer"] = "Žádná odpověď od hostitele %{host}: prosím zkontrolujte, zda je SNMP nastaven a komunita je nastavena na správnou hodnotu",
    ["no_host_discovered"] = "Nebyl nalezen žádný hostitel %{host}/%{cidr}",
    ["note"] = "POZNÁMKA",
    ["object_id"] = "ObjectID",
    ["out_bytes"] = "Z bajtů",
    ["per_interface_settings"] = "Toto nastavení ovlivňuje pouze rozhraní \"%{iface}\". Navštivte <a href=\"%{url}\">%{global}</a> pro globální konfiguraci.",
    ["port_macs"] = "Mac adresy",
    ["port_macs_short"] = "MACs",
    ["remove_all_snmp_devices"] = "Odebrat všechna zařízení SNMP",
    ["remove_all_snmp_devices_confirm"] = "Opravdu chcete odebrat všechna zařízení SNMP?",
    ["remove_snmp_device"] = "Odebrat zařízení SNMP",
    ["remove_snmp_device_confirm"] = "Opravdu chcete odebrat zařízení SNMP %{device}?",
    ["snmp_all_interfaces"] = "Všechna rozhraní",
    ["snmp_also_seen_on"] = "Také vidět na",
    ["snmp_and_n_more_interfaces"] = "a <a href='%{url}'>%{count} více rozhraní</a>",
    ["snmp_community"] = "Komunita SNMP",
    ["snmp_device"] = "Zařízení SNMP",
    ["snmp_device_does_not_respond"] = "Zařízení SNMP neodpovídá.",
    ["snmp_device_last_poll"] = "4as od posledního Poll",
    ["snmp_device_polling_disabled"] = "Periodické Polling zařízení je zakázáno. Zobrazené informace mohou chybět nebo mohou být neaktuální. Polling lze povolit pomocí <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preference</a>.",
    ["snmp_device_x"] = "%{device}",
    ["snmp_devices"] = "Zařízení SNMP",
    ["snmp_interface"] = "Rozhraní SNMP",
    ["snmp_interface_type"] = "Typ rozhraní",
    ["snmp_interface_x"] = "Rozhraní: %{interface}",
    ["snmp_interfaces"] = "Rozhraní",
    ["snmp_monitor_disable_confirm"] = "Opravdu chcete zakázat monitorování stavu portu na zařízení SNMP %{device}?",
    ["snmp_monitor_enable_confirm"] = "Opravdu chcete povolit monitorování stavu portu na zařízení SNMP %{device}? Upozornění budou generována vždy, když port změní stav.",
    ["snmp_note_bridge_mib"] = "Periodic SNMP walks on the Bridge MIB are performed to populate the table.",
    ["snmp_note_bridge_mib_status"] = "Zobrazený stav je stav MIB dot1qTpFdbStatus Bridge spojený s adresou mac.",
    ["snmp_note_periodic_interfaces_polling"] = "Pravidelné  SNMP walks se provádějí pro aktualizaci rozhraní v pravidelných 5 minutových intervalech.",
    ["snmp_note_thpt_calc"] = "Propustnost odpovídá celkovému provozu (in + out) během dvou posledních po sobě jdoucích SNMP walks.",
    ["snmp_note_thpt_span"] = "Na dvou posledních po sobě jdoucích SNMP walks došlo k narušení %{last} a %{prev}.",
    ["snmp_port_monitor"] = "Monitorování portu SNMP",
    ["snmp_printer"] = "Tiskárna",
    ["snmp_timeseries_descr"] = "Timeseries zařízení SNMP lze povolit z  <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preference</a>. K zobrazení prvních datových bodů je třeba jen pár minut.",
    ["snmp_version"] = "Verze SNMP",
    ["status_down"] = "Dolů",
    ["status_up"] = "Nahoru",
    ["testing"] = "Testování",
    ["tp_fbd_status_invalid"] = "neplatný",
    ["tp_fbd_status_learned"] = "naučený",
    ["tp_fbd_status_mgmt"] = "mgmt",
    ["tp_fbd_status_other"] = "jiný",
    ["tp_fbd_status_self"] = "sám",
    ["trunk"] = "trunk",
    ["unable_to_delete_snmp_device"] = "Zařízení SNMP nelze smazat %{device}",
    ["unresponsive_device"] = "SNMP walks  jsou příliš pomalá. Zobrazené údaje mohou být zastaralé nebo chybějící. Zkontrolujte připojení k síti a odezvu zařízení. Nový pokus o skenování bude proveden za 15 minut.",
    ["view_device"] = "Zobrazit zařízení",
  },
  ["snmp_page"] = {
    ["guide_snmp_page_message"] = "Navštivte stránku <a href='%{url}'> SNMP</a> k přidání tohoto hostitele do seznamu nakonfigurovaných zařízení SNMP.",
    ["not_configured_as_snmp_device_message"] = "Hostitel %{host_ip} nebyl nakonfigurován jako zařízení SNMP.",
    ["showing_snmp_mib_info_default_community_message"] = "Zobrazuje informace SNMP MIB načtené pomocí výchozí komunity '%{community}'",
    ["trying_to_retrive_message"] = "Pokus o načtení hostitele SNMP MIB pomocí výchozí komunity '%{community}'",
    ["unable_to_retrive_snmp_default_community_message"] = "Nelze načíst hostitele SNMP MIB pomocí výchozí komunity '%{community}'.",
  },
  ["sprobe_page"] = {
    ["active_memory"] = "Aktivní paměť",
    ["latency"] = "Latence",
    ["processes"] = "Procesy",
    ["processes_traffic_tree"] = "Zpracovává se Traffic Tree",
    ["show_more_info"] = "Přejetím myší zobrazíte informace o procesu nebo dvojitým kliknutím zobrazíte další informace.",
    ["system_interactions"] = "Systémové interakce",
    ["top_processes"] = "Top procesy",
    ["top_users"] = "Top uživatelé",
    ["tree"] = "Tree",
    ["users"] = "Uživatelé",
  },
  ["sub_interfaces"] = {
    ["add_sub_if"] = "Přidat podrozhraní",
    ["add_sub_if_success"] = "Podřízené rozhraní bylo úspěšně vytvořeno. <b> Aby se změna projevila, je nutné restartovat ntopng</b>.",
    ["confirm_delete"] = "Jste si jistí, že chcete odstranit %{name}?",
    ["delete"] = "Odstranit podrozhraní",
    ["disaggregation"] = "Vlastní rozdělení provozu",
    ["filter_description"] = "Je podporován rozšířený formát nBPF: kromě standardní syntaxe BPF lze použít také pole NetFlow, včetně INPUT_SNMP, OUTPUT_SNMP, SRC_VLAN, DST_VLAN.",
    ["filter_examples"] = "Příklady filtrů",
    ["invalid_xnbpf"] = "Neplatný filtr nBPF",
    ["note"] = "ntopng může použít filtry podobné BPF k rozčlenění příchozího provozu a přesměrování na logická dílčí rozhraní. Stejný provoz lze přesměrovat na více rozhraní v případě překrývání filtrů.",
    ["sub_if_name"] = "Název podřízeného rozhraní",
    ["traffic_filter_nbpf"] = "Filtr provozu (formát nBPF)",
    ["traffic_filter_xnbpf"] = "Filtr provozu (rozšířený formát nBPF)",
  },
  ["system_stats"] = {
    ["delete_rtt_confirm"] = "Opravdu chcete odstranit hostitele \"%{host}\" ?",
    ["delete_rtt_host"] = "Odstranit RTT hostitele",
    ["descr_influxdb_cardinality"] = "<a href='%{car_url}'>Series cardinality  %{car_fa}</a> poskytuje informaci o tom, jak náročné je pro InfluxDB zpracovat písemné body. Vysoká řadová mohutnost je primárním ovladačem využití vysoké paměti pro mnoho pracovních zátěží databáze. <a href='%{sizing_url}'>Pokyny pro dimenzování hardwaru %{sizing_fa}</a> pro sérii doporučení mohutnosti jsou k dispozici na základě hardwaru.",
    ["descr_influxdb_dropped_points"] = "Celkový počet bodů ntopng klesl, protože je nemohl zapsat do InfluxDB. <a href='%{drop_url}'>Důvody %{drop_fa}</a> můžou být nedostupný, spadlý, přetížený nebo výrazně narušený InfluxDB.",
    ["descr_influxdb_exported_points"] = "Celkový počet bodů ntopng úspěšně zapsán do InfluxDB. <a target='_blank' href='%{point_url}'>Bod %{point_fa}</a> je hodnota měření v daném čase. Body se používají k vytváření časových grafů. Příkladem bodů je počet TLS bytů odeslaných daným hostitelem v poledne a celkový počet bytů přijatých v určitém rozhraní jednu minutu po poledni.",
    ["descr_influxdb_exports"] = "Celkový počet, kolikrát ntopng úspěšně zapsal do InfluxDB body <a href='%{exp_url}'>odesílání POST požadavků %{exp_fa}</a> do koncového bodu / write.",
    ["descr_influxdb_ram_memory"] = " <a href='%{mem_url}'>celkovou paměť %{mem_fa}</a> InfluxDB získal od operačního systému k fungování.",
    ["descr_influxdb_storage_utilization"] = "Celkové místo na disku, které používá InfluxDB k uložení všech bodů. Použité místo na disku také zahrnuje body automaticky agregované pomocí <a target='_blank' href='%{cq_url}'>nepřetržitých dotazů %{cq_fa}</a>.",
    ["dropped_points"] = "Spadlé body",
    ["export_failures"] = "Nevydařené exporty",
    ["export_retries"] = "Opakované exporty",
    ["exported_points"] = "Celkový počet bodů",
    ["exported_vs_dropped_points"] = "Celkový počet vs spadlé body",
    ["exports"] = "Celkový počet exportů",
    ["exports_label"] = "Exporty",
    ["health"] = "Zdraví",
    ["high_series_cardinality"] = "Vysoká mohutnost může způsobit zpomalení databáze",
    ["infludb_retried_vs_failed_exports"] = "Opakované / neúspěšné exporty",
    ["influxdb_health_green"] = "OK",
    ["influxdb_health_green_descr"] = "Export do InfluxDB funguje dobře.",
    ["influxdb_health_red"] = "Nepodařilo se exportovat",
    ["influxdb_health_red_descr"] = "InfluxDB je nedosažitelný nebo příliš pomalý, neschopný držet krok s ním. Vynechání bodů.",
    ["influxdb_health_yellow"] = "Dočasně nelze exportovat",
    ["influxdb_health_yellow_descr"] = "Momentálně nelze exportovat do InfluxDB. Probíhá opakování.",
    ["influxdb_note_docs"] = "Dokumentace s podrobným popisem všech zobrazených polí je k dispozici v ntopngDokumentace s podrobným popisem všech zobrazených polí je k dispozici v ntopng <a target='_blank' href='%{url}'>Uživatelské příručce</a>.",
    ["influxdb_storage"] = "Uložiště (%{dbname})",
    ["last_ip"] = "Poslední IP",
    ["last_rtt"] = "Poslední RTT",
    ["max_rtt"] = "Max RTT (ms)",
    ["max_rtt_no_ms"] = "Max RTT",
    ["metric"] = "Metrický",
    ["no_hosts_configured"] = "Nebyli nakonfigurováni žádní hostitelé",
    ["no_rtt_configured_for_host"] = "Žádné RTT nakonfigurováno pro %{host}",
    ["probe"] = "Sonda",
    ["probe_config"] = "Konfigurace",
    ["probes"] = "Sondy",
    ["series_cardinality"] = "Series Cardinality",
    ["short_desc_influxdb_cardinality"] = "Indikace toho, jak náročné je pro InfluxDB zpracovat písemné body.",
    ["short_desc_influxdb_dropped_points"] = "Celkový počet bodů klesl kvůli selhání zápisu InfluxDB.",
    ["short_desc_influxdb_exported_points"] = "Celkový počet bodů úspěšně zapsaných do InfluxDB.",
    ["short_desc_influxdb_exports"] = "Celkový počet úspěšných zápisů do InfluxDB.",
    ["short_desc_influxdb_health"] = "Aktuální zdraví exportu InfluxDB.",
    ["short_desc_influxdb_ram_memory"] = "Celková paměť, kterou InfluxDB získal z operačního systému.",
    ["short_desc_influxdb_storage_utilization"] = "Celkové místo na disku, které používá InfluxDB.",
    ["value"] = "Hodnota",
    ["write_througput"] = "Napište propustnost",
    ["redis"] = {
      ["redis_health_green"] = "OK",
      ["redis_health_green_descr"] = "Redis pracuje OK.",
      ["redis_health_red"] = "Problémy s perzistencí",
      ["redis_health_red_descr"] = "Redis nemůže data přetrvávat. Očekávejte %{product} k poruše.",
      ["redis_keys"] = "Databázové klíče",
      ["short_desc_redis_health"] = "Aktuální zdraví Redis.",
      ["short_desc_redis_keys"] = "Celkem klíčů v databázi Redis.",
      ["short_desc_redis_ram_memory"] = "Celková paměť, kterou Redis získala z operačního systému.",
    },
  },
  ["telemetry_page"] = {
    ["crash_report"] = "Zpráva o selhání",
    ["crash_report_descr"] = "Zpráva o selhání je odeslána %{product} neobvyklé ukončení. Zpráva o selhání obsahuje %{product} informace, jako je verze, architektura sestavení, operační systém a možnosti spuštění. Nic ohledně sledovaného provozu není nikdy zasláno. Následuje příklad zprávy o selhání:",
    ["last_data_sent"] = "Poslední data byla odeslána",
    ["send_telemetry_data"] = "Přispějte zasláním telemetrických dat",
    ["telemetry_data"] = "Telemetrická data",
    ["telemetry_data_change_preference"] = "<a href='%{url}'>změna</a>",
    ["telemetry_data_no_consent"] = "Nebyla vyjádřena žádná preference",
  },
  ["top_hosts"] = {
    ["top_hosts_local"] = "Top Hostitelé (Lokální)",
  },
  ["topk_heuristic"] = {
    ["precision"] = {
      ["aggressive"] = "Agresivní",
      ["disabled"] = "Zakázáno",
      ["less_accurate"] = "Méně přesné",
      ["more_accurate"] = "Přesnější",
    },
  },
  ["traffic_page"] = {
    ["l4_proto_overview"] = "Přehled protokolu",
    ["no_traffic_observed_message"] = "U zadaného hostitele nebyl pozorován žádný provoz",
    ["rcvd"] = "Rcvd",
  },
  ["traffic_profiles"] = {
    ["advanced_filter_examples"] = "Příklady pokročilých filtrů",
    ["all_profiles"] = "Všechny profily",
    ["confirm_delete_profile"] = "Opravdu chcete profil odstranit?",
    ["delete_profile"] = "Odstranit profil",
    ["destination_network"] = "Cílová síť",
    ["duplicate_profile"] = "Duplikovat název profilu",
    ["edit_traffic_profiles"] = "Profily provozu",
    ["enter_profile_filter"] = "Zadejte filtr profilu",
    ["enter_profile_name"] = "Zadejte název profilu",
    ["facebook_traffic"] = "Facebook",
    ["host_http_https"] = "Hostujte HTTP / HTTPS",
    ["host_traffic"] = "Host / Hostitel",
    ["http_traffic"] = "HTTP",
    ["invalid_bpf"] = "Neplatný filtr BPF",
    ["max_profiles_num"] = "S touto verzí ntopng můžete vytvářet pouze %{maxnum} profilů. Chcete-li tento limit odstranit, upgradujte na verzi Enterprise",
    ["no_profiles"] = "Nejsou nastaveny žádné profily",
    ["note"] = "Poznámka",
    ["note_0"] = "Názvy profilů provozu umožňují alfanumerické znaky, mezery a podtržítka",
    ["note_1"] = "Profily provozu se používají na toky. Každý tok může mít až jeden profil, takže v případě více shod profilů je vybrán pouze první",
    ["profile_name"] = "Jméno profilu",
    ["see_ndpi_protos"] = "(použíjte %{option} pro tisk všech protokolů podporovaných nDPI)",
    ["simple_filter_examples"] = "Příklady jednoduchých filtrů",
    ["source_ethernet"] = "Zdrojová adresa MAC",
    ["traffic_between"] = "Provoz mezi hostiteli",
    ["traffic_filter_bpf"] = "Filtr provozu (formát nBPF)",
    ["traffic_from_to"] = "Provoz z hostitele na druhého",
    ["traffic_profiles"] = "Profily provozu",
  },
  ["traffic_recording"] = {
    ["about_to_extract"] = "Extrahování provozu z <b>%{date_begin}</b> to <b>%{date_end}</b>",
    ["active_since"] = "Aktivní od",
    ["archive"] = "Archiv",
    ["completed"] = "Dokončeno",
    ["continuous_recording"] = "Nepřetržité sledování provozu",
    ["continuous_recording_and_flows"] = "Nepřetržité sledování provozu a viditelnost toku",
    ["delete_all_jobs"] = "Odstranit všechny úlohy",
    ["delete_all_jobs_confirm"] = "Opravdu chcete odstranit všechny extrakční úlohy? Aktivní úlohy budou zastaveny.",
    ["delete_job"] = "Smazat úlohu",
    ["delete_job_confirm"] = "Opravdu chcete odstranit úlohu %{job_id} a související soubory Pcap?",
    ["disabled"] = "Zakázáno",
    ["disk_space"] = "Maximální místo na disku",
    ["disk_space_note"] = "Maximum disk space used for recorded traffic on disk.",
    ["disk_space_note_in_use"] = "%{in_use} GB se v této instanci již používají.",
    ["download"] = "Stažení",
    ["download_nth_pcap"] = "Stahování Pcap #{0}",
    ["dump_window"] = "Dump Window",
    ["edit_filter"] = "Upravit filtr",
    ["err_alloc"] = "chyba přidělení paměti",
    ["err_filter"] = "nepodporovaný filtr",
    ["err_open"] = "nelze otevřít výpis",
    ["err_stuck"] = "seklý nebo přerušen",
    ["err_unknown"] = "neočekávaná chyba",
    ["ext_interface"] = "Externí rozhraní",
    ["extract_action"] = "Extrahovat",
    ["extract_now"] = "Extrahujte nyní",
    ["extracted_bytes"] = "Extrahované bajty",
    ["extracted_packets"] = "Extrahované pakety",
    ["extraction_scheduled"] = "Byla naplánována extrakce úlohy, zkontrolujte prosím %{page} stránku ke stažení pcap, jakmile je soubor připraven. ID úlohy pro tuto extrakci je",
    ["failed"] = "Selhalo",
    ["failure"] = "Selhání",
    ["failure_note"] = "Zkontrolujte trasování protokolu a zkuste restartovat službu.",
    ["filter_bpf"] = "Filtr (formát nBPF)",
    ["filter_examples"] = "Příklady filtrů",
    ["global_settings_note"] = "Globální nastavení (např. Licenční klíč) lze konfigurovat z <a href=\"%{url}\">Předvoleb záznamu provozu</a>.",
    ["invalid_bpf"] = "Neplatný filtr",
    ["job_date_time"] = "Datum / čas vytvoření úlohy",
    ["job_id"] = "ID úlohy",
    ["jobs"] = "Úlohy",
    ["logs"] = "Záznamy provozu",
    ["max_extracted_pcap_bytes_description"] = "Maximální velikost souborů pcap extrahovaných ze zaznamenaných dat. V případě extrakcí přesahujících tuto velikost bude výstup rozdělen do několika souborů.",
    ["max_extracted_pcap_bytes_title"] = "Maximální velikost extrahovaného souboru",
    ["missing_data_msg"] = "Záznam provozu byl zastaven nebo restartován. Některá data mohou chybět.",
    ["missing_parameters"] = "Chybí povinné parametry",
    ["msg_err_missing_timeline"] = "Nelze určit časovou osu aktuálně spuštěného n2disk. Extrakce lze provést pouze tehdy, když je n2disk aktuální a spuštěn s volbou --timeline-dir.",
    ["msg_err_timeline_path_not_existing"] = "Cesta Timeline nebyla v systému nalezena.",
    ["msg_err_unable_to_access_timeline"] = "Nelze číst zaznamenaná data. Nedostatečná oprávnění. Ujistěte se, že uživatel provozující ntopng je ve stejné skupině jako uživatel n2disk.",
    ["msg_err_unknown"] = "Neznámý stav.",
    ["msg_external_providers_detected"] = "Zjištěni externí poskytovatelé záznamu provozu Program ntopng může automaticky propojit toto rozhraní s externím poskytovatelem. Můžete nechat ntopng postarat se o nahrávání pomocí této stránky, nebo můžete <a href=\"%{url}\"><i class=\"fas fa-cog\"></i> konfigurovat</a> externí poskytovatele záznamu provozu.",
    ["msg_ok"] = "Připraven k extrakci",
    ["multiple_extracted_files"] = "Extrakce provozu generovala více souborů pcap systému %{mb} MB, je možné tento limit změnit z Předvoleb. Kliknutím na odkazy níže stáhněte soubory pcap.",
    ["no_data_in_interval"] = "Na vybraném časovém intervalu nejsou na disku žádná (nebo částečná) data pcap. Vezměte prosím na vědomí, že data pcap jsou ukládána každou minutu (poslední minuta není k dispozici) a stará data jsou vymazána (zkontrolujte aktuální okno výpisu v <A HREF=\"%{page}\">stavové stránce</A>). Zkuste prosím zvolit jiný časový interval.",
    ["no_file"] = "Zatím žádné vysypané soubory",
    ["no_recorded_data"] = "V zadaném časovém frame nejsou zaznamenána žádná data. Provozový záznamník potřebuje nějaký čas k zápisu posledních dat.",
    ["not_found"] = "Soubor nenalezen",
    ["not_granted"] = "Žádosti nebylo vyhověno",
    ["note_dump"] = "V ethernetových sítích má každý paket <A HREF=\"https://en.wikipedia.org/wiki/Ethernet_frame\">režii 24 bajtů </A> [preambule, začátek rámce, CRC, IFG]. Taková režie se účtuje do provozu rozhraní, ale nepřidává se k provozu, který je ukládán na disk. Z tohoto důvodu se může počet bytů na této stránce lišit od těch, které jsou uvedeny v grafu rozhraní.",
    ["packet_dumps"] = "Výpisy paketů",
    ["pcap_download"] = "Extrahovat pcap",
    ["pcap_download_message"] = "Zahajte extrakci a zkontrolujte %{page} stránku ke stažení pcap, jakmile je soubor připraven.",
    ["processing"] = "zpracovává se",
    ["queue_as_job"] = "Queue as a Job",
    ["recording"] = "Záznam",
    ["restart"] = "Restart",
    ["restart_service"] = "Restartujte službu",
    ["settings"] = "Nastavení",
    ["start_extraction"] = "Zahajte extrakci",
    ["stop_job"] = "Zastavit úlohu",
    ["stop_job_confirm"] = "Opravdu chcete úlohu zastavit %{job_id}?",
    ["stopped"] = "Zastavilo",
    ["storage"] = "Úložiště",
    ["storage_dir"] = "Adresář úložiště",
    ["storage_directory_config"] = "Cesta úložného adresáře lze změnit zadáním <i>%{option}</i> možnosti do %{product} konfiguračního souboru.",
    ["storage_utilization"] = "Využití úložiště",
    ["storage_utilization_pcap"] = "Využití úložiště PCAP",
    ["traffic_extraction_jobs"] = "Traffic Extraction Jobs",
    ["traffic_extractions"] = "Extrakce",
    ["traffic_on_disk"] = "Provoz na disku",
    ["traffic_recording"] = "Záznam provozu",
    ["traffic_recording_provider"] = "Poskytovatel provozního záznamu",
    ["traffic_recording_settings"] = "Nastavení záznamu provozu",
    ["traffic_recording_status"] = "Stav záznamu provozu",
    ["unsupported_fields"] = "Vybraný chart poskytuje pohled na provoz, který násrtoj pro extrakci plně nepodporuje, extrahovaný provoz bude obsahovat větší provoz, než se očekávalo.",
    ["waiting"] = "Čekání",
    ["waiting_nospace"] = "Čekání (na disku není místo)",
  },
  ["traffic_report"] = {
    ["current_day"] = "Aktuální den",
    ["current_month"] = "Aktuální měsíc",
    ["current_week"] = "Tento týden",
    ["daily"] = "Denně",
    ["header_daily"] = "Denní zpráva",
    ["header_monthly"] = "Měsíční zpráva",
    ["header_weekly"] = "Týdenní zpráva",
    ["monthly"] = "Měsičně",
    ["previous_day"] = "Předchozí den",
    ["previous_month"] = "Předchozí měsíc",
    ["previous_week"] = "Předchozí týden",
    ["weekly"] = "Týdně",
  },
  ["tree_map"] = {
    ["hosts_treemap"] = "Hosts Tree Map",
  },
  ["unknown_devices"] = {
    ["active_only"] = "Pouze aktivní",
    ["all_devices"] = "Všechna zařízení",
    ["assign_device_pool"] = "Přiřadit zařízení fondu",
    ["assign_pool"] = "Přiřadit k fondu",
    ["device_name"] = "Název zařízení",
    ["devices_only_note"] = "Zařízení není považováno za nepřiřazené, pokud pro tuto adresu MAC nejsou definováni žádné členy fondu. Členské adresy založené na IP zde neplatí.",
    ["filter_devices"] = "Filtrovat zařízení",
    ["first_seen"] = "Prvně viděn",
    ["inactive_only"] = "Pouze neaktivní",
    ["last_seen"] = "Posledně viděn",
    ["no_pools"] = "Aby bylo možné přiřadit neznámá zařízení, musí být vytvořen hostitelský fond.",
    ["select_pool"] = "Vyberte z rozevíracího seznamu hostitelský fond, který chcete přiřadit '%{mac}' to:",
    ["unassigned_devices"] = "Nepřiřazená zařízení",
  },
  ["user_activity"] = {
    ["alerts_deleted"] = "Uživatel '%{user}' vyčištil '%{status}' upozornění.",
    ["changed_preference"] = "Uživatel '%{user}' změněnil nastavení pro %{pref}.",
    ["deleted_all_interfaces_data"] = "Uživatel '%{user}' smazal data pro všechna rozhraní.",
    ["deleted_host_data"] = "Uživatel '%{user}' smazal data pro hostitele %{host} na rozhraní %{ifname}.",
    ["deleted_inactive_interfaces_data"] = "Uživatel '%{user}' smazal data pro všechna neaktivní rozhraní.",
    ["deleted_interface_data"] = "Uživatel '%{user}' smazal data pro rozhraní %{ifname}.",
    ["deleted_network_data"] = "Uživatel '%{user}' smazal data pro síť %{network} na rozhraní %{ifname}.",
    ["disabled_preference"] = "Uživatel '%{user}' zakázal preference %{pref}.",
    ["enabled_preference"] = "Uživatel '%{user}' povolil preference %{pref}.",
    ["exported_data"] = "Uživatel '%{user}' exportoval data JSON pro '%{mode}' hostitelé.",
    ["exported_data_host"] = "Uživatel '%{user}' exportoval data JSON pro '%{mode}' hostitele %{host}.",
    ["file_downloaded"] = "Uživatel '%{user}' stáhnul soubor '%{file}'.",
    ["flows_downloaded"] = "Uživatel '%{user}' stáhnul toky dat z %{from} na %{to}.",
    ["host_json_downloaded"] = "Uživatel '%{user}' stáhnul data JSON pro hostitele %{host}.",
    ["live_capture"] = "Uživatel '%{user}' zachytil živý provoz na rozhraní %{ifname}.",
    ["live_capture_host"] = "Uživatel '%{user}' zachytil živý provoz pro hostitele %{host} na rozhraní %{ifname}.",
    ["live_capture_with_filter"] = "Uživatel '%{user}' zachytil filtr pro porovnávání živých přenosů '%{filter}' na rozhraní %{ifname}.",
    ["live_extraction"] = "UživatelUživatel '%{user}' stáhnul provoz z rozhraní %{ifname} z %{from} na %{to}.",
    ["live_extraction_with_filter"] = "Uživatel '%{user}' stáhl provoz z rozhraní %{ifname} z %{from} na %{to} odpovídající filtr '%{filter}'.",
    ["login_not_authorized"] = "Bylo odepřeno přihlášení uživateli'%{user}'.",
    ["login_successful"] = "Uživatel '%{user}' přihlášen.",
    ["password_changed"] = "Heslo pro uživatele '%{pwd_user}' změněno uživatelem '%{user}' s ip '%{ip}'.",
    ["recording_disabled"] = "Uživatel '%{user}' zakázal sledování provozu na rozhraní %{ifname}.",
    ["recording_enabled"] = "Uživatel '%{user}' povolil sledování provozu na rozhraní %{ifname}.",
    ["snmp_device_added"] = "Uživatel '%{user}' přidal zařízení SNMP %{ip}.",
    ["snmp_device_deleted"] = "Uživatel '%{user}' odebral zařízení SNMP %{ip}.",
    ["unknown_activity"] = "Uživatel '%{user}' dělal nějakou neznámou aktivitu (%{scope}), nahlaste to prosím.",
    ["unknown_activity_function"] = "Uživatel '%{user}' dělal nějakou neznámou aktivitu (%{name}), nahlaste to prosím.",
    ["user_added"] = "Uživatel '%{add_user}' přidán uživatelem '%{user}'.",
    ["user_deleted"] = "Uživatel '%{del_user}' odebrán uživatelem '%{user}'.",
  },
  ["user_info"] = {
    ["missing_user_name_message"] = "Chybí uživatelské jméno",
    ["processes"] = "Procesy",
    ["processes_overview"] = "Přehled procesů",
    ["top_l4_protocols"] = "Top protokoly",
    ["top_l7_protocols"] = "Top aplikace",
  },
  ["users"] = {
    ["add_new_user"] = "Přidat nového uživatele",
    ["add_user"] = "Přidat uživatele",
    ["assigned_devices"] = "Přiřazená zařízení",
    ["cat_protocols"] = "%{cat} Aplikace",
    ["categories"] = "Kategorie",
    ["client_policy"] = "Zařízení jako klient",
    ["confirm_delete_user"] = "Opravdu chcete smazat uživatele \"%{user}\"?",
    ["delete_user"] = "Smazat uživatele",
    ["devices"] = "Zařízení",
    ["edit"] = "Upravit",
    ["edit_global_policies"] = "Upravit globální politiky",
    ["fallback_policy"] = "Záložní politika",
    ["full_name"] = "Celé jméno",
    ["global"] = "Globalní",
    ["global_policies"] = "Výchozí politika",
    ["no_users"] = "Žádní uživatelé",
    ["num_protocols"] = "Počet aplikací",
    ["policy"] = "Politika",
    ["protocols"] = "Aplikace",
    ["reset_to_defaults"] = "Obnovit na výchozí hodnoty",
    ["reset_to_defaults_confirm"] = "Opravdu chcete resetovat typ zařízení \"%{devtype}\" politiky k výchozím hodnotám?",
    ["server_policy"] = "Zařízení jako server",
    ["settings"] = "Nastavení",
    ["total_daily_time_quota"] = "Celková denní kvóta",
    ["total_daily_traffic_quota"] = "Celková denní provozní kvóta",
    ["unchanged"] = "Beze změny",
    ["user_exists"] = "Uživetel \"%{user}\" již existuje",
    ["user_x"] = "Uživatel: %{user}",
    ["shapers"] = {
      ["default"] = "Výchozí",
      ["drop"] = "Spadnout",
      ["pass"] = "Přejít",
      ["slow"] = "Pomalý průchod",
      ["slower"] = "Pomalejší průchod",
    },
  },
  ["vlan_details"] = {
    ["no_available_stats_for_vlan_message"] = "Žádné dostupné statistiky pro VLAN %{vlan_id}. Počkejte prosím několik minut, než povolíte %{product} sbírat nové statistiky.",
    ["vlan_id_parameter_missing_or_invalid_message"] = "Parametr Vlan_Id chybí nebo není platný",
  },
  ["vlan_stats"] = {
    ["vlan_id"] = "VLAN ID",
    ["vlans"] = "VLANs",
  },
}

return lang
